@@ -33,26 +33,14 @@
 #include <tango/tango.h>
 #include "DataBase.h"
 #include "DataBaseClass.h"
+#include "DatabaseConnectionHandle.h"
+#include "DatabaseConnectionPool.h"
 #include "Logging.h"
 
 #include <errmsg.h>
 
 #include <stdio.h>
 
-#ifdef _TG_WINDOWS_
-#include <ws2tcpip.h>
-#include <windows.h>
-static inline void sleep(DWORD seconds)
-{
-    Sleep(seconds * 1000);
-}
-#else
-#include <arpa/inet.h>
-#include <sys/socket.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#endif
-
 namespace DataBase_ns {
 
 //+----------------------------------------------------------------------------
@@ -420,59 +408,37 @@ void DataBase::check_history_tables()
 //
 //-----------------------------------------------------------------------------
 
-Tango::DevULong64 DataBase::get_id(const char *name,int con_nb)
+Tango::DevULong64 DataBase::get_id(const char *name, DatabaseConnectionHandle &dch)
 {
 	TangoSys_MemStream sql_query;
 
-//
-// If no MySQL connection passed to this method,
-// get one
-//
-
-	bool need_release = false;
-
-	if (con_nb == -1)
-	{
-		con_nb = get_connection();
-		need_release = true;
-	}
-
-    sql_query.str("");
-    sql_query << "UPDATE " << name << "_history_id SET id=LAST_INSERT_ID(id+1)";
+	sql_query.str("");
+	sql_query << "UPDATE " << name << "_history_id SET id=LAST_INSERT_ID(id+1)";
 	std::string tmp_str = sql_query.str();
 
-	if (mysql_real_query(conn_pool[con_nb].db, tmp_str.c_str(),tmp_str.length()) != 0)
+	if (mysql_real_query(dch.db(), tmp_str.c_str(),tmp_str.length()) != 0)
 	{
 		TangoSys_OMemStream o;
 
 		WARN_STREAM << "DataBase::get_id() failed to query TANGO database:" << std::endl;
 		WARN_STREAM << "  query = " << tmp_str << std::endl;
-		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
+		WARN_STREAM << " (SQL error=" << mysql_error(dch.db()) << ")" << std::endl;
 
-		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::ends;
-
-		if (need_release == true)
-			release_connection(con_nb);
+		o << "Failed to query TANGO database (error=" << mysql_error(dch.db()) << ")" << std::ends;
 
 		Tango::Except::throw_exception(DB_SQLError,o.str(),"DataBase::get_id()");
 	}
 
-	my_ulonglong val = mysql_insert_id(conn_pool[con_nb].db);
+	my_ulonglong val = mysql_insert_id(dch.db());
 	if (val == 0)
 	{
 		TangoSys_OMemStream o;
 
 		o << "Failed to get history id : " << name;
 
-		if (need_release == true)
-			release_connection(con_nb);
-
 		Tango::Except::throw_exception(DB_SQLError,o.str(),"DataBase::get_id()");
 	}
 
-	if (need_release == true)
-		release_connection(con_nb);
-
 	return (Tango::DevULong64)val;
 }
 
@@ -483,50 +449,34 @@ Tango::DevULong64 DataBase::get_id(const char *name,int con_nb)
 // description : 	Execute a SQL query , ignore the result.
 //
 //-----------------------------------------------------------------------------
-void DataBase::simple_query(std::string sql_query,const char *method,int con_nb)
+void DataBase::simple_query(std::string sql_query,const char *method, DatabaseConnectionHandle &dch)
 {
-
-//
-// If no MySQL connection passed to this method,
-// get one
-//
-
-	bool need_release = false;
-
-	if (con_nb == -1)
-	{
-		con_nb = get_connection();
-		need_release = true;
-	}
-
-	DEBUG_STREAM << "Using MySQL connection with semaphore " << con_nb << std::endl;
-
 //
 // Call MySQL
 //
 
-	if (mysql_real_query(conn_pool[con_nb].db, sql_query.c_str(),sql_query.length()) != 0)
+	if (mysql_real_query(dch.db(), sql_query.c_str(),sql_query.length()) != 0)
 	{
 		TangoSys_OMemStream o;
 		TangoSys_OMemStream o2;
 
 		WARN_STREAM << "DataBase::" << method << " failed to query TANGO database:" << std::endl;
 		WARN_STREAM << "  query = " << sql_query << std::endl;
-		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
+		WARN_STREAM << " (SQL error=" << mysql_error(dch.db()) << ")" << std::endl;
 
-		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")";
+		o << "Failed to query TANGO database (error=" << mysql_error(dch.db()) << ")";
 		o << "\n.The query was: " << sql_query << std::ends;
 		o2 << "DataBase::" << method << std::ends;
 
-		if (need_release == true)
-			release_connection(con_nb);
-
 		Tango::Except::throw_exception(DB_SQLError,o.str(),o2.str());
 	}
+}
 
-	if (need_release)
-		release_connection(con_nb);
+void DataBase::simple_query(std::string sql_query,const char *method)
+{
+	DatabaseConnectionHandle dch(dcp);
 
+	simple_query(sql_query, method, dch);
 }
 
 //+----------------------------------------------------------------------------
@@ -536,110 +486,54 @@ void DataBase::simple_query(std::string sql_query,const char *method,int con_nb)
 // description : 	Execute a SQL query and return the result.
 //
 //-----------------------------------------------------------------------------
-MYSQL_RES *DataBase::query(std::string sql_query,const char *method,int con_nb)
+MYSQL_RES *DataBase::query(std::string sql_query,const char *method, DatabaseConnectionHandle& dch)
 {
 	MYSQL_RES *result;
 
-//
-// If no MySQL connection passed to this method,
-// get one
-//
-
-	bool need_release = false;
-
-	if (con_nb == -1)
-	{
-		con_nb = get_connection();
-		need_release = true;
-	}
-
-	DEBUG_STREAM << "Using MySQL connection with semaphore " << con_nb << std::endl;
-
 //
 // Call MySQL
 //
 
-	if (mysql_real_query(conn_pool[con_nb].db, sql_query.c_str(),sql_query.length()) != 0)
+	if (mysql_real_query(dch.db(), sql_query.c_str(),sql_query.length()) != 0)
 	{
 		TangoSys_OMemStream o;
 		TangoSys_OMemStream o2;
 
 		WARN_STREAM << "DataBase::" << method << " failed to query TANGO database:" << std::endl;
 		WARN_STREAM << "  query = " << sql_query << std::endl;
-		WARN_STREAM << " (SQL error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
+		WARN_STREAM << " (SQL error=" << mysql_error(dch.db()) << ")" << std::endl;
 
-		o << "Failed to query TANGO database (error=" << mysql_error(conn_pool[con_nb].db) << ")";
+		o << "Failed to query TANGO database (error=" << mysql_error(dch.db()) << ")";
 		o << "\nThe query was: " << sql_query << std::ends;
 		o2 << "DataBase::" << method << std::ends;
 
-		if (need_release == true)
-			release_connection(con_nb);
-
 		Tango::Except::throw_exception(DB_SQLError,o.str(),o2.str());
 	}
 
-	if ((result = mysql_store_result(conn_pool[con_nb].db)) == NULL)
+	if ((result = mysql_store_result(dch.db())) == NULL)
 	{
 		TangoSys_OMemStream o;
 		TangoSys_OMemStream o2;
 
-		WARN_STREAM << "DataBase:: " << method << " : mysql_store_result() failed  (error=" << mysql_error(conn_pool[con_nb].db) << ")" << std::endl;
+		WARN_STREAM << "DataBase:: " << method << " : mysql_store_result() failed  (error=" << mysql_error(dch.db()) << ")" << std::endl;
 
-		o << "mysql_store_result() failed (error=" << mysql_error(conn_pool[con_nb].db) << ")";
+		o << "mysql_store_result() failed (error=" << mysql_error(dch.db()) << ")";
 		o2 << "DataBase::" << method;
 
-		if (need_release == true)
-			release_connection(con_nb);
-
 		Tango::Except::throw_exception(DB_SQLError,o.str(),o2.str());
 	}
 
-	if (need_release)
-		release_connection(con_nb);
-
 	return result;
 
 }
 
-//+----------------------------------------------------------------------------
-//
-// method : 		DataBase::get_connection()
-//
-// description : 	Get a MySQl connection from the connection pool
-//
-//-----------------------------------------------------------------------------
-int DataBase::get_connection()
+MYSQL_RES *DataBase::query(std::string sql_query,const char *method)
 {
+	DatabaseConnectionHandle dch(dcp);
 
-//
-// Get a MySQL connection and lock it
-// If none available, wait for one
-//
-
-	int loop = 0;
-	while (conn_pool[loop].the_sema.trywait() == 0)
-	{
-		loop++;
-		if (loop == conn_pool_size)
-		{
-			int sem_to_wait;
-			{
-				omni_mutex_lock oml(sem_wait_mutex);
-				sem_to_wait = last_sem_wait++;
-				if (last_sem_wait == conn_pool_size)
-					last_sem_wait = 0;
-			}
-			loop = sem_to_wait;
-			WARN_STREAM << "Waiting for one free MySQL connection on semaphore " << loop << std::endl;
-			conn_pool[loop].the_sema.wait();
-			break;
-		}
-	}
-
-	return loop;
+	return query(sql_query, method, dch);
 }
 
-
 //+------------------------------------------------------------------
 /**
  *	method:	purge_property()
@@ -648,7 +542,7 @@ int DataBase::get_connection()
  *
  */
 //+------------------------------------------------------------------
-void DataBase::purge_property(const char *table,const char *field,const char *object,const char *name,int con_nb) {
+void DataBase::purge_property(const char *table,const char *field,const char *object,const char *name, DatabaseConnectionHandle &dch) {
 
   TangoSys_MemStream sql_query;
   MYSQL_RES *result;
@@ -659,7 +553,7 @@ void DataBase::purge_property(const char *table,const char *field,const char *ob
             << " WHERE " << field << "=\"" << object << "\" AND name=\"" << name
             << "\" ORDER by date";
 
-  result = query(sql_query.str(),"purge_property()",con_nb);
+  result = query(sql_query.str(),"purge_property()", dch);
   int nb_item = mysql_num_rows(result);
 
   if(nb_item>historyDepth) {
@@ -669,7 +563,7 @@ void DataBase::purge_property(const char *table,const char *field,const char *ob
         row2 = mysql_fetch_row(result);
         sql_query.str("");
         sql_query << "DELETE FROM " << table << " WHERE id='" << row2[0] << "'";
-		simple_query(sql_query.str(),"purge_property()",con_nb);
+		simple_query(sql_query.str(),"purge_property()", dch);
     }
   }
 
@@ -684,7 +578,7 @@ void DataBase::purge_property(const char *table,const char *field,const char *ob
  *
  */
 //+------------------------------------------------------------------
-void DataBase::purge_att_property(const char *table,const char *field,const char *object,const char *attribute,const char *name,int con_nb) {
+void DataBase::purge_att_property(const char *table,const char *field,const char *object,const char *attribute,const char *name, DatabaseConnectionHandle& dch) {
 
   TangoSys_MemStream sql_query;
   MYSQL_RES *result;
@@ -697,7 +591,7 @@ void DataBase::purge_att_property(const char *table,const char *field,const char
             << " WHERE " << field << "=\"" << object << "\" AND name=\"" << name
             << "\" AND attribute=\"" << attribute << "\" ORDER by date";
 
-  result = query(sql_query.str(),"purge_att_property()",con_nb);
+  result = query(sql_query.str(),"purge_att_property()", dch);
   int nb_item = mysql_num_rows(result);
 
   if(nb_item>historyDepth) {
@@ -707,7 +601,7 @@ void DataBase::purge_att_property(const char *table,const char *field,const char
 		row2 = mysql_fetch_row(result);
         sql_query.str("");
         sql_query << "DELETE FROM " << table << " WHERE id='" << row2[0] << "'";
-		simple_query(sql_query.str(),"purge_att_property()",con_nb);
+		simple_query(sql_query.str(),"purge_att_property()", dch);
     }
   }
   mysql_free_result(result);
@@ -721,7 +615,7 @@ void DataBase::purge_att_property(const char *table,const char *field,const char
  *
  */
 //+------------------------------------------------------------------
-void DataBase::purge_pipe_property(const char *table,const char *field,const char *object,const char *pipe,const char *name,int con_nb) {
+void DataBase::purge_pipe_property(const char *table,const char *field,const char *object,const char *pipe,const char *name, DatabaseConnectionHandle &dch) {
 
   TangoSys_MemStream sql_query;
   MYSQL_RES *result;
@@ -734,7 +628,7 @@ void DataBase::purge_pipe_property(const char *table,const char *field,const cha
             << " WHERE " << field << "=\"" << object << "\" AND name=\"" << name
             << "\" AND pipe=\"" << pipe << "\" ORDER by date";
 
-  result = query(sql_query.str(),"purge_pipe_property()",con_nb);
+  result = query(sql_query.str(),"purge_pipe_property()", dch);
   int nb_item = mysql_num_rows(result);
 
   if(nb_item>historyDepth) {
@@ -744,174 +638,12 @@ void DataBase::purge_pipe_property(const char *table,const char *field,const cha
 		row2 = mysql_fetch_row(result);
         sql_query.str("");
         sql_query << "DELETE FROM " << table << " WHERE id='" << row2[0] << "'";
-		simple_query(sql_query.str(),"purge_pipe_property()",con_nb);
+		simple_query(sql_query.str(),"purge_pipe_property()", dch);
     }
   }
   mysql_free_result(result);
 }
 
-//+------------------------------------------------------------------
-/**
- *	method:	base_connect()
- *
- *	description:	Basic action to build a Mysql connection
- *
- */
-//+------------------------------------------------------------------
-
-void DataBase::base_connect(int loop)
-{
-
-//
-// Initialise mysql database structure and connect to TANGO database
-//
-
-	conn_pool[loop].db = mysql_init(conn_pool[loop].db);
-	mysql_options(conn_pool[loop].db,MYSQL_READ_DEFAULT_GROUP,"client");
-
-#if   (MYSQL_VERSION_ID > 50000)
-
-	//C. Scafuri: auto reconnection has been off since 5.0.3. From 5.0.13 it is possible to set it as an option
-	// with reconnection enabled DataBase keeps working after timeouts and mysql shutdown/restart
-	if(mysql_get_client_version() >= 50013)
-	{
-		my_bool my_auto_reconnect=1;
-		if (mysql_options(conn_pool[loop].db,MYSQL_OPT_RECONNECT,&my_auto_reconnect) !=0)
-		{
-			ERROR_STREAM << "DataBase: error setting mysql auto reconnection: " << mysql_error(conn_pool[loop].db) << std::endl;
-		}
-		else
-		{
-			WARN_STREAM << "DataBase: set mysql auto reconnect to true" << std::endl;
-		}
-	}
-#endif
-}
-
-//+------------------------------------------------------------------
-/**
- *	method:	create_connection_pool()
- *
- *	description:	Create the MySQL connections pool
- *
- */
-//+------------------------------------------------------------------
-
-void DataBase::create_connection_pool(const char *mysql_user,
-                                      const char *mysql_password,
-                                      const char *mysql_host)
-{
-//
-// Check on provided MySQl user and password
-//
-
-	if (mysql_user != NULL && mysql_password != NULL)
-	{
-		WARN_STREAM << "DataBase::create_connection_pool(): mysql database user =  " << mysql_user
-	           	 << " , password = " << mysql_password << std::endl;
-	}
-
-	const char *host;
-	std::string my_host;
-	std::string ho,port;
-	unsigned int port_num = 0;
-
-	if (mysql_host != NULL)
-	{
-		my_host = mysql_host;
-		WARN_STREAM << "DataBase::create_connection_pool(): mysql host = " << mysql_host << std::endl;
-		std::string::size_type pos = my_host.find(':');
-		if (pos != std::string::npos)
-		{
-			ho = my_host.substr(0,pos);
-			pos++;
-			port = my_host.substr(pos);
-			std::stringstream ss(port);
-			ss >> port_num;
-			if (!ss)
-				port_num = 0;
-			host = ho.c_str();
-		}
-		else
-			host = my_host.c_str();
-		WARN_STREAM << "DataBase::create_connection_pool(): mysql host = " << host << ", port = " << port_num << std::endl;
-	}
-	else
-		host = NULL;
-
-	for (int loop = 0;loop < conn_pool_size;loop++)
-	{
-
-		base_connect(loop);
-
-//
-// Inmplement a retry. On some OS (Ubuntu 10.10), it may happens that MySQl needs some time to start.
-// This retry should cover this case
-// We also have to support case when this server is started while mysql is not ready yet
-// (this has been experienced on Ubuntu after a reboot when the ureadahead cache being invalidated
-// by a package installing file in /etc/init.d
-// Bloody problem!!!
-//
-
-
-		WARN_STREAM << "Going to connect to MySQL for conn. " << loop << std::endl;
-		if (!mysql_real_connect(conn_pool[loop].db, host, mysql_user, mysql_password, mysql_db_name.c_str(), port_num, NULL, CLIENT_MULTI_STATEMENTS | CLIENT_FOUND_ROWS))
-		{
-			if (loop == 0)
-			{
-				int retry = 5;
-				while (retry > 0)
-				{
-					sleep(1);
-					int db_err = mysql_errno(conn_pool[loop].db);
-					WARN_STREAM << "Connection to MySQL failed with error " << db_err << std::endl;
-					if (db_err == CR_CONNECTION_ERROR || db_err == CR_CONN_HOST_ERROR)
-					{
-						mysql_close(conn_pool[loop].db);
-						conn_pool[loop].db = NULL;
-						base_connect(loop);
-					}
-					WARN_STREAM << "Going to retry to connect to MySQL for connection " << loop << std::endl;
-					if (!mysql_real_connect(conn_pool[loop].db, host, mysql_user, mysql_password, mysql_db_name.c_str(), port_num, NULL, CLIENT_MULTI_STATEMENTS | CLIENT_FOUND_ROWS))
-					{
-						WARN_STREAM << "Connection to MySQL (re-try) failed with error " << mysql_errno(conn_pool[loop].db) << std::endl;
-						retry--;
-						if (retry == 0)
-						{
-							WARN_STREAM << "Throw exception because no MySQL connection possible after 5 re-tries" << std::endl;
-							TangoSys_MemStream out_stream;
-							out_stream << "Failed to connect to TANGO database (error = " << mysql_error(conn_pool[loop].db) << ")" << std::ends;
-
-							Tango::Except::throw_exception("CANNOT_CONNECT_MYSQL",
-												out_stream.str(),
-												"DataBase::init_device()");
-						}
-					}
-					else
-					{
-						WARN_STREAM << "MySQL connection succeed after retry" << std::endl;
-						retry = 0;
-					}
-				}
-			}
-			else
-			{
-				WARN_STREAM << "Failed to connect to MySQL for conn. " << loop << ". No re-try in this case" << std::endl;
-				TangoSys_MemStream out_stream;
-				out_stream << "Failed to connect to TANGO database (error = " << mysql_error(conn_pool[loop].db) << ")" << std::ends;
-
-				Tango::Except::throw_exception("CANNOT_CONNECT_MYSQL",
-												out_stream.str(),
-												"DataBase::init_device()");
-			}
-		}
-	}
-
-	mysql_svr_version = mysql_get_server_version(conn_pool[0].db);
-	last_sem_wait = 0;
-
-}
-
 //+------------------------------------------------------------------
 /**
  *	method:	host_port_from_ior()
@@ -1082,38 +814,23 @@ bool DataBase::host_port_from_ior(const char *iorstr,std::string &h_p)
 /**
  *	method:	AutoLock class ctor and dtor
  *
- *	description:	AutoLock is a small helper class which get a
- *					MySQL connection from the pool and which lock
- *					table(s). The exact lock statemen is passed to the
- *					ctor as a parameter
- *					The dtor release the table(s) lock
- *
+ *	description:	AutoLock is a small helper class which get a MySQL
+ *	              connection from the pool and manages the DB transaction.
  */
 //+------------------------------------------------------------------
 
-AutoLock::AutoLock(const char *lock_cmd,DataBase *db):the_db(db)
+AutoLock::AutoLock(DataBase *db)
+  :the_db(db),
+  m_dch(the_db->dcp)
 {
-	con_nb = the_db->get_connection();
-	TangoSys_MemStream sql_query_stream;
-
-	sql_query_stream << lock_cmd;
-	try
-	{
-		the_db->simple_query(sql_query_stream.str(),"AutoLock",con_nb);
-	}
-	catch (...)
-	{
-		the_db->release_connection(con_nb);
-		throw;
-	}
+	const std::string sql_query{"SET autocommit=0;"}; // or START TRANSACTION
+	the_db->simple_query(sql_query,"AutoLock",m_dch);
 }
 
 AutoLock::~AutoLock()
 {
-	TangoSys_MemStream sql_query_stream;
-	sql_query_stream << "UNLOCK TABLES";
-	the_db->simple_query(sql_query_stream.str(),"~AutoLock",con_nb);
-	the_db->release_connection(con_nb);
+	const std::string sql_query{"SET autocommit=1;"}; // or COMMIT
+	the_db->simple_query(sql_query,"~AutoLock",m_dch);
 }
 
 /// Parse a string to return an integer
