@@ -234,4 +234,31 @@ BOOST_FIXTURE_TEST_SUITE(AllTests, Fixture)
     }
   }
 
+  BOOST_AUTO_TEST_CASE(DbPutPropertyWorks)
+  {
+    const std::string objName{"globalObj"};
+    const std::string propName{"propName"};
+    const std::string propValue{"propValue"};
+
+    // write free property
+    {
+      auto in = MakeDeviceDataStringArray({objName, "1", propName, "1", propValue});
+
+      Tango::DeviceData reply;
+      BOOST_CHECK_NO_THROW(reply = dp->command_inout("DbPutProperty", in));
+    }
+
+    // read it back
+    {
+      auto in = MakeDeviceDataStringArray({objName, propName});
+
+      Tango::DeviceData reply;
+      BOOST_CHECK_NO_THROW(reply = dp->command_inout("DbGetProperty", in));
+
+      auto vec = ExtractStringVector(reply);
+      std::vector<std::string> ref = {objName, "1", propName, "1", propValue};
+      BOOST_CHECK_EQUAL_COLLECTIONS(std::begin(vec), std::end(vec), std::begin(ref), std::end(ref));
+    }
+  }
+
 BOOST_AUTO_TEST_SUITE_END() // AllTests
