@@ -7,7 +7,6 @@ SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
 
 source "${SCRIPT_DIR}"/vars.sh
 
-MAKEFLAGS=${MAKEFLAGS:- -j ${NUM_PROCESSORS}}
-TANGO_MAKE_TARGET=${TANGO_MAKE_TARGET:-all}
+TANGO_BUILD_TARGET=${TANGO_BUILD_TARGET:-all}
 
-make -C ${BUILD_DIR} ${MAKEFLAGS} ${TANGO_MAKE_TARGET}
+cmake --build ${BUILD_DIR} --target ${TANGO_BUILD_TARGET}
