@@ -13,7 +13,7 @@ then
 fi
 
 function exit_on_abi_api_breakages() {
-  local reports=compat_reports/libtango/${old_revision}_to_${new_revision}
+  local reports=compat_reports/libtango/old_to_new
   if [ -e ${reports}/abi_affected.txt ]; then
     echo "ABI breakages detected:"
     cat ${reports}/abi_affected.txt | c++filt
@@ -28,6 +28,9 @@ function exit_on_abi_api_breakages() {
 function prepare_old() {
   git worktree remove --force old-branch 2>/dev/null || true
   git worktree add old-branch origin/${CI_TARGET_BRANCH}
+  cd old-branch
+  git submodule update --init
+  cd "${base}"
 }
 
 function prepare_new() {
@@ -37,7 +40,10 @@ function prepare_new() {
   git branch -D ci/abi-api-test-merge 2>/dev/null || true
   git worktree add -b ci/abi-api-test-merge new-branch origin/${CI_TARGET_BRANCH}
   cd new-branch
+  # We initialise submodules after the merge in case they are updated in the MR
+  # branch.
   git merge ${revision} --no-commit
+  git submodule update --init
   cd "${base}"
 }
 
@@ -47,13 +53,14 @@ function generate_info() {
 
   mkdir ${prefix}-branch/build
   cd ${prefix}-branch/build
-  cmake                                    \
-    -Werror=dev                            \
-    -DCMAKE_BUILD_TYPE=Debug               \
-    -Dcppzmq_ROOT=/home/tango        \
-    -DBUILD_TESTING=OFF                    \
-    -DCMAKE_DISABLE_PRECOMPILE_HEADERS=OFF \
-    -DCMAKE_CXX_FLAGS=-gdwarf-4            \
+  cmake                                                 \
+    -Werror=dev                                         \
+    -DCMAKE_BUILD_TYPE=Debug                            \
+    -Dcppzmq_ROOT=/home/tango                           \
+    -DBUILD_TESTING=OFF                                 \
+    -DCMAKE_DISABLE_PRECOMPILE_HEADERS=OFF              \
+    -DTANGO_USE_TELEMETRY="${TANGO_USE_TELEMETRY:-OFF}" \
+    -DCMAKE_CXX_FLAGS=-gdwarf-4                         \
     ..
   cmake --build . --parallel ${NUM_PROCESSORS}
   abi-dumper libtango.so -o ${base}/libtango-${prefix}.dump -lver ${prefix}
