@@ -7,4 +7,4 @@ SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
 
 source "${SCRIPT_DIR}"/vars.sh
 
-make -C ${BUILD_DIR} install
+cmake --build ${BUILD_DIR} --target install
