@@ -55,8 +55,8 @@ void Logger::set_level(Level::Value level)
             std::lock_guard<std::mutex> guard(_appendersMutex);
             if(!_appenders.empty())
             {
-                AppenderMapIterator i = _appenders.begin();
-                AppenderMapIterator e = _appenders.end();
+                auto i = _appenders.begin();
+                auto e = _appenders.end();
                 for(; i != e; ++i)
                 {
                     i->second->level_changed(_level);
@@ -68,22 +68,22 @@ void Logger::set_level(Level::Value level)
 
 void Logger::call_appenders(const LoggingEvent &event)
 {
-    std::vector<std::string> *bad_appenders = 0;
+    std::vector<std::string> *bad_appenders = nullptr;
     { //-- Begin critical section -----------------------------
         std::lock_guard<std::mutex> guard(_appendersMutex);
         if(!_appenders.empty())
         {
-            AppenderMapIterator i = _appenders.begin();
-            AppenderMapIterator e = _appenders.end();
+            auto i = _appenders.begin();
+            auto e = _appenders.end();
             for(; i != e; ++i)
             {
                 if(i->second->append(event) == -1)
                 {
-                    if(!bad_appenders)
+                    if(bad_appenders == nullptr)
                     {
                         bad_appenders = new std::vector<std::string>;
                     }
-                    if(bad_appenders)
+                    if(bad_appenders != nullptr)
                     {
                         bad_appenders->push_back(i->second->get_name());
                     }
@@ -91,7 +91,7 @@ void Logger::call_appenders(const LoggingEvent &event)
             }
         }
     } //-- End critical section ------------------------------
-    if(bad_appenders)
+    if(bad_appenders != nullptr)
     {
         for(unsigned int a = 0; a < bad_appenders->size(); a++)
         {
