@@ -27,8 +27,10 @@
 //
 //
 
-#include <tango/tango.h>
+#include <tango/client/AttributeProxy.h>
 #include <tango/client/eventconsumer.h>
+#include <tango/common/pointer_with_lock.h>
+#include <tango/internal/utils.h>
 
 #include <ctime>
 #include <csignal>
@@ -48,14 +50,12 @@ namespace Tango
 //-----------------------------------------------------------------------------
 
 AttributeProxy::AttributeProxy(std::string &name) :
-    dev_proxy(nullptr),
     ext(new AttributeProxyExt(name))
 {
     real_constructor(name);
 }
 
 AttributeProxy::AttributeProxy(const char *na) :
-    dev_proxy(nullptr),
     ext(new AttributeProxyExt(na))
 {
     std::string name(na);
@@ -1274,6 +1274,24 @@ int AttributeProxy::subscribe_event(EventType event, CallBack *callback)
     return subscribe_event(event, callback, filters, false);
 }
 
+int AttributeProxy::subscribe_event(EventType event, CallBack *callback, EventSubMode event_sub_mode)
+{
+    ApiUtil *au = ApiUtil::instance();
+
+    std::vector<std::string> filters;
+    return au->create_zmq_event_consumer()->subscribe_event(
+        dev_proxy, attr_name, event, callback, filters, event_sub_mode);
+}
+
+int AttributeProxy::subscribe_event(EventType event, int event_queue_size, EventSubMode event_sub_mode)
+{
+    ApiUtil *au = ApiUtil::instance();
+
+    std::vector<std::string> filters;
+    return au->create_zmq_event_consumer()->subscribe_event(
+        dev_proxy, attr_name, event, event_queue_size, filters, event_sub_mode);
+}
+
 //-----------------------------------------------------------------------------
 //
 // AttributeProxy::subscribe_event - Subscribe to an event
@@ -1287,11 +1305,8 @@ int AttributeProxy::subscribe_event(EventType event,
                                     const std::vector<std::string> &filters,
                                     bool stateless)
 {
-    ApiUtil *api_ptr = ApiUtil::instance();
-    if(api_ptr->get_zmq_event_consumer() == nullptr)
-    {
-        api_ptr->create_zmq_event_consumer();
-    }
+    ApiUtil *au = ApiUtil::instance();
+    auto event_sub_mode = detail::get_event_sub_mode_compat(stateless);
 
     int ret;
     try
@@ -1300,21 +1315,17 @@ int AttributeProxy::subscribe_event(EventType event,
         //  see https://github.com/tango-controls/cppTango/pull/423
         std::vector<std::string> non_const_filters;
         non_const_filters.push_back(get_user_defined_name());
-        ret = api_ptr->get_zmq_event_consumer()->subscribe_event(
-            dev_proxy, attr_name, event, callback, non_const_filters, stateless);
+        auto zmq_consumer = au->create_zmq_event_consumer();
+        ret = zmq_consumer->subscribe_event(dev_proxy, attr_name, event, callback, non_const_filters, event_sub_mode);
     }
     catch(DevFailed &e)
     {
         std::string reason(e.errors[0].reason.in());
         if(reason == API_CommandNotFound)
         {
-            if(ApiUtil::instance()->get_notifd_event_consumer() == nullptr)
-            {
-                ApiUtil::instance()->create_notifd_event_consumer();
-            }
+            auto notifd_consumer = au->create_notifd_event_consumer();
 
-            ret = api_ptr->get_notifd_event_consumer()->subscribe_event(
-                dev_proxy, attr_name, event, callback, filters, stateless);
+            ret = notifd_consumer->subscribe_event(dev_proxy, attr_name, event, callback, filters, event_sub_mode);
         }
         else
         {
@@ -1344,29 +1355,24 @@ int AttributeProxy::subscribe_event(EventType event,
                                     const std::vector<std::string> &filters,
                                     bool stateless)
 {
-    ApiUtil *api_ptr = ApiUtil::instance();
-    if(api_ptr->get_zmq_event_consumer() == nullptr)
-    {
-        api_ptr->create_zmq_event_consumer();
-    }
+    ApiUtil *au = ApiUtil::instance();
+    auto event_sub_mode = detail::get_event_sub_mode_compat(stateless);
 
     int ret;
     try
     {
-        ret = api_ptr->get_zmq_event_consumer()->subscribe_event(
-            dev_proxy, attr_name, event, event_queue_size, filters, stateless);
+        auto zmq_consumer = au->create_zmq_event_consumer();
+        ret = zmq_consumer->subscribe_event(dev_proxy, attr_name, event, event_queue_size, filters, event_sub_mode);
     }
     catch(DevFailed &e)
     {
         std::string reason(e.errors[0].reason.in());
         if(reason == API_CommandNotFound)
         {
-            if(api_ptr->get_notifd_event_consumer() == nullptr)
-            {
-                api_ptr->create_notifd_event_consumer();
-            }
-            ret = api_ptr->get_notifd_event_consumer()->subscribe_event(
-                dev_proxy, attr_name, event, event_queue_size, filters, stateless);
+            auto notifd_consumer = au->create_notifd_event_consumer();
+
+            ret = notifd_consumer->subscribe_event(
+                dev_proxy, attr_name, event, event_queue_size, filters, event_sub_mode);
         }
         else
         {
