@@ -29,7 +29,8 @@
 //
 //-================================================================================================================
 
-#include <tango/tango.h>
+#include <tango/client/Database.h>
+#include <tango/internal/parse.h>
 
 using namespace CORBA;
 
@@ -90,8 +91,8 @@ DbServerCache::DbServerCache(Database *db, const std::string &ds_name, const std
             std::string maj_str = rel.substr(0, pos);
             std::string min_str = rel.substr(pos + 1);
 
-            int maj = atoi(maj_str.c_str());
-            int min = atoi(min_str.c_str());
+            int maj = detail::parse_as<int>(maj_str);
+            int min = detail::parse_as<int>(min_str);
 
             proc_release = (maj * 100) + min;
         }
@@ -182,7 +183,7 @@ DbServerCache::DbServerCache(Database *db, const std::string &ds_name, const std
     //
 
     start_idx = stop_idx + 1;
-    class_nb = ::atoi((*data_list)[start_idx + 1]);
+    class_nb = detail::parse_as<int>((*data_list)[start_idx + 1].in());
     stop_idx = stop_idx + 2;
     classes_idx = new ClassEltIdx[class_nb];
 
@@ -218,7 +219,7 @@ DbServerCache::DbServerCache(Database *db, const std::string &ds_name, const std
         //
 
         start_idx = stop_idx + 1;
-        int nb_dev = ::atoi((*data_list)[start_idx + 1]);
+        int nb_dev = detail::parse_as<int>((*data_list)[start_idx + 1].in());
         stop_idx = stop_idx + nb_dev + 2;
 
         classes_idx[cl_loop].dev_list.first_idx = start_idx;
@@ -309,17 +310,43 @@ const DevVarLongStringArray *DbServerCache::import_adm_dev()
         TANGO_THROW_EXCEPTION("aaa", "bbb");
     }
 
-    imp_adm_data.lvalue.length(2);
-    imp_adm_data.svalue.length(5);
+    // We want to return a structure identical to what is returned by DbImportDevice, so
+    // we return 6 strings and 2 longs, following this structure:
+    //   svalue[0] = dev name (domain/family/member)
+    //   svalue[1] = ior
+    //   svalue[2] = version
+    //   svalue[3] = server name (server name/instance name)
+    //   svalue[4] = host
+    //   svalue[5] = class
+    //   lvalue[0] = exported (0/1)
+    //   lvalue[1] = pid
+    // HOWEVER, as of Tango-Database v5.23 (C++), the Database is returning only
+    // strings from the call to DbGetDataForServerCache (which internally builds the
+    // resulting string array with SQL procedures):
+    //   [0] = db server version
+    //   [1] = dev name (@imp_adm.first_idx)
+    //   [2] = ior
+    //   [3] = version
+    //   [4] = server name
+    //   [5] = host
+    //   [6] = exported
+    //   [7] = pid
+    //   [8] = class  (IMPORTANT: not after 'host', @imp_adm.last_idx)
 
-    imp_adm_data.lvalue[0] = ::atoi((*data_list)[imp_adm.first_idx + 5]);
-    imp_adm_data.lvalue[1] = ::atoi((*data_list)[imp_adm.last_idx]);
+    imp_adm_data.lvalue.length(2);
+    imp_adm_data.svalue.length(6);
+
+    imp_adm_data.lvalue[0] = detail::parse_as<CORBA::Long>((*data_list)[imp_adm.first_idx + 5].in());
+    imp_adm_data.lvalue[1] = detail::parse_as<CORBA::Long>((*data_list)[imp_adm.first_idx + 6].in());
 
     for(int loop = 0; loop < 5; loop++)
     {
         imp_adm_data.svalue[loop] = Tango::string_dup((*data_list)[imp_adm.first_idx + loop]);
     }
 
+    // This is the 'class' name that is after everything!
+    imp_adm_data.svalue[5] = Tango::string_dup((*data_list)[imp_adm.last_idx]);
+
     return &imp_adm_data;
 }
 
@@ -347,8 +374,8 @@ const DevVarLongStringArray *DbServerCache::import_notifd_event()
     imp_notifd_event_data.lvalue.length(2);
     imp_notifd_event_data.svalue.length(5);
 
-    imp_notifd_event_data.lvalue[0] = ::atoi((*data_list)[imp_notifd_event.first_idx + 4]);
-    imp_notifd_event_data.lvalue[1] = ::atoi((*data_list)[imp_notifd_event.last_idx]);
+    imp_notifd_event_data.lvalue[0] = detail::parse_as<CORBA::Long>((*data_list)[imp_notifd_event.first_idx + 4].in());
+    imp_notifd_event_data.lvalue[1] = detail::parse_as<CORBA::Long>((*data_list)[imp_notifd_event.last_idx].in());
 
     for(int loop = 0; loop < 4; loop++)
     {
@@ -382,8 +409,8 @@ const DevVarLongStringArray *DbServerCache::import_adm_event()
     imp_adm_event_data.lvalue.length(2);
     imp_adm_event_data.svalue.length(5);
 
-    imp_adm_event_data.lvalue[0] = ::atoi((*data_list)[imp_adm_event.first_idx + 4]);
-    imp_adm_event_data.lvalue[1] = ::atoi((*data_list)[imp_notifd_event.last_idx]);
+    imp_adm_event_data.lvalue[0] = detail::parse_as<CORBA::Long>((*data_list)[imp_adm_event.first_idx + 4].in());
+    imp_adm_event_data.lvalue[1] = detail::parse_as<CORBA::Long>((*data_list)[imp_notifd_event.last_idx].in());
 
     for(int loop = 0; loop < 4; loop++)
     {
@@ -699,14 +726,14 @@ const DevVarStringArray *DbServerCache::get_class_att_property(DevVarStringArray
                     //
 
                     int att_index = classes_idx[cl_idx].class_att_prop.atts_idx[ll];
-                    int nb_prop = ::atoi((*data_list)[att_index + 1]);
+                    int nb_prop = detail::parse_as<int>((*data_list)[att_index + 1].in());
                     int nb_elt = 0;
                     int nb_to_copy = 0;
                     int tmp_idx = att_index + 2;
                     nb_to_copy = 2;
                     for(int k = 0; k < nb_prop; k++)
                     {
-                        nb_elt = ::atoi((*data_list)[tmp_idx + 1]);
+                        nb_elt = detail::parse_as<int>((*data_list)[tmp_idx + 1].in());
                         tmp_idx = tmp_idx + nb_elt + 2;
                         nb_to_copy = nb_to_copy + 2 + nb_elt;
                     }
@@ -788,14 +815,14 @@ const DevVarStringArray *DbServerCache::get_dev_att_property(DevVarStringArray *
                                  (*data_list)[classes_idx[class_ind].devs_idx[dev_ind].dev_att_prop.atts_idx[ll]]) == 0)
                 {
                     int att_index = classes_idx[class_ind].devs_idx[dev_ind].dev_att_prop.atts_idx[ll];
-                    int nb_prop = ::atoi((*data_list)[att_index + 1]);
+                    int nb_prop = detail::parse_as<int>((*data_list)[att_index + 1].in());
                     int nb_elt = 0;
                     int nb_to_copy = 0;
                     int tmp_idx = att_index + 2;
                     nb_to_copy = 2;
                     for(int k = 0; k < nb_prop; k++)
                     {
-                        nb_elt = ::atoi((*data_list)[tmp_idx + 1]);
+                        nb_elt = detail::parse_as<int>((*data_list)[tmp_idx + 1].in());
                         tmp_idx = tmp_idx + nb_elt + 2;
                         nb_to_copy = nb_to_copy + 2 + nb_elt;
                     }
@@ -991,7 +1018,7 @@ DbServerCache::~DbServerCache()
 void DbServerCache::prop_indexes(int &start, int &stop, PropEltIdx &obj, const DevVarStringArray *list)
 {
     start = stop + 1;
-    int nb_prop = atoi((*list)[start + 1]);
+    int nb_prop = detail::parse_as<int>((*list)[start + 1].in());
     if(nb_prop == 0)
     {
         stop = start + 1;
@@ -1008,7 +1035,7 @@ void DbServerCache::prop_indexes(int &start, int &stop, PropEltIdx &obj, const D
     for(int loop = 0; loop < nb_prop; loop++)
     {
         obj.props_idx[id++] = stop + 1;
-        int nb_elt = atoi((*list)[stop + 2]);
+        int nb_elt = detail::parse_as<int>((*list)[stop + 2].in());
         obj.props_idx[id++] = nb_elt;
         stop = stop + nb_elt + 2;
     }
@@ -1041,7 +1068,7 @@ void DbServerCache::prop_indexes(int &start, int &stop, PropEltIdx &obj, const D
 void DbServerCache::prop_att_indexes(int &start, int &stop, AttPropEltIdx &obj, const DevVarStringArray *list)
 {
     start = stop + 1;
-    int nb_att = atoi((*list)[start + 1]);
+    int nb_att = detail::parse_as<int>((*list)[start + 1].in());
     if(nb_att == 0)
     {
         stop = start + 1;
@@ -1060,12 +1087,12 @@ void DbServerCache::prop_att_indexes(int &start, int &stop, AttPropEltIdx &obj,
     for(int ll = 0; ll < nb_att; ll++)
     {
         obj.atts_idx[id++] = stop;
-        int nb_prop = atoi((*list)[stop + 1]);
+        int nb_prop = detail::parse_as<int>((*list)[stop + 1].in());
         stop = stop + 2;
 
         for(int loop = 0; loop < nb_prop; loop++)
         {
-            int nb_elt = atoi((*list)[stop + 1]);
+            int nb_elt = detail::parse_as<int>((*list)[stop + 1].in());
             stop = stop + nb_elt + 2;
         }
         if(ll == (nb_att - 1))
@@ -1100,7 +1127,7 @@ void DbServerCache::prop_att_indexes(int &start, int &stop, AttPropEltIdx &obj,
 void DbServerCache::prop_pipe_indexes(int &start, int &stop, AttPropEltIdx &obj, const DevVarStringArray *list)
 {
     start = stop + 1;
-    int nb_att = atoi((*list)[start + 1]);
+    int nb_att = detail::parse_as<int>((*list)[start + 1].in());
     if(nb_att == 0)
     {
         stop = start + 1;
@@ -1119,12 +1146,12 @@ void DbServerCache::prop_pipe_indexes(int &start, int &stop, AttPropEltIdx &obj,
     for(int ll = 0; ll < nb_att; ll++)
     {
         obj.atts_idx[id++] = stop;
-        int nb_prop = atoi((*list)[stop + 1]);
+        int nb_prop = detail::parse_as<int>((*list)[stop + 1].in());
         stop = stop + 2;
 
         for(int loop = 0; loop < nb_prop; loop++)
         {
-            int nb_elt = atoi((*list)[stop + 1]);
+            int nb_elt = detail::parse_as<int>((*list)[stop + 1].in());
             stop = stop + nb_elt + 2;
         }
         if(ll == (nb_att - 1))
@@ -1449,8 +1476,8 @@ const DevVarLongStringArray *DbServerCache::import_tac_dev(const std::string &ta
     imp_tac_data.lvalue.length(2);
     imp_tac_data.svalue.length(5);
 
-    imp_tac_data.lvalue[0] = ::atoi((*data_list)[imp_tac.first_idx + 5]);
-    imp_tac_data.lvalue[1] = ::atoi((*data_list)[imp_tac.last_idx - 1]);
+    imp_tac_data.lvalue[0] = detail::parse_as<CORBA::Long>((*data_list)[imp_tac.first_idx + 5].in());
+    imp_tac_data.lvalue[1] = detail::parse_as<CORBA::Long>((*data_list)[imp_tac.last_idx - 1].in());
 
     for(int loop = 0; loop < 5; loop++)
     {
@@ -1519,14 +1546,14 @@ const DevVarStringArray *DbServerCache::get_class_pipe_property(DevVarStringArra
                     //
 
                     int pipe_index = classes_idx[cl_idx].class_pipe_prop.atts_idx[ll];
-                    int nb_prop = ::atoi((*data_list)[pipe_index + 1]);
+                    int nb_prop = detail::parse_as<int>((*data_list)[pipe_index + 1].in());
                     int nb_elt = 0;
                     int nb_to_copy = 0;
                     int tmp_idx = pipe_index + 2;
                     nb_to_copy = 2;
                     for(int k = 0; k < nb_prop; k++)
                     {
-                        nb_elt = ::atoi((*data_list)[tmp_idx + 1]);
+                        nb_elt = detail::parse_as<int>((*data_list)[tmp_idx + 1].in());
                         tmp_idx = tmp_idx + nb_elt + 2;
                         nb_to_copy = nb_to_copy + 2 + nb_elt;
                     }
@@ -1622,14 +1649,14 @@ const DevVarStringArray *DbServerCache::get_dev_pipe_property(DevVarStringArray
                    0)
                 {
                     int pipe_index = classes_idx[class_ind].devs_idx[dev_ind].dev_pipe_prop.atts_idx[ll];
-                    int nb_prop = ::atoi((*data_list)[pipe_index + 1]);
+                    int nb_prop = detail::parse_as<int>((*data_list)[pipe_index + 1].in());
                     int nb_elt = 0;
                     int nb_to_copy = 0;
                     int tmp_idx = pipe_index + 2;
                     nb_to_copy = 2;
                     for(int k = 0; k < nb_prop; k++)
                     {
-                        nb_elt = ::atoi((*data_list)[tmp_idx + 1]);
+                        nb_elt = detail::parse_as<int>((*data_list)[tmp_idx + 1].in());
                         tmp_idx = tmp_idx + nb_elt + 2;
                         nb_to_copy = nb_to_copy + 2 + nb_elt;
                     }
