@@ -26,11 +26,16 @@
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 //
 
-#include <tango/tango.h>
+#include <tango/client/DbDatum.h>
+
+#include <tango/server/tango_config.h>
+#include <tango/client/apiexcept.h>
 
 #include <iomanip>
 #include <limits>
-#include <memory>
+#include <algorithm>
+#include <iostream>
+#include <ostream>
 
 using namespace CORBA;
 
@@ -102,6 +107,11 @@ DbDatum::DbDatum(const DbDatum &source) :
 
 DbDatum &DbDatum::operator=(const DbDatum &rval)
 {
+    if(this == &rval)
+    {
+        return *this;
+    }
+
     name = rval.name;
     value_string = rval.value_string;
     value_type = rval.value_type;
