@@ -26,7 +26,7 @@
 //
 //===================================================================================================================
 
-#include <tango/tango.h>
+#include <tango/client/DbDevice.h>
 
 using namespace CORBA;
 
