@@ -27,7 +27,10 @@
 //
 //
 
-#include <tango/tango.h>
+#include <tango/client/DeviceData.h>
+#include <tango/client/ApiUtil.h>
+#include <tango/client/apiexcept.h>
+#include <tango/internal/utils.h>
 
 #include <memory>
 
@@ -174,9 +177,8 @@ bool DeviceData::is_empty()
 bool DeviceData::any_is_null() const
 {
     ext->ext_state.reset(isempty_flag);
-    CORBA::TypeCode_ptr tc;
 
-    tc = any->type();
+    CORBA::TypeCode_var tc = any->type();
     if(tc->equal(CORBA::_tc_null))
     {
         ext->ext_state.set(isempty_flag);
@@ -187,7 +189,6 @@ bool DeviceData::any_is_null() const
         }
         return (true);
     }
-    CORBA::release(tc);
 
     return (false);
 }
@@ -208,12 +209,11 @@ int DeviceData::get_type()
     }
     else
     {
-        CORBA::TypeCode_ptr tc;
         CORBA::TypeCode_var tc_al;
         CORBA::TypeCode_var tc_seq;
         CORBA::TypeCode_var tc_field;
 
-        tc = any->type();
+        CORBA::TypeCode_var tc = any->type();
         switch(tc->kind())
         {
         case CORBA::tk_boolean:
@@ -356,8 +356,6 @@ int DeviceData::get_type()
             desc << "'this->any' with unexpected kind '" << tc->kind() << "'.";
             TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
         }
-
-        CORBA::release(tc);
     }
 
     return data_type;
@@ -2229,226 +2227,7 @@ std::ostream &operator<<(std::ostream &o_str, const DeviceData &dd)
     }
     else
     {
-        CORBA::TypeCode_ptr tc;
-        CORBA::TypeCode_var tc_al;
-        CORBA::TypeCode_var tc_seq;
-        CORBA::TypeCode_var tc_field;
-
-        tc = dd.any->type();
-        switch(tc->kind())
-        {
-        case CORBA::tk_boolean:
-            bool bo_tmp;
-            dd.any >>= CORBA::Any::to_boolean(bo_tmp);
-            if(bo_tmp)
-            {
-                o_str << "true";
-            }
-            else
-            {
-                o_str << "false";
-            }
-            break;
-
-        case CORBA::tk_short:
-            short tmp;
-            dd.any >>= tmp;
-            o_str << tmp;
-            break;
-
-        case CORBA::tk_long:
-            Tango::DevLong l_tmp;
-            dd.any >>= l_tmp;
-            o_str << l_tmp;
-            break;
-
-        case CORBA::tk_longlong:
-            Tango::DevLong64 ll_tmp;
-            dd.any >>= ll_tmp;
-            o_str << ll_tmp;
-            break;
-
-        case CORBA::tk_float:
-            float f_tmp;
-            dd.any >>= f_tmp;
-            o_str << f_tmp;
-            break;
-
-        case CORBA::tk_double:
-            double db_tmp;
-            dd.any >>= db_tmp;
-            o_str << db_tmp;
-            break;
-
-        case CORBA::tk_ushort:
-            unsigned short us_tmp;
-            dd.any >>= us_tmp;
-            o_str << us_tmp;
-            break;
-
-        case CORBA::tk_ulong:
-            Tango::DevULong ul_tmp;
-            dd.any >>= ul_tmp;
-            o_str << ul_tmp;
-            break;
-
-        case CORBA::tk_ulonglong:
-            Tango::DevULong64 ull_tmp;
-            dd.any >>= ull_tmp;
-            o_str << ull_tmp;
-            break;
-
-        case CORBA::tk_string:
-            const char *str_tmp;
-            dd.any >>= str_tmp;
-            o_str << str_tmp;
-            break;
-
-        case CORBA::tk_alias:
-            tc_al = tc->content_type();
-            tc_seq = tc_al->content_type();
-            switch(tc_seq->kind())
-            {
-            case CORBA::tk_octet:
-                Tango::DevVarCharArray *ch_arr;
-                dd.any.in() >>= ch_arr;
-                o_str << *ch_arr;
-                break;
-
-            case CORBA::tk_boolean:
-                Tango::DevVarBooleanArray *bl_arr;
-                dd.any.in() >>= bl_arr;
-                o_str << *bl_arr;
-                break;
-
-            case CORBA::tk_short:
-                Tango::DevVarShortArray *sh_arr;
-                dd.any.in() >>= sh_arr;
-                o_str << *sh_arr;
-                break;
-
-            case CORBA::tk_long:
-                Tango::DevVarLongArray *lg_arr;
-                dd.any.in() >>= lg_arr;
-                o_str << *lg_arr;
-                break;
-
-            case CORBA::tk_longlong:
-                Tango::DevVarLong64Array *llg_arr;
-                dd.any.in() >>= llg_arr;
-                o_str << *llg_arr;
-                break;
-
-            case CORBA::tk_float:
-                Tango::DevVarFloatArray *fl_arr;
-                dd.any.in() >>= fl_arr;
-                o_str << *fl_arr;
-                break;
-
-            case CORBA::tk_double:
-                Tango::DevVarDoubleArray *db_arr;
-                dd.any.in() >>= db_arr;
-                o_str << *db_arr;
-                break;
-
-            case CORBA::tk_ushort:
-                Tango::DevVarUShortArray *us_arr;
-                dd.any.in() >>= us_arr;
-                o_str << *us_arr;
-                break;
-
-            case CORBA::tk_ulong:
-                Tango::DevVarULongArray *ul_arr;
-                dd.any.in() >>= ul_arr;
-                o_str << *ul_arr;
-                break;
-
-            case CORBA::tk_ulonglong:
-                Tango::DevVarULong64Array *ull_arr;
-                dd.any.in() >>= ull_arr;
-                o_str << *ull_arr;
-                break;
-
-            case CORBA::tk_string:
-                Tango::DevVarStringArray *str_arr;
-                dd.any.in() >>= str_arr;
-                o_str << *str_arr;
-                break;
-
-            default:
-                TangoSys_OMemStream desc;
-                desc << "'dd.any' with unexpected sequence kind '" << tc_seq->kind() << "'.";
-                TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
-            }
-            break;
-
-        case CORBA::tk_struct:
-            tc_field = tc->member_type(0);
-            tc_al = tc_field->content_type();
-            switch(tc_al->kind())
-            {
-            case CORBA::tk_sequence:
-                tc_seq = tc_al->content_type();
-                switch(tc_seq->kind())
-                {
-                case CORBA::tk_long:
-                    Tango::DevVarLongStringArray *lgstr_arr;
-                    dd.any.in() >>= lgstr_arr;
-                    o_str << lgstr_arr->lvalue << std::endl;
-                    o_str << lgstr_arr->svalue;
-                    break;
-
-                case CORBA::tk_double:
-                    Tango::DevVarDoubleStringArray *dbstr_arr;
-                    dd.any.in() >>= dbstr_arr;
-                    o_str << dbstr_arr->dvalue << std::endl;
-                    o_str << dbstr_arr->svalue;
-                    break;
-
-                default:
-                    TangoSys_OMemStream desc;
-                    desc << "'dd.any' with unexpected struct field sequence kind '" << tc_seq->kind() << "'.";
-                    TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
-                }
-                break;
-
-            case CORBA::tk_string:
-                Tango::DevEncoded *enc;
-                dd.any.in() >>= enc;
-                o_str << "Encoding string: " << enc->encoded_format << std::endl;
-                {
-                    long nb_data_elt = enc->encoded_data.length();
-                    for(long i = 0; i < nb_data_elt; i++)
-                    {
-                        o_str << "Data element number [" << i << "] = " << (int) enc->encoded_data[i];
-                        if(i < (nb_data_elt - 1))
-                        {
-                            o_str << '\n';
-                        }
-                    }
-                }
-                break;
-
-            default:
-                TangoSys_OMemStream desc;
-                desc << "'dd.any' with unexpected struct field alias kind '" << tc_al->kind() << "'.";
-                TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
-            }
-            break;
-
-        case CORBA::tk_enum:
-            Tango::DevState tmp_state;
-            dd.any.in() >>= tmp_state;
-            o_str << Tango::DevStateName[tmp_state];
-            break;
-
-        default:
-            TangoSys_OMemStream desc;
-            desc << "'dd.any' with unexpected kind '" << tc->kind() << "'.";
-            TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, desc.str().c_str());
-        }
-
-        CORBA::release(tc);
+        detail::stringify_any(o_str, dd.any);
     }
 
     return o_str;
