@@ -29,8 +29,26 @@
 //
 //===================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/client/event.h>
+#include <tango/server/logging.h>
+
+#include <iostream>
+
+namespace
+{
+
+template <typename T>
+void clear_vector(T &vec)
+{
+    for(auto elem : vec)
+    {
+        delete elem;
+    }
+
+    vec.clear();
+}
+
+} // anonymous namespace
 
 namespace Tango
 {
@@ -96,47 +114,11 @@ EventQueue::~EventQueue()
 
     omni_mutex_lock l(modification_mutex);
 
-    long nb = nb_elt;
-
-    //
-    // check whether the events are not attribute configuration events
-    //
-
-    if(event_buffer.size() > 0)
-    {
-        for(long i = 0; i < nb; i++)
-        {
-            delete event_buffer[i];
-        }
-
-        event_buffer.clear();
-    }
-
-    //
-    // for attribute configuration events
-    //
-
-    else
-    {
-        if(conf_event_buffer.size() > 0)
-        {
-            for(long i = 0; i < nb; i++)
-            {
-                delete conf_event_buffer[i];
-            }
-
-            conf_event_buffer.clear();
-        }
-        else
-        {
-            for(long i = 0; i < nb; i++)
-            {
-                delete ready_event_buffer[i];
-            }
-
-            ready_event_buffer.clear();
-        }
-    }
+    clear_vector(event_buffer);
+    clear_vector(conf_event_buffer);
+    clear_vector(ready_event_buffer);
+    clear_vector(dev_inter_event_buffer);
+    clear_vector(pipe_event_buffer);
 }
 
 //+-----------------------------------------------------------------------------------------------------------------
@@ -155,42 +137,7 @@ EventQueue::~EventQueue()
 
 void EventQueue::insert_event(EventData *new_event)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::insert_event" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Insert data in the event queue
-    //
-
-    // when no maximum queue size is given, just add the new event
-    if(max_elt == 0)
-    {
-        event_buffer.push_back(new_event);
-    }
-
-    // when a maximum size is given, handle a circular buffer
-    else
-    {
-        // allocate ring buffer when not yet done
-        if(event_buffer.empty())
-        {
-            event_buffer.resize(max_elt, nullptr);
-        }
-
-        // free data when necessary
-        if(event_buffer[insert_elt] != nullptr)
-        {
-            delete event_buffer[insert_elt];
-        }
-
-        // insert the event data pointer into the queue
-        event_buffer[insert_elt] = new_event;
-    }
-
-    // Manage insert and read indexes
-    inc_indexes();
+    insert_event_helper(new_event, event_buffer);
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -209,42 +156,7 @@ void EventQueue::insert_event(EventData *new_event)
 
 void EventQueue::insert_event(AttrConfEventData *new_event)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::insert_event" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Insert data in the event queue
-    //
-
-    // when no maximum queue size is given, just add the new event
-    if(max_elt == 0)
-    {
-        conf_event_buffer.push_back(new_event);
-    }
-
-    // when a maximum size s given, handle a circular buffer
-    else
-    {
-        // allocate ring buffer when not yet done
-        if(conf_event_buffer.empty())
-        {
-            conf_event_buffer.resize(max_elt, nullptr);
-        }
-
-        // free data when necessary
-        if(conf_event_buffer[insert_elt] != nullptr)
-        {
-            delete conf_event_buffer[insert_elt];
-        }
-
-        // insert the event data pointer into the queue
-        conf_event_buffer[insert_elt] = new_event;
-    }
-
-    // Manage insert and read indexes
-    inc_indexes();
+    insert_event_helper(new_event, conf_event_buffer);
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -263,42 +175,7 @@ void EventQueue::insert_event(AttrConfEventData *new_event)
 
 void EventQueue::insert_event(DataReadyEventData *new_event)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::insert_event" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Insert data in the event queue
-    //
-
-    // when no maximum queue size is given, just add the new event
-    if(max_elt == 0)
-    {
-        ready_event_buffer.push_back(new_event);
-    }
-
-    // when a maximum size s given, handle a circular buffer
-    else
-    {
-        // allocate ring buffer when not yet done
-        if(ready_event_buffer.empty())
-        {
-            ready_event_buffer.resize(max_elt, nullptr);
-        }
-
-        // free data when necessary
-        if(ready_event_buffer[insert_elt] != nullptr)
-        {
-            delete ready_event_buffer[insert_elt];
-        }
-
-        // insert the event data pointer into the queue
-        ready_event_buffer[insert_elt] = new_event;
-    }
-
-    // Manage insert and read indexes
-    inc_indexes();
+    insert_event_helper(new_event, ready_event_buffer);
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -317,63 +194,7 @@ void EventQueue::insert_event(DataReadyEventData *new_event)
 
 void EventQueue::insert_event(DevIntrChangeEventData *new_event)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::insert_event" << std::endl;
-
-    //
-    // lock the event queue
-    //
-
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Insert data in the event queue
-    //
-
-    //
-    // when no maximum queue size is given, just add the new event
-    //
-
-    if(max_elt == 0)
-    {
-        dev_inter_event_buffer.push_back(new_event);
-    }
-
-    //
-    // when a maximum size s given, handle a circular buffer
-    //
-
-    else
-    {
-        //
-        // allocate ring buffer when not yet done
-        //
-
-        if(dev_inter_event_buffer.empty())
-        {
-            dev_inter_event_buffer.resize(max_elt, nullptr);
-        }
-
-        //
-        // free data when necessary
-        //
-
-        if(dev_inter_event_buffer[insert_elt] != nullptr)
-        {
-            delete dev_inter_event_buffer[insert_elt];
-        }
-
-        //
-        // insert the event data pointer into the queue
-        //
-
-        dev_inter_event_buffer[insert_elt] = new_event;
-    }
-
-    //
-    // Manage insert and read indexes
-    //
-
-    inc_indexes();
+    insert_event_helper(new_event, dev_inter_event_buffer);
 }
 
 //+-----------------------------------------------------------------------------------------------------------------
@@ -392,42 +213,7 @@ void EventQueue::insert_event(DevIntrChangeEventData *new_event)
 
 void EventQueue::insert_event(PipeEventData *new_event)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::insert_event" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Insert data in the event queue
-    //
-
-    // when no maximum queue size is given, just add the new event
-    if(max_elt == 0)
-    {
-        pipe_event_buffer.push_back(new_event);
-    }
-
-    // when a maximum size is given, handle a circular buffer
-    else
-    {
-        // allocate ring buffer when not yet done
-        if(pipe_event_buffer.empty())
-        {
-            pipe_event_buffer.resize(max_elt, nullptr);
-        }
-
-        // free data when necessary
-        if(pipe_event_buffer[insert_elt] != nullptr)
-        {
-            delete pipe_event_buffer[insert_elt];
-        }
-
-        // insert the event data pointer into the queue
-        pipe_event_buffer[insert_elt] = new_event;
-    }
-
-    // Manage insert and read indexes
-    inc_indexes();
+    insert_event_helper(new_event, pipe_event_buffer);
 }
 
 //+------------------------------------------------------------------------------------------------------------------
@@ -534,24 +320,44 @@ TimeVal EventQueue::get_last_event_date()
                 }
                 else
                 {
-                    return conf_event_buffer[insert_elt - 1]->get_date();
+                    return ready_event_buffer[insert_elt - 1]->get_date();
                 }
             }
             else
             {
-                TangoSys_OMemStream o;
-                o << "No new events available!\n";
-                o << "Cannot return any event date" << std::ends;
-                TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_EventQueues, o.str());
+                if(!dev_inter_event_buffer.empty())
+                {
+                    if(insert_elt == 0)
+                    {
+                        return dev_inter_event_buffer[max_elt - 1]->get_date();
+                    }
+                    else
+                    {
+                        return dev_inter_event_buffer[insert_elt - 1]->get_date();
+                    }
+                }
+                else
+                {
+                    if(!pipe_event_buffer.empty())
+                    {
+                        if(insert_elt == 0)
+                        {
+                            return pipe_event_buffer[max_elt - 1]->get_date();
+                        }
+                        else
+                        {
+                            return pipe_event_buffer[insert_elt - 1]->get_date();
+                        }
+                    }
+
+                    TangoSys_OMemStream o;
+                    o << "No new events available!\n";
+                    o << "Cannot return any event date" << std::ends;
+                    TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_EventQueues, o.str());
+                }
             }
         }
     }
-
-    // Should never reach here. To make compiler happy
-
-    struct TimeVal tv;
-    tv.tv_sec = tv.tv_usec = tv.tv_nsec = 0;
-    return tv;
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -572,55 +378,7 @@ TimeVal EventQueue::get_last_event_date()
 
 void EventQueue::get_events(EventDataList &event_list)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Set index to read the ring buffer and to initialise the vector
-    // of pointers to return.
-    // In the returned sequence , indice 0 is the oldest data
-    //
-    long index = insert_elt;
-    if(index == 0)
-    {
-        index = max_elt;
-    }
-    index--;
-
-    long seq_index = nb_elt - 1;
-
-    // prepare the vector to be returned
-
-    event_list.clear();
-    event_list.resize(nb_elt);
-
-    //
-    // Read buffer
-    //
-    for(long i = 0; i < nb_elt; i++)
-    {
-        event_list[seq_index] = event_buffer[index];
-
-        // we do not want to free the event data when cleaning-up
-        // the vector
-        event_buffer[index] = nullptr;
-
-        if(index == 0)
-        {
-            index = max_elt;
-        }
-        index--;
-        seq_index--;
-    }
-
-    // empty the event queue now
-    event_buffer.clear();
-    insert_elt = 0;
-    nb_elt = 0;
-
-    TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
+    get_events_helper(event_list, event_buffer);
 }
 
 //--------------------------------------------------------------------------------------------------------------------
@@ -641,55 +399,7 @@ void EventQueue::get_events(EventDataList &event_list)
 
 void EventQueue::get_events(AttrConfEventDataList &event_list)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Set index to read the ring buffer and to initialise the vector
-    // of pointers to return.
-    // In the returned sequence , indice 0 is the oldest data
-    //
-    long index = insert_elt;
-    if(index == 0)
-    {
-        index = max_elt;
-    }
-    index--;
-
-    long seq_index = nb_elt - 1;
-
-    // prepare the vector to be returned
-
-    event_list.clear();
-    event_list.resize(nb_elt);
-
-    //
-    // Read buffer
-    //
-    for(long i = 0; i < nb_elt; i++)
-    {
-        event_list[seq_index] = conf_event_buffer[index];
-
-        // we do not want to free the event data when cleaning-up
-        // the vector
-        conf_event_buffer[index] = nullptr;
-
-        if(index == 0)
-        {
-            index = max_elt;
-        }
-        index--;
-        seq_index--;
-    }
-
-    // empty the event queue now
-    conf_event_buffer.clear();
-    insert_elt = 0;
-    nb_elt = 0;
-
-    TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
+    get_events_helper(event_list, conf_event_buffer);
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -710,55 +420,7 @@ void EventQueue::get_events(AttrConfEventDataList &event_list)
 
 void EventQueue::get_events(DataReadyEventDataList &event_list)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
-
-    // lock the event queue
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Set index to read the ring buffer and to initialise the vector
-    // of pointers to return.
-    // In the returned sequence , indice 0 is the oldest data
-    //
-    long index = insert_elt;
-    if(index == 0)
-    {
-        index = max_elt;
-    }
-    index--;
-
-    long seq_index = nb_elt - 1;
-
-    // prepare the vector to be returned
-
-    event_list.clear();
-    event_list.resize(nb_elt);
-
-    //
-    // Read buffer
-    //
-    for(long i = 0; i < nb_elt; i++)
-    {
-        event_list[seq_index] = ready_event_buffer[index];
-
-        // we do not want to free the event data when cleaning-up
-        // the vector
-        ready_event_buffer[index] = nullptr;
-
-        if(index == 0)
-        {
-            index = max_elt;
-        }
-        index--;
-        seq_index--;
-    }
-
-    // empty the event queue now
-    ready_event_buffer.clear();
-    insert_elt = 0;
-    nb_elt = 0;
-
-    TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
+    get_events_helper(event_list, ready_event_buffer);
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -779,67 +441,7 @@ void EventQueue::get_events(DataReadyEventDataList &event_list)
 
 void EventQueue::get_events(DevIntrChangeEventDataList &event_list)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
-
-    //
-    // lock the event queue
-    //
-
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Set index to read the ring buffer and to initialise the vector of pointers to return.
-    // In the returned sequence , indice 0 is the oldest data
-    //
-
-    long index = insert_elt;
-    if(index == 0)
-    {
-        index = max_elt;
-    }
-    index--;
-
-    long seq_index = nb_elt - 1;
-
-    //
-    // prepare the vector to be returned
-    //
-
-    event_list.clear();
-    event_list.resize(nb_elt);
-
-    //
-    // Read buffer
-    //
-
-    for(long i = 0; i < nb_elt; i++)
-    {
-        event_list[seq_index] = dev_inter_event_buffer[index];
-
-        //
-        // we do not want to free the event data when cleaning-up
-        // the vector
-        //
-
-        dev_inter_event_buffer[index] = nullptr;
-
-        if(index == 0)
-        {
-            index = max_elt;
-        }
-        index--;
-        seq_index--;
-    }
-
-    //
-    // empty the event queue now
-    //
-
-    dev_inter_event_buffer.clear();
-    insert_elt = 0;
-    nb_elt = 0;
-
-    TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
+    get_events_helper(event_list, dev_inter_event_buffer);
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -860,67 +462,7 @@ void EventQueue::get_events(DevIntrChangeEventDataList &event_list)
 
 void EventQueue::get_events(PipeEventDataList &event_list)
 {
-    TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
-
-    //
-    // lock the event queue
-    //
-
-    omni_mutex_lock l(modification_mutex);
-
-    //
-    // Set index to read the ring buffer and to initialise the vector of pointers to return.
-    // In the returned sequence , indice 0 is the oldest data
-    //
-
-    long index = insert_elt;
-    if(index == 0)
-    {
-        index = max_elt;
-    }
-    index--;
-
-    long seq_index = nb_elt - 1;
-
-    //
-    // prepare the vector to be returned
-    //
-
-    event_list.clear();
-    event_list.resize(nb_elt);
-
-    //
-    // Read buffer
-    //
-
-    for(long i = 0; i < nb_elt; i++)
-    {
-        event_list[seq_index] = pipe_event_buffer[index];
-
-        //
-        // we do not want to free the event data when cleaning-up
-        // the vector
-        //
-
-        pipe_event_buffer[index] = nullptr;
-
-        if(index == 0)
-        {
-            index = max_elt;
-        }
-        index--;
-        seq_index--;
-    }
-
-    //
-    // empty the event queue now
-    //
-
-    pipe_event_buffer.clear();
-    insert_elt = 0;
-    nb_elt = 0;
-
-    TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << event_list.size() << std::endl;
+    get_events_helper(event_list, pipe_event_buffer);
 }
 
 //-------------------------------------------------------------------------------------------------------------------
@@ -1081,4 +623,99 @@ void EventQueue::get_events(CallBack *cb)
     }
 }
 
+template <typename T, typename U>
+void EventQueue::insert_event_helper(T elem, U &vec)
+{
+    TANGO_LOG_DEBUG << "Entering EventQueue::insert_event" << std::endl;
+
+    // lock the event queue
+    omni_mutex_lock l(modification_mutex);
+
+    //
+    // Insert data in the event queue
+    //
+
+    // when no maximum queue size is given, just add the new event
+    if(max_elt == 0)
+    {
+        vec.push_back(elem);
+    }
+
+    // when a maximum size is given, handle a circular buffer
+    else
+    {
+        // allocate ring buffer when not yet done
+        if(vec.empty())
+        {
+            vec.resize(max_elt, nullptr);
+        }
+
+        // free data when necessary
+        if(vec[insert_elt] != nullptr)
+        {
+            delete vec[insert_elt];
+        }
+
+        // insert the event data pointer into the queue
+        vec[insert_elt] = elem;
+    }
+
+    // Manage insert and read indexes
+    inc_indexes();
+}
+
+template <typename T, typename U>
+void EventQueue::get_events_helper(T &output, U &vec)
+{
+    TANGO_LOG_DEBUG << "Entering EventQueue::get_events" << std::endl;
+
+    // lock the event queue
+    omni_mutex_lock l(modification_mutex);
+
+    //
+    // Set index to read the ring buffer and to initialise the vector
+    // of pointers to return.
+    // In the returned sequence , indice 0 is the oldest data
+    //
+    long index = insert_elt;
+    if(index == 0)
+    {
+        index = max_elt;
+    }
+    index--;
+
+    long seq_index = nb_elt - 1;
+
+    // prepare the vector to be returned
+
+    output.clear();
+    output.resize(nb_elt);
+
+    //
+    // Read buffer
+    //
+    for(long i = 0; i < nb_elt; i++)
+    {
+        output[seq_index] = vec[index];
+
+        // we do not want to free the event data when cleaning-up
+        // the vector
+        vec[index] = nullptr;
+
+        if(index == 0)
+        {
+            index = max_elt;
+        }
+        index--;
+        seq_index--;
+    }
+
+    // empty the event queue now
+    vec.clear();
+    insert_elt = 0;
+    nb_elt = 0;
+
+    TANGO_LOG_DEBUG << "EventQueue::get_events() : size = " << vec.size() << std::endl;
+}
+
 } // namespace Tango
