@@ -18,11 +18,18 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with Tango.  If not, see <http://www.gnu.org/licenses/>.
 
+#include <tango/client/filedatabase.h>
+#include <tango/common/utils/type_info.h>
+#include <tango/common/tango_const.h>
+#include <tango/common/tango_type_traits.h>
+#include <tango/server/logging.h>
+#include <tango/server/except.h>
+#include <tango/client/apiexcept.h>
+#include <tango/internal/parse.h>
+
 #include <iostream>
 #include <numeric>
-#include <tango/tango.h>
-#include <tango/common/utils/type_info.h>
-
+#include <algorithm>
 // DbInfo                              done
 // DbImportDevice
 // DbExportDevice
@@ -72,20 +79,9 @@
 
 using namespace std;
 
-namespace Tango
+namespace
 {
 
-const char *FileDatabase::lexical_word_null = "NULL";
-const char *FileDatabase::lexical_word_number = "NUMBER";
-const char *FileDatabase::lexical_word_string = "STRING";
-const char *FileDatabase::lexical_word_coma = "COMA";
-const char *FileDatabase::lexical_word_colon = "COLON";
-const char *FileDatabase::lexical_word_slash = "SLASH";
-const char *FileDatabase::lexical_word_backslash = "BackSLASH";
-const char *FileDatabase::lexical_word_arrow = "->";
-int FileDatabase::ReadBufferSize = 4069;
-int FileDatabase::MaxWordLength = 256;
-
 char chartolower(const char c)
 {
     if(c >= 'A' && c <= 'Z')
@@ -117,7 +113,7 @@ bool equalsIgnoreCase(const string &s1, const string &s2)
     return ret;
 }
 
-t_device *search_device(t_server &s, string &name)
+Tango::t_device *search_device(Tango::t_server &s, string &name)
 {
     for(unsigned int j = 0; j < s.devices.size(); j++)
     {
@@ -130,7 +126,7 @@ t_device *search_device(t_server &s, string &name)
     return nullptr;
 }
 
-t_tango_class *search_class(t_server &s, string &name)
+Tango::t_tango_class *search_class(Tango::t_server &s, string &name)
 {
     for(unsigned int i = 0; i < s.classes.size(); i++)
     {
@@ -142,7 +138,7 @@ t_tango_class *search_class(t_server &s, string &name)
     return nullptr;
 }
 
-t_free_object *search_free_object(t_server &s, string &name)
+Tango::t_free_object *search_free_object(Tango::t_server &s, string &name)
 {
     for(unsigned int i = 0; i < s.free_objects.size(); i++)
     {
@@ -154,7 +150,7 @@ t_free_object *search_free_object(t_server &s, string &name)
     return nullptr;
 }
 
-t_attribute_property *search_dev_attr_prop(t_device *d, const string &name)
+Tango::t_attribute_property *search_dev_attr_prop(Tango::t_device *d, const string &name)
 {
     for(unsigned int i = 0; i < d->attribute_properties.size(); i++)
     {
@@ -166,7 +162,7 @@ t_attribute_property *search_dev_attr_prop(t_device *d, const string &name)
     return nullptr;
 }
 
-t_attribute_property *search_class_attr_prop(t_tango_class *d, const string &name)
+Tango::t_attribute_property *search_class_attr_prop(Tango::t_tango_class *d, const string &name)
 {
     for(unsigned int i = 0; i < d->attribute_properties.size(); i++)
     {
@@ -178,83 +174,6 @@ t_attribute_property *search_class_attr_prop(t_tango_class *d, const string &nam
     return nullptr;
 }
 
-std::string &trim(string &str)
-{
-    // trim leading whitespace
-    string::size_type notwhite = str.find_first_not_of(" \t\n");
-    str.erase(0, notwhite);
-
-    // trim trailing whitespace
-    notwhite = str.find_last_not_of(" \t\n");
-    str.erase(notwhite + 1);
-    return str;
-}
-
-std::vector<std::string> &makeStringArray(const std::string &input, vector<string> &results)
-{
-    std::string delimiter = "\n";
-    int iPos = 0;
-    int sizeS2 = delimiter.size();
-    int isize = input.size();
-
-    std::vector<int> positions;
-
-    int newPos = input.find(delimiter, 0);
-
-    if(newPos < 0)
-    {
-        return results;
-    }
-
-    while(newPos > iPos)
-    {
-        positions.push_back(newPos);
-        iPos = newPos;
-        newPos = input.find(delimiter, iPos + sizeS2 + 1);
-    }
-
-    for(unsigned int i = 0; i <= positions.size(); i++)
-    {
-        string s;
-        if(i == 0)
-        {
-            s = input.substr(i, positions[i]);
-        }
-        int offset = positions[i - 1] + sizeS2;
-        if(offset < isize)
-        {
-            if(i == positions.size())
-            {
-                s = input.substr(offset);
-            }
-            else if(i > 0)
-            {
-                s = input.substr(positions[i - 1] + sizeS2, positions[i] - positions[i - 1] - sizeS2);
-            }
-        }
-        if(s.size() > 0)
-        {
-            results.push_back(trim(s));
-        }
-    }
-    return results;
-}
-
-template <class T>
-bool hasName<T>::operator()(T *obj)
-{
-    return (Tango::equalsIgnoreCase(obj->name, name));
-}
-
-template <class T>
-bool hasAttributeName<T>::operator()(T *obj)
-{
-    return (Tango::equalsIgnoreCase(obj->attribute_name, attribute_name));
-}
-
-namespace
-{
-
 char *to_corba_string(CORBA::ULong val)
 {
     auto str = std::to_string(val);
@@ -263,6 +182,31 @@ char *to_corba_string(CORBA::ULong val)
 
 } // anonymous namespace
 
+namespace Tango
+{
+const char *FileDatabase::lexical_word_null = "NULL";
+const char *FileDatabase::lexical_word_number = "NUMBER";
+const char *FileDatabase::lexical_word_string = "STRING";
+const char *FileDatabase::lexical_word_coma = "COMA";
+const char *FileDatabase::lexical_word_colon = "COLON";
+const char *FileDatabase::lexical_word_slash = "SLASH";
+const char *FileDatabase::lexical_word_backslash = "BackSLASH";
+const char *FileDatabase::lexical_word_arrow = "->";
+int FileDatabase::ReadBufferSize = 4069;
+int FileDatabase::MaxWordLength = 256;
+
+template <class T>
+bool hasName<T>::operator()(T *obj)
+{
+    return (equalsIgnoreCase(obj->name, name));
+}
+
+template <class T>
+bool hasAttributeName<T>::operator()(T *obj)
+{
+    return (equalsIgnoreCase(obj->attribute_name, attribute_name));
+}
+
 FileDatabaseExt::FileDatabaseExt() { }
 
 FileDatabase::FileDatabase(const std::string &file_name) :
@@ -1280,8 +1224,8 @@ CORBA::Any_var FileDatabase ::DbGetDeviceProperty(CORBA::Any &send)
 
     send >>= data_in;
 
-    CORBA::Any *any_ptr;
-    any_ptr = new CORBA::Any();
+    CORBA::Any_var any;
+    any = new CORBA::Any();
     int index = 0;
 
     data_out->length(2);
@@ -1363,19 +1307,19 @@ CORBA::Any_var FileDatabase ::DbGetDeviceProperty(CORBA::Any &send)
         }
     }
 
-    (*any_ptr) <<= data_out;
+    any.inout() <<= data_out;
 
     // for (unsigned int i = 0; i < data_out->length(); i++)
     //     TANGO_LOG << "data_out[" << i << "] = " << (*data_out)[i] << endl;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbPutDeviceProperty(CORBA::Any &send)
 {
     TANGO_LOG_DEBUG << "FILEDATABASE: entering DbPutDeviceProperty" << endl;
 
-    CORBA::Any *any_ptr = new CORBA::Any;
+    CORBA::Any_var any = new CORBA::Any;
 
     const Tango::DevVarStringArray *data_in = nullptr;
     unsigned int n_properties = 0;
@@ -1392,11 +1336,11 @@ CORBA::Any_var FileDatabase ::DbPutDeviceProperty(CORBA::Any &send)
         if(it == m_server.devices.end())
         {
             TANGO_LOG_DEBUG << "Nome device " << (*data_in)[0] << " non trovato. " << endl;
-            return any_ptr;
+            return any;
         }
         t_device &device_trovato = *(*(it));
 
-        sscanf((*data_in)[1], "%6u", &n_properties);
+        n_properties = detail::parse_as<unsigned int>((*data_in)[1].in());
         index++;
         for(unsigned int i = 0; i < n_properties; i++)
         {
@@ -1409,7 +1353,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceProperty(CORBA::Any &send)
             {
                 /* we found a  property */
                 t_property &prop = (*(*prop_it));
-                sscanf((*data_in)[index], "%6d", &n_values);
+                n_values = detail::parse_as<int>((*data_in)[index].in());
                 index++;
                 prop.value.resize(n_values);
                 for(int j = 0; j < n_values; j++)
@@ -1423,7 +1367,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceProperty(CORBA::Any &send)
                 /* it is a new property */
                 t_property *temp_property = new t_property;
                 temp_property->name = (*data_in)[index - 1];
-                sscanf((*data_in)[index], "%6d", &n_values);
+                n_values = detail::parse_as<int>((*data_in)[index].in());
                 index++;
                 for(int j = 0; j < n_values; j++)
                 {
@@ -1436,7 +1380,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceProperty(CORBA::Any &send)
     }
 
     write_file();
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbDeleteDeviceProperty(CORBA::Any &send)
@@ -1465,16 +1409,16 @@ CORBA::Any_var FileDatabase ::DbDeleteDeviceProperty(CORBA::Any &send)
 
             if(itp != device_trovato.properties.end())
             {
-                // TANGO_LOG << "found " << (*itp)->name << endl;
+                delete *itp;
                 device_trovato.properties.erase(itp, itp + 1);
             }
         }
     }
 
-    CORBA::Any *any_ptr = new CORBA::Any;
+    CORBA::Any_var any = new CORBA::Any;
 
     write_file();
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbGetDeviceAttributeProperty(CORBA::Any &send)
@@ -1482,8 +1426,8 @@ CORBA::Any_var FileDatabase ::DbGetDeviceAttributeProperty(CORBA::Any &send)
     auto *data_out = new DevVarStringArray;
     const Tango::DevVarStringArray *data_in = nullptr;
 
-    CORBA::Any *any_ptr;
-    any_ptr = new CORBA::Any();
+    CORBA::Any_var any;
+    any = new CORBA::Any();
 
     TANGO_LOG_DEBUG << "FILEDATABASE: entering DbGetDeviceAttributeProperty" << endl;
 
@@ -1549,7 +1493,7 @@ CORBA::Any_var FileDatabase ::DbGetDeviceAttributeProperty(CORBA::Any &send)
     }
     else
     {
-        data_out->length(index + 2 * num_attr);
+        data_out->length(index + (2 * num_attr));
         for(unsigned int i = 0; i < num_attr; i++)
         {
             (*data_out)[index] = Tango::string_dup((*data_in)[i + 1]);
@@ -1562,9 +1506,9 @@ CORBA::Any_var FileDatabase ::DbGetDeviceAttributeProperty(CORBA::Any &send)
     // for(unsigned int i = 0; i < data_out->length(); i++)
     //     TANGO_LOG << "data_out[" << i << "] = " << (*data_out)[i] << endl;
 
-    (*any_ptr) <<= data_out;
+    any.inout() <<= data_out;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
@@ -1574,7 +1518,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
     unsigned int num_attr = 0;
     unsigned int num_vals = 0;
 
-    CORBA::Any *ret = new CORBA::Any;
+    CORBA::Any_var any = new CORBA::Any;
 
     TANGO_LOG_DEBUG << "FILEDATABASE: entering DbPutDeviceAttributeProperty" << endl;
 
@@ -1587,7 +1531,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
     index++;
     if(dev_it != m_server.devices.end())
     {
-        sscanf((*data_in)[index], "%6u", &num_attr);
+        num_attr = detail::parse_as<unsigned int>((*data_in)[index].in());
         index++;
         for(unsigned int j = 0; j < num_attr; j++)
         {
@@ -1610,7 +1554,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
             // if (equalsIgnoreCase((*dev_it)->attribute_properties[j]->attribute_name, (*data_in)[index].in()))
 
             index++;
-            sscanf((*data_in)[index], "%6u", &num_prop);
+            num_prop = detail::parse_as<unsigned int>((*data_in)[index].in());
             index++;
             for(unsigned int i = 0; i < num_prop; i++)
             {
@@ -1624,7 +1568,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
                             temp_attribute_property->properties[k]->value.begin(),
                             temp_attribute_property->properties[k]->value.begin() +
                                 temp_attribute_property->properties[k]->value.size());
-                        sscanf((*data_in)[index], "%6u", &num_vals);
+                        num_vals = detail::parse_as<unsigned int>((*data_in)[index].in());
                         index++;
                         for(unsigned int n = 0; n < num_vals; n++)
                         {
@@ -1637,7 +1581,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
                         if(index >= data_in->length())
                         {
                             write_file();
-                            return ret;
+                            return any;
                         }
                         exist = true;
                     }
@@ -1648,7 +1592,7 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
                     new_prop->name = (*data_in)[index];
                     index++;
 
-                    sscanf((*data_in)[index], "%6u", &num_vals);
+                    num_vals = detail::parse_as<unsigned int>((*data_in)[index].in());
                     index++;
                     for(unsigned int n = 0; n < num_vals; n++)
                     {
@@ -1656,20 +1600,18 @@ CORBA::Any_var FileDatabase ::DbPutDeviceAttributeProperty(CORBA::Any &send)
                         index++;
                     }
 
-                    // makeStringArray( string((*data_in)[index]), new_prop->value);index++;
-                    // new_prop->value.push_back( string((*data_in)[index]) );index++;
                     temp_attribute_property->properties.push_back(new_prop);
                     if(index >= data_in->length())
                     {
                         write_file();
-                        return ret;
+                        return any;
                     }
                 }
             }
         }
     }
     write_file();
-    return ret;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbDeleteDeviceAttributeProperty(CORBA::Any &send)
@@ -1702,8 +1644,7 @@ CORBA::Any_var FileDatabase ::DbDeleteDeviceAttributeProperty(CORBA::Any &send)
 
                     if(itp != device_trovato.attribute_properties[j]->properties.end())
                     {
-                        //                        TANGO_LOG << "found property" << (*itp)->name << "for attribute " <<
-                        //                        device_trovato.attribute_properties[j]->attribute_name << endl;
+                        delete *itp;
                         device_trovato.attribute_properties[j]->properties.erase(itp, itp + 1);
                     }
                 }
@@ -1711,9 +1652,9 @@ CORBA::Any_var FileDatabase ::DbDeleteDeviceAttributeProperty(CORBA::Any &send)
         }
     }
 
-    CORBA::Any *ret = new CORBA::Any;
+    CORBA::Any_var any = new CORBA::Any;
     write_file();
-    return ret;
+    return any;
 }
 
 /*
@@ -1749,7 +1690,7 @@ CORBA::Any_var FileDatabase ::DbGetClassProperty(CORBA::Any &send)
 
     send >>= data_in;
 
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
     int index = 0;
     int seq_length = 2;
 
@@ -1825,16 +1766,16 @@ CORBA::Any_var FileDatabase ::DbGetClassProperty(CORBA::Any &send)
         }
     }
 
-    (*any_ptr) <<= data_out;
+    any.inout() <<= data_out;
 
     TANGO_LOG_DEBUG << "FILEDATABASE: ending DbGetClassProperty" << endl;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbPutClassProperty(CORBA::Any &send)
 {
-    CORBA::Any *ret = new CORBA::Any;
+    CORBA::Any_var any = new CORBA::Any;
     const Tango::DevVarStringArray *data_in = nullptr;
     unsigned int n_properties = 0;
     int n_values = 0;
@@ -1853,11 +1794,11 @@ CORBA::Any_var FileDatabase ::DbPutClassProperty(CORBA::Any &send)
         if(it == m_server.classes.end())
         {
             TANGO_LOG_DEBUG << "Nome classe " << (*data_in)[0] << " non trovato. " << endl;
-            return ret;
+            return any;
         }
         t_tango_class &classe_trovata = *(*(it));
 
-        sscanf((*data_in)[index], "%6u", &n_properties);
+        n_properties = detail::parse_as<unsigned int>((*data_in)[index].in());
         index++;
         for(unsigned int i = 0; i < n_properties; i++)
         {
@@ -1870,7 +1811,7 @@ CORBA::Any_var FileDatabase ::DbPutClassProperty(CORBA::Any &send)
                 /* we found a  property */
                 index++;
                 t_property &prop = (*(*prop_it));
-                sscanf((*data_in)[index], "%6d", &n_values);
+                n_values = detail::parse_as<int>((*data_in)[index].in());
                 index++;
                 prop.value.resize(n_values);
                 for(int j = 0; j < n_values; j++)
@@ -1886,7 +1827,7 @@ CORBA::Any_var FileDatabase ::DbPutClassProperty(CORBA::Any &send)
                 t_property *temp_property = new t_property;
                 temp_property->name = (*data_in)[index];
                 index++;
-                sscanf((*data_in)[index], "%6d", &n_values);
+                n_values = detail::parse_as<int>((*data_in)[index].in());
                 index++;
                 for(int j = 0; j < n_values; j++)
                 {
@@ -1897,14 +1838,14 @@ CORBA::Any_var FileDatabase ::DbPutClassProperty(CORBA::Any &send)
                 if(index >= data_in->length())
                 {
                     write_file();
-                    return ret;
+                    return any;
                 }
             }
         }
     }
 
     write_file();
-    return ret;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbDeleteClassProperty(CORBA::Any &send)
@@ -1933,20 +1874,20 @@ CORBA::Any_var FileDatabase ::DbDeleteClassProperty(CORBA::Any &send)
 
             if(itp != classe_trovata.properties.end())
             {
-                // TANGO_LOG << "found " << (*itp)->name << endl;
+                delete *itp;
                 classe_trovata.properties.erase(itp, itp + 1);
             }
         }
     }
 
-    CORBA::Any *ret = new CORBA::Any;
+    CORBA::Any_var any = new CORBA::Any;
     write_file();
-    return ret;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbGetClassAttributeProperty(CORBA::Any &send)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
     auto *data_out = new DevVarStringArray;
     const Tango::DevVarStringArray *data_in = nullptr;
 
@@ -1967,7 +1908,7 @@ CORBA::Any_var FileDatabase ::DbGetClassAttributeProperty(CORBA::Any &send)
     if(it == m_server.classes.end())
     {
         TANGO_LOG_DEBUG << "Nome classe " << (*data_in)[0] << " non trovato. " << endl;
-        data_out->length(index + num_attr * 2);
+        data_out->length(index + (num_attr * 2));
         for(unsigned int j = 0; j < num_attr; j++)
         {
             (*data_out)[index] = Tango::string_dup((*data_in)[j + 1]);
@@ -1975,9 +1916,9 @@ CORBA::Any_var FileDatabase ::DbGetClassAttributeProperty(CORBA::Any &send)
             (*data_out)[index] = Tango::string_dup("0");
             index++;
         }
-        (*any_ptr) <<= data_out;
+        any.inout() <<= data_out;
 
-        return any_ptr;
+        return any;
     }
     t_tango_class &classe_trovata = *(*(it));
 
@@ -2030,14 +1971,14 @@ CORBA::Any_var FileDatabase ::DbGetClassAttributeProperty(CORBA::Any &send)
     // for(unsigned int i = 0; i < data_out->length(); i++)
     //     TANGO_LOG << "data_out[" << i << "] = " << (*data_out)[i] << endl;
 
-    (*any_ptr) <<= data_out;
+    any.inout() <<= data_out;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
 {
-    CORBA::Any *ret = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
     const Tango::DevVarStringArray *data_in = nullptr;
     unsigned int num_attr = 0;
     unsigned int num_prop = 0;
@@ -2058,7 +1999,7 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
     }
     else
     {
-        sscanf((*data_in)[index], "%6u", &num_attr);
+        num_attr = detail::parse_as<unsigned int>((*data_in)[index].in());
         index++;
         t_tango_class &classe_trovata = *(*(it));
         t_attribute_property *temp_attribute_property;
@@ -2082,7 +2023,7 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
                 classe_trovata.attribute_properties.push_back(temp_attribute_property);
             }
             index++;
-            sscanf((*data_in)[index], "%6u", &num_prop);
+            num_prop = detail::parse_as<unsigned int>((*data_in)[index].in());
             index++;
             for(unsigned int i = 0; i < num_prop; i++)
             {
@@ -2096,7 +2037,7 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
                             temp_attribute_property->properties[k]->value.begin(),
                             temp_attribute_property->properties[k]->value.begin() +
                                 temp_attribute_property->properties[k]->value.size());
-                        sscanf((*data_in)[index], "%6u", &num_vals);
+                        num_vals = detail::parse_as<unsigned int>((*data_in)[index].in());
                         index++;
                         for(unsigned int n = 0; n < num_vals; n++)
                         {
@@ -2109,7 +2050,7 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
                         if(index >= data_in->length())
                         {
                             write_file();
-                            return ret;
+                            return any;
                         }
                         exist = true;
                     }
@@ -2120,7 +2061,7 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
                     new_prop->name = (*data_in)[index];
                     index++;
 
-                    sscanf((*data_in)[index], "%6u", &num_vals);
+                    num_vals = detail::parse_as<unsigned int>((*data_in)[index].in());
                     index++;
                     for(unsigned int n = 0; n < num_vals; n++)
                     {
@@ -2128,13 +2069,11 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
                         index++;
                     }
 
-                    // makeStringArray( string((*data_in)[index]), new_prop->value);index++;
-                    // new_prop->value.push_back( string((*data_in)[index]) );index++;
                     temp_attribute_property->properties.push_back(new_prop);
                     if(index >= data_in->length())
                     {
                         write_file();
-                        return ret;
+                        return any;
                     }
                 }
             }
@@ -2142,7 +2081,7 @@ CORBA::Any_var FileDatabase ::DbPutClassAttributeProperty(CORBA::Any &send)
     }
 
     write_file();
-    return ret;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbDeleteClassAttributeProperty(CORBA::Any &)
@@ -2152,7 +2091,7 @@ CORBA::Any_var FileDatabase ::DbDeleteClassAttributeProperty(CORBA::Any &)
 
 CORBA::Any_var FileDatabase ::DbGetDeviceList(CORBA::Any &send)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
     const Tango::DevVarStringArray *data_in = nullptr;
     auto *data_out = new DevVarStringArray;
 
@@ -2181,7 +2120,6 @@ CORBA::Any_var FileDatabase ::DbGetDeviceList(CORBA::Any &send)
 
             if(i == m_server.classes.size())
             {
-                delete any_ptr;
                 delete data_out;
 
                 TangoSys_MemStream desc;
@@ -2192,7 +2130,6 @@ CORBA::Any_var FileDatabase ::DbGetDeviceList(CORBA::Any &send)
         }
         else
         {
-            delete any_ptr;
             delete data_out;
 
             TangoSys_MemStream desc;
@@ -2202,13 +2139,13 @@ CORBA::Any_var FileDatabase ::DbGetDeviceList(CORBA::Any &send)
         }
     }
 
-    (*any_ptr) <<= data_out;
-    return any_ptr;
+    any.inout() <<= data_out;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbInfo(CORBA::Any &)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
 
     auto generate_string = [](std::string prefix, CORBA::ULong size) -> char *
     {
@@ -2244,9 +2181,9 @@ CORBA::Any_var FileDatabase ::DbInfo(CORBA::Any &)
     (*data_out)[12] =
         generate_string("Device attribute properties defined = ", accumulate(m_server.devices, prop_attr_func));
 
-    (*any_ptr) <<= data_out;
+    any.inout() <<= data_out;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbImportDevice(CORBA::Any &)
@@ -2301,14 +2238,14 @@ CORBA::Any_var FileDatabase ::DbGetServerInfo(CORBA::Any &)
 
 CORBA::Any_var FileDatabase ::DbGetDeviceMemberList(CORBA::Any &)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
 
     auto *argout = new Tango::DevVarStringArray();
     argout->length(1);
     (*argout)[0] = Tango::string_dup("NoMember");
-    (*any_ptr) <<= argout;
+    any.inout() <<= argout;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbGetDeviceWideList(CORBA::Any &)
@@ -2323,26 +2260,26 @@ CORBA::Any_var FileDatabase ::DbGetDeviceExportedList(CORBA::Any &)
 
 CORBA::Any_var FileDatabase ::DbGetDeviceFamilyList(CORBA::Any &)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
 
     auto *argout = new Tango::DevVarStringArray();
     argout->length(1);
     (*argout)[0] = Tango::string_dup("NoDevice");
-    (*any_ptr) <<= argout;
+    any.inout() <<= argout;
 
-    return any_ptr;
+    return any;
 }
 
 CORBA::Any_var FileDatabase ::DbGetDeviceDomainList(CORBA::Any &)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
 
     auto *argout = new Tango::DevVarStringArray();
     argout->length(1);
     (*argout)[0] = Tango::string_dup("NoDevice");
-    (*any_ptr) <<= argout;
+    any.inout() <<= argout;
 
-    return any_ptr;
+    return any;
 }
 
 /**
@@ -2365,10 +2302,9 @@ CORBA::Any_var FileDatabase ::DbGetDeviceDomainList(CORBA::Any &)
  */
 CORBA::Any_var FileDatabase::DbGetProperty(CORBA::Any &send)
 {
-    CORBA::Any *any_ptr = new CORBA::Any();
+    CORBA::Any_var any = new CORBA::Any();
 
     const DevVarStringArray *data_in = nullptr;
-    auto *data_out = new DevVarStringArray;
 
     TANGO_LOG_DEBUG << "FILEDATABASE: entering DbGetProperty" << endl;
 
@@ -2388,6 +2324,8 @@ CORBA::Any_var FileDatabase::DbGetProperty(CORBA::Any &send)
         TANGO_THROW_EXCEPTION(API_InvalidCorbaAny, ss.str().c_str());
     }
 
+    auto *data_out = new DevVarStringArray;
+
     const auto &free_objects = m_server.free_objects;
     const char *obj_name = (*data_in)[0].in();
 
@@ -2405,7 +2343,7 @@ CORBA::Any_var FileDatabase::DbGetProperty(CORBA::Any &send)
     //
     // Later we allocate more space if we find that there are multiple elements
     // for a value.
-    data_out->length(2 + 3 * num_prop);
+    data_out->length(2 + (3 * num_prop));
 
     size_t out_index = 0;
     (*data_out)[out_index] = Tango::string_dup(obj_name);
@@ -2460,8 +2398,8 @@ CORBA::Any_var FileDatabase::DbGetProperty(CORBA::Any &send)
         }
     }
 
-    (*any_ptr) <<= data_out;
-    return any_ptr;
+    any.inout() <<= data_out;
+    return any;
 }
 
 //--------------------------------------------------------
@@ -2512,8 +2450,7 @@ CORBA::Any_var FileDatabase::DbPutProperty(CORBA::Any &send)
 
     auto &prop_list = (*obj)->properties;
 
-    unsigned int n_properties = 0;
-    sscanf((*data_in)[1], "%6u", &n_properties);
+    unsigned int n_properties = detail::parse_as<unsigned int>((*data_in)[1].in());
     unsigned int index = 2;
 
     for(unsigned int i = 0; i < n_properties; i++)
@@ -2528,8 +2465,7 @@ CORBA::Any_var FileDatabase::DbPutProperty(CORBA::Any &send)
             prop = prop_list.insert(prop_list.end(), new t_property{prop_name, {}});
         }
 
-        unsigned int n_values = 0;
-        sscanf((*data_in)[index], "%6u", &n_values);
+        unsigned int n_values = detail::parse_as<unsigned int>((*data_in)[index].in());
         index++;
 
         auto &value = (*prop)->value;
@@ -2602,6 +2538,7 @@ CORBA::Any_var FileDatabase::DbDeleteProperty(CORBA::Any &send)
             continue;
         }
 
+        delete *prop;
         prop_list.erase(prop);
     }
 
