@@ -31,11 +31,13 @@
 //
 //=============================================================================
 
-#include <sstream>
-#include <tango/tango.h>
+#include <tango/client/group.h>
+#include <tango/client/Database.h>
 
 #include <tango/internal/telemetry/telemetry_kernel_macros.h>
 
+#include <sstream>
+
 //-----------------------------------------------------------------------------
 // LOCAL DEBUGGING MACRO
 //-----------------------------------------------------------------------------
