@@ -33,8 +33,10 @@
 ///
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <tango/tango.h>
 #include <tango/client/eventconsumer.h>
+#include <tango/client/Database.h>
+#include <tango/client/event.h>
+#include <tango/server/auto_tango_monitor.h>
 
 #include <cstdio>
 
@@ -49,9 +51,6 @@ using namespace CORBA;
 namespace Tango
 {
 
-NotifdEventConsumer *NotifdEventConsumer::_instance = nullptr;
-omni_mutex EventConsumer::ev_consumer_inst_mutex;
-
 void NotifdEventConsumer::disconnect_structured_push_consumer()
 {
     TANGO_LOG_DEBUG << "calling Tango::NotifdEventConsumer::disconnect_structured_push_consumer() \n";
@@ -77,32 +76,9 @@ NotifdEventConsumer::NotifdEventConsumer(ApiUtil *ptr) :
     TANGO_LOG_DEBUG << "calling Tango::NotifdEventConsumer::NotifdEventConsumer() \n";
     orb_ = ptr->get_orb();
 
-    _instance = this;
-
     start_undetached();
 }
 
-NotifdEventConsumer *NotifdEventConsumer::create()
-{
-    omni_mutex_lock guard(ev_consumer_inst_mutex);
-
-    //
-    // check if the NotifdEventConsumer singleton exists, if so return it
-    //
-
-    if(_instance != nullptr)
-    {
-        return _instance;
-    }
-
-    //
-    // NotifdEventConsumer singleton does not exist, create it
-    //
-
-    ApiUtil *ptr = ApiUtil::instance();
-    return new NotifdEventConsumer(ptr);
-}
-
 //+----------------------------------------------------------------------------
 //
 // method :         NotifdEventConsumer::run_undetached()
@@ -136,6 +112,16 @@ void *NotifdEventConsumer::run_undetached(void *arg)
     return (void *) nullptr;
 }
 
+void NotifdEventConsumer::query_event_system(TANGO_UNUSED(std::ostream &os))
+{
+    TANGO_ASSERT(0);
+}
+
+void NotifdEventConsumer::get_subscribed_event_ids(TANGO_UNUSED(DeviceProxy *dev), TANGO_UNUSED(std::vector<int> &ids))
+{
+    TANGO_ASSERT(0);
+}
+
 //+----------------------------------------------------------------------------
 //
 // method :         NotifdEventConsumer::cleanup_EventChannel_map()
@@ -202,9 +188,6 @@ void NotifdEventConsumer::cleanup_EventChannel_map()
                               << evt_ch.full_adm_name << std::endl;
                 }
 
-                // Release the connection to the device server administration device
-
-                delete evt_ch.adm_device_proxy;
                 evt_ch.adm_device_proxy = nullptr;
             }
         }
@@ -623,7 +606,7 @@ void NotifdEventConsumer::connect_event_channel(const std::string &channel_name,
         new_event_channel_struct.heartbeat_skipped = false;
         new_event_channel_struct.adm_device_proxy = nullptr;
         // create a channel monitor
-        new_event_channel_struct.channel_monitor = new TangoMonitor(channel_name.c_str());
+        new_event_channel_struct.channel_monitor = std::make_shared<TangoMonitor>(channel_name.c_str());
         // set the timeout for the channel monitor to 1000ms not to block the event consumer for to long.
         new_event_channel_struct.channel_monitor->timeout(1000);
         set_channel_type(new_event_channel_struct);
@@ -1036,12 +1019,17 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                                     dev_attr_copy->deep_copy(*dev_attr);
                                 }
 
-                                event_data =
-                                    new EventData(esspos->device, fq_dev_name, event_name, dev_attr_copy, errors);
+                                event_data = new EventData(esspos->device,
+                                                           fq_dev_name,
+                                                           event_name,
+                                                           dev_attr_copy,
+                                                           EventReason::Update,
+                                                           errors);
                             }
                             else
                             {
-                                event_data = new EventData(esspos->device, fq_dev_name, event_name, dev_attr, errors);
+                                event_data = new EventData(
+                                    esspos->device, fq_dev_name, event_name, dev_attr, EventReason::Update, errors);
                             }
 
                             // if a callback method was specified, call it!
@@ -1076,13 +1064,17 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                             {
                                 AttributeInfoEx *attr_info_copy = new AttributeInfoEx();
                                 *attr_info_copy = *attr_info_ex;
-                                event_data = new AttrConfEventData(
-                                    esspos->device, fq_dev_name, event_name, attr_info_copy, errors);
+                                event_data = new AttrConfEventData(esspos->device,
+                                                                   fq_dev_name,
+                                                                   event_name,
+                                                                   attr_info_copy,
+                                                                   EventReason::Update,
+                                                                   errors);
                             }
                             else
                             {
                                 event_data = new AttrConfEventData(
-                                    esspos->device, fq_dev_name, event_name, attr_info_ex, errors);
+                                    esspos->device, fq_dev_name, event_name, attr_info_ex, EventReason::Update, errors);
                             }
 
                             // if callback methods were specified, call them!
@@ -1111,8 +1103,8 @@ void NotifdEventConsumer::push_structured_event(const CosNotification::Structure
                         }
                         else
                         {
-                            DataReadyEventData *event_data =
-                                new DataReadyEventData(esspos->device, att_ready, event_name, errors);
+                            DataReadyEventData *event_data = new DataReadyEventData(
+                                esspos->device, att_ready, event_name, EventReason::Update, errors);
                             // if a callback method was specified, call it!
                             if(callback != nullptr)
                             {
