@@ -32,7 +32,7 @@
 //
 //===================================================================================
 
-#include <tango/tango.h>
+#include <tango/client/Database.h>
 #include <tango/internal/telemetry/telemetry_kernel_macros.h>
 
 #define _dyn_attr
@@ -3043,9 +3043,6 @@ DeviceData Connection::omni420_except(int id, char *cb_excep_mess, TgRequest &re
     remove_asyn_request(id);
 
     TANGO_RETHROW_DETAILED_EXCEPTION(ApiCommExcept, cb_excep_mess, API_CommunicationFailed, ss.str());
-
-    DeviceData dummy;
-    return dummy;
 }
 
 void DeviceProxy::omni420_timeout_attr(int id, char *cb_excep_mess, read_attr_type type)
