@@ -28,11 +28,51 @@
 //
 //
 
-#include <tango/tango.h>
+#include <tango/client/Connection.h>
+#include <tango/client/apiexcept.h>
+#include <tango/client/ApiUtil.h>
+#include <tango/client/DeviceProxy.h>
+#include <tango/client/DeviceAttribute.h>
+#include <tango/server/tango_config.h>
+
+#include <thread>
 
 namespace Tango
 {
 
+//--------------------------------------------------------------------------------------------------------------------
+//
+// helper method to user callback and printout error, if failed
+//
+//--------------------------------------------------------------------------------------------------------------------
+template <typename Func>
+static void catch_and_report_callback_failure(const char *method_name, const std::string &dev_name, Func &&callback)
+{
+    try
+    {
+        // invoke the real callback
+        callback();
+    }
+    catch(const DevFailed &e)
+    {
+        TangoSys_OMemStream o;
+        o << method_name << " callback method of " << dev_name << " got DevFailed exception: \n\n" << e.errors[0].desc;
+        ApiUtil::instance()->print_error_message(o.str().c_str());
+    }
+    catch(const std::exception &e)
+    {
+        TangoSys_OMemStream o;
+        o << method_name << " callback method of " << dev_name << " got std::exception: \n\n" << e.what();
+        ApiUtil::instance()->print_error_message(o.str().c_str());
+    }
+    catch(...)
+    {
+        TangoSys_OMemStream o;
+        o << method_name << " callback method of " << dev_name << " got unknown exception";
+        ApiUtil::instance()->print_error_message(o.str().c_str());
+    }
+}
+
 //-----------------------------------------------------------------------------
 //
 // method :         Connection::command_inout_asyn()
@@ -386,7 +426,8 @@ void Connection::Cb_Cmd_Request(CORBA::Request_ptr req, Tango::CallBack *cb_ptr)
     CmdDoneEvent *cb_data = new CmdDoneEvent(local_dev, cmd_str, data_out, errors);
 
     std::unique_ptr<CmdDoneEvent> auto_cb_data(cb_data);
-    cb_ptr->cmd_ended(auto_cb_data.get());
+
+    catch_and_report_callback_failure("cmd_ended", dev_name(), [&]() { cb_ptr->cmd_ended(auto_cb_data.get()); });
 }
 
 //-----------------------------------------------------------------------------
@@ -483,7 +524,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
                 }
 
                 //
-                // Add an error in the error stack in case there is one
+                // Add an error in the event error stack in case the attribute has an error
                 //
 
                 DevErrorList_var &err_list = (*dev_attr)[i].get_error_list();
@@ -494,12 +535,13 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
                     desc << "Failed to read_attributes on device " << dev_name();
                     desc << ", attribute " << (*dev_attr)[i].name << std::ends;
 
-                    err_list.inout().length(nb_except + 1);
-                    err_list[nb_except].reason = Tango::string_dup(API_AttributeFailed);
-                    err_list[nb_except].origin = Tango::string_dup(TANGO_EXCEPTION_ORIGIN);
+                    const auto idx = errors.length();
+                    errors.length(idx + 1);
+                    errors[idx].reason = Tango::string_dup(API_AttributeFailed);
+                    errors[idx].origin = Tango::string_dup(TANGO_EXCEPTION_ORIGIN);
                     std::string st = desc.str();
-                    err_list[nb_except].desc = Tango::string_dup(st.c_str());
-                    err_list[nb_except].severity = Tango::ERR;
+                    errors[idx].desc = Tango::string_dup(st.c_str());
+                    errors[idx].severity = Tango::ERR;
                 }
             }
             else
@@ -639,7 +681,7 @@ void Connection::Cb_ReadAttr_Request(CORBA::Request_ptr req, Tango::CallBack *cb
 
     std::unique_ptr<AttrReadEvent> auto_cb_data(cb_data);
 
-    cb_ptr->attr_read(auto_cb_data.get());
+    catch_and_report_callback_failure("attr_read", dev_name(), [&]() { cb_ptr->attr_read(auto_cb_data.get()); });
 }
 
 //-----------------------------------------------------------------------------
@@ -895,7 +937,7 @@ void Connection::Cb_WriteAttr_Request(CORBA::Request_ptr req, Tango::CallBack *c
 
     std::unique_ptr<AttrWrittenEvent> auto_cb_data(cb_data);
 
-    cb_ptr->attr_written(auto_cb_data.get());
+    catch_and_report_callback_failure("attr_written", dev_name(), [&]() { cb_ptr->attr_written(auto_cb_data.get()); });
 }
 
 //-----------------------------------------------------------------------------
