@@ -30,6 +30,18 @@
 #ifndef _APIUTIL_H
 #define _APIUTIL_H
 
+#include <tango/server/tango_config.h>
+#include <tango/client/Connection.h>
+#include <tango/client/devapi.h>
+#include <tango/client/devasyn.h>
+
+#include <string>
+#include <map>
+#include <memory>
+#include <vector>
+
+namespace Tango
+{
 /****************************************************************************************
  *                                                                                         *
  *                     The ApiUtil class                                                    *
@@ -50,6 +62,7 @@
  * @ingroup Client
  */
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class ApiUtil
 {
   public:
@@ -252,22 +265,20 @@ class ApiUtil
     // EventConsumer related methods
     //
 
-    void create_notifd_event_consumer();
-    void create_zmq_event_consumer();
+    PointerWithLock<EventConsumer> create_notifd_event_consumer();
+    PointerWithLock<EventConsumer> create_zmq_event_consumer();
 
-    bool is_notifd_event_consumer_created()
-    {
-        return notifd_event_consumer != nullptr;
-    }
+    bool is_notifd_event_consumer_created();
+    PointerWithLock<EventConsumer> get_notifd_event_consumer();
 
-    NotifdEventConsumer *get_notifd_event_consumer();
+    bool is_zmq_event_consumer_created();
+    PointerWithLock<EventConsumer> get_zmq_event_consumer();
 
-    bool is_zmq_event_consumer_created()
-    {
-        return zmq_event_consumer != nullptr;
-    }
+    PointerWithLock<ZmqEventConsumer> get_zmq_event_consumer_derived(EventConsumer *ptr);
 
-    ZmqEventConsumer *get_zmq_event_consumer();
+    PointerWithLock<EventConsumer> get_locked_event_consumer(EventConsumer *ptr);
+
+    void shutdown_event_consumers();
 
     //
     // Asynchronous methods
@@ -323,17 +334,22 @@ class ApiUtil
         ApiUtilExt() { }
     };
 
+    void shutdown_cb_thread();
+
     static ApiUtil *_instance;
     static omni_mutex inst_mutex;
     bool exit_lock_installed{false};
     bool reset_already_executed_flag{false};
+    ReadersWritersLock zmq_rw_lock, notifd_rw_lock;
+    // we don't use smart pointers here as these are omnithreads
+    // which cleanup when join'ed
+    ZmqEventConsumer *zmq_event_consumer{nullptr};
+    NotifdEventConsumer *notifd_event_consumer{nullptr};
 
     std::unique_ptr<ApiUtilExt> ext;
 
-    NotifdEventConsumer *notifd_event_consumer{nullptr};
     TangoSys_Pid cl_pid;
     int user_connect_timeout{-1};
-    ZmqEventConsumer *zmq_event_consumer{nullptr};
     std::vector<std::string> host_ip_adrs;
     DevLong user_sub_hwm{-1};
     /***
@@ -346,9 +362,6 @@ class ApiUtil
      * @param req, the request to be forwarded on the connection
      */
     void process_request(Connection *connection, const TgRequest &tg_req, CORBA::Request_ptr &req);
-
-    template <typename T>
-    static void attr_to_device_base(const T *, DeviceAttribute *);
 };
-
+} // namespace Tango
 #endif /* _APIUTIL_H */
