@@ -30,6 +30,16 @@
 #ifndef _ATTRIBUTEPROXY_H
 #define _ATTRIBUTEPROXY_H
 
+#include <string>
+#include <memory>
+#include <vector>
+
+#include <tango/client/DeviceProxy.h>
+#include <tango/client/devapi.h>
+#include <tango/client/DbDevice.h>
+
+namespace Tango
+{
 /****************************************************************************************
  *                                                                                         *
  *                     The AttributeProxy class                                            *
@@ -58,8 +68,8 @@ class AttributeProxy
     std::string attr_name;
     std::string device_name;
     std::string alias_name;
-    Tango::DeviceProxy *dev_proxy;
-    Tango::DbAttribute *db_attr;
+    Tango::DeviceProxy *dev_proxy{nullptr};
+    Tango::DbAttribute *db_attr{nullptr};
     bool dbase_used;   // Dev. with database
     bool from_env_var; // DB from TANGO_HOST
 
@@ -508,6 +518,7 @@ class AttributeProxy
      * @exception EventSystemFailed
      */
     virtual int subscribe_event(EventType event, CallBack *cb);
+
     /**
      * Stateless subscription to attribute event
      *
@@ -525,6 +536,22 @@ class AttributeProxy
      * @exception EventSystemFailed
      */
     virtual int subscribe_event(EventType event, CallBack *cb, bool stateless);
+
+    /**
+     * Subscribe for event reception with EventSubMode support
+     *
+     * Variant of `subscribe_event(EventType event, CallBack *cb)` with support for different event
+     * subscription modes.
+     *
+     * @param [in] event The event type
+     * @param [in] cb The callback object
+     * @param [in] event_sub_mode One of Tango::EventSubMode
+     *
+     * @return The event identifier
+     * @throws EventSystemFailed
+     */
+    virtual int subscribe_event(EventType event, CallBack *callback, EventSubMode mode);
+
     /**
      * Stateless subscription to attribute event with event queue
      *
@@ -549,6 +576,21 @@ class AttributeProxy
      */
     virtual int subscribe_event(EventType event, int event_queue_size, bool stateless = false);
 
+    /**
+     * Subscribe for event reception with EventSubMode support
+     *
+     * Variant of `subscribe_event(EventType event, int event_queue_size, bool stateless = false)` with support for
+     * different event subscription modes.
+     *
+     * @param [in] event The event type
+     * @param [in] event_queue_size The event queue size
+     * @param [in] event_sub_mode One of Tango::EventSubMode
+     *
+     * @return The event identifier
+     * @throws EventSystemFailed
+     */
+    virtual int subscribe_event(EventType event, int event_queue_size, EventSubMode mode);
+
     /**
      * Unsubsribe to attribute event
      *
@@ -773,5 +815,5 @@ class AttributeProxy
     AttributeProxy &operator=(const AttributeProxy &);
     virtual ~AttributeProxy();
 };
-
+} // namespace Tango
 #endif /* _ATTRIBUTEPROXY_H */
