@@ -35,10 +35,11 @@
 #ifndef _CBTHREAD_H
 #define _CBTHREAD_H
 
-#include <tango/tango.h>
+#include <tango/common/omnithread_wrapper.h>
 
 namespace Tango
 {
+class AsynReq;
 
 class CbThreadCmd : public omni_mutex
 {
@@ -75,6 +76,7 @@ class CbThreadCmd : public omni_mutex
 //
 //=============================================================================
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class CallBackThread : public omni_thread
 {
   public:
@@ -93,6 +95,9 @@ class CallBackThread : public omni_thread
 
     CbThreadCmd &shared_cmd;
     AsynReq *asyn_ptr;
+
+  private:
+    ~CallBackThread() override = default;
 };
 
 } // namespace Tango
