@@ -36,6 +36,8 @@
 #include <tango/server/attribute.h>
 #include <tango/server/except.h>
 #include <tango/common/tango_const.h>
+#include <tango/client/devapi.h>
+#include <tango/client/ApiUtil.h>
 
 #include <zmq.hpp>
 
@@ -51,6 +53,8 @@ extern "C"
 }
 #endif
 
+class DeviceProxy;
+
 /********************************************************************************
  *                                                                                 *
  *                         EventData class                                            *
@@ -77,9 +81,10 @@ class EventData
               const std::string &nam,
               const std::string &evt,
               Tango::DeviceAttribute *attr_value_in,
+              Tango::EventReason event_reason_in,
               const DevErrorList &errors_in);
 
-    ~EventData();
+    virtual ~EventData();
     EventData(const EventData &);
     EventData &operator=(const EventData &);
     /**
@@ -96,12 +101,13 @@ class EventData
     std::unique_ptr<DeviceAttribute>
         get_attr_err_info(); ///< Construct and return a DeviceAttribute containing the error stack
 
-    DeviceProxy *device;         ///< The DeviceProxy object on which the call was executed
-    std::string attr_name;       ///< The attribute name
-    std::string event;           ///< The event name
-    DeviceAttribute *attr_value; ///< The attribute data
-    bool err;                    ///< A boolean flag set to true if the request failed. False otherwise
-    DevErrorList errors;         ///< The error stack
+    DeviceProxy *device{nullptr};         ///< The DeviceProxy object on which the call was executed
+    std::string attr_name;                ///< The attribute name
+    std::string event;                    ///< The event name
+    DeviceAttribute *attr_value{nullptr}; ///< The attribute data
+    bool err{false};                      ///< A boolean flag set to true if the request failed. False otherwise
+    EventReason event_reason{EventReason::Unknown}; ///< Reason for the event, see @ref EventReason
+    DevErrorList errors;                            ///< The error stack
 
   private:
     void set_time();
@@ -110,13 +116,18 @@ class EventData
 class FwdEventData : public EventData
 {
   public:
-    FwdEventData();
-    FwdEventData(
-        DeviceProxy *, const std::string &, const std::string &, Tango::DeviceAttribute *, const DevErrorList &);
+    FwdEventData() = default;
     FwdEventData(DeviceProxy *,
                  const std::string &,
                  const std::string &,
                  Tango::DeviceAttribute *,
+                 Tango::EventReason,
+                 const DevErrorList &);
+    FwdEventData(DeviceProxy *,
+                 const std::string &,
+                 const std::string &,
+                 Tango::DeviceAttribute *,
+                 Tango::EventReason,
                  const DevErrorList &,
                  zmq::message_t *);
 
@@ -136,8 +147,8 @@ class FwdEventData : public EventData
     }
 
   private:
-    const AttributeValue_5 *av_5;
-    zmq::message_t *event_data;
+    const AttributeValue_5 *av_5{nullptr};
+    zmq::message_t *event_data{nullptr};
 };
 
 /********************************************************************************
@@ -207,8 +218,9 @@ class AttrConfEventData
                       const std::string &nam,
                       const std::string &evt,
                       Tango::AttributeInfoEx *attr_conf_in,
+                      Tango::EventReason event_reason_in,
                       const DevErrorList &errors_in);
-    ~AttrConfEventData();
+    virtual ~AttrConfEventData();
     AttrConfEventData(const AttrConfEventData &);
     AttrConfEventData &operator=(const AttrConfEventData &);
     /**
@@ -222,12 +234,13 @@ class AttrConfEventData
     }
 
     ///@publicsection
-    DeviceProxy *device;        ///< The DeviceProxy object on which the call was executed
-    std::string attr_name;      ///< The attribute name
-    std::string event;          ///< The event name
-    AttributeInfoEx *attr_conf; ///< The attribute configuration
-    bool err;                   ///< A boolean flag set to true if the request failed. False otherwise
-    DevErrorList errors;        ///< The error stack
+    DeviceProxy *device{nullptr};        ///< The DeviceProxy object on which the call was executed
+    std::string attr_name;               ///< The attribute name
+    std::string event;                   ///< The event name
+    AttributeInfoEx *attr_conf{nullptr}; ///< The attribute configuration
+    bool err{false};                     ///< A boolean flag set to true if the request failed. False otherwise
+    EventReason event_reason{EventReason::Unknown}; ///< Reason for the event, see @ref EventReason
+    DevErrorList errors;                            ///< The error stack
 
   private:
     void set_time();
@@ -236,9 +249,13 @@ class AttrConfEventData
 class FwdAttrConfEventData : public AttrConfEventData
 {
   public:
-    FwdAttrConfEventData();
-    FwdAttrConfEventData(
-        DeviceProxy *, const std::string &, const std::string &, Tango::AttributeInfoEx *, const DevErrorList &);
+    FwdAttrConfEventData() = default;
+    FwdAttrConfEventData(DeviceProxy *,
+                         const std::string &,
+                         const std::string &,
+                         Tango::AttributeInfoEx *,
+                         Tango::EventReason,
+                         const DevErrorList &);
 
     void set_fwd_attr_conf(const AttributeConfig_5 *_p)
     {
@@ -251,7 +268,7 @@ class FwdAttrConfEventData : public AttrConfEventData
     }
 
   private:
-    const AttributeConfig_5 *fwd_attr_conf;
+    const AttributeConfig_5 *fwd_attr_conf{nullptr};
 };
 
 /********************************************************************************
@@ -316,7 +333,7 @@ class DataReadyEventData
     ///@privatesection
     DataReadyEventData() { }
 
-    DataReadyEventData(DeviceProxy *, AttDataReady *, const std::string &evt, const DevErrorList &);
+    DataReadyEventData(DeviceProxy *, AttDataReady *, const std::string &evt, EventReason, const DevErrorList &);
 
     ~DataReadyEventData() { }
 
@@ -333,14 +350,15 @@ class DataReadyEventData
     }
 
     ///@publicsection
-    DeviceProxy *device;   ///< The DeviceProxy object on which the call was executed
-    std::string attr_name; ///< The attribute name
-    std::string event;     ///< The event name
-    int attr_data_type;    ///< The attribute data type
-    int ctr;               ///< The user counter. Set to 0 if not defined when sent by the server
+    DeviceProxy *device{nullptr}; ///< The DeviceProxy object on which the call was executed
+    std::string attr_name;        ///< The attribute name
+    std::string event;            ///< The event name
+    int attr_data_type;           ///< The attribute data type
+    int ctr;                      ///< The user counter. Set to 0 if not defined when sent by the server
 
-    bool err;            ///< A boolean flag set to true if the request failed. False otherwise
-    DevErrorList errors; ///< The error stack
+    bool err{false}; ///< A boolean flag set to true if the request failed. False otherwise
+    EventReason event_reason{EventReason::Unknown}; ///< Reason for the event, see @ref EventReason
+    DevErrorList errors;                            ///< The error stack
 
   private:
     void set_time();
@@ -415,6 +433,7 @@ class DevIntrChangeEventData
                            DevCmdInfoList_2 *,
                            AttributeConfigList_5 *,
                            bool,
+                           EventReason,
                            const DevErrorList &);
     DevIntrChangeEventData(DeviceProxy *,
                            const std::string &,
@@ -422,6 +441,7 @@ class DevIntrChangeEventData
                            CommandInfoList *,
                            AttributeInfoListEx *,
                            bool,
+                           EventReason,
                            const DevErrorList &);
 
     ~DevIntrChangeEventData() { }
@@ -439,16 +459,17 @@ class DevIntrChangeEventData
     }
 
     ///@publicsection
-    DeviceProxy *device;          ///< The DeviceProxy object on which the call was executed
+    DeviceProxy *device{nullptr}; ///< The DeviceProxy object on which the call was executed
     std::string event;            ///< The event name
     std::string device_name;      ///< The device name
     CommandInfoList cmd_list;     ///< Device command list info
     AttributeInfoListEx att_list; ///< Device attribute list info
-    bool dev_started;             ///< Device started flag (true when event sent due to device being (re)started
+    bool dev_started{false};      ///< Device started flag (true when event sent due to device being (re)started
                                   ///< and with only a possible but not sure interface change)
 
-    bool err;            ///< A boolean flag set to true if the request failed. False otherwise
-    DevErrorList errors; ///< The error stack
+    bool err{false}; ///< A boolean flag set to true if the request failed. False otherwise
+    EventReason event_reason{EventReason::Unknown}; ///< Reason for the event, see @ref EventReason
+    DevErrorList errors;                            ///< The error stack
 
   private:
     void set_time();
@@ -521,6 +542,7 @@ class PipeEventData
                   const std::string &nam,
                   const std::string &evt,
                   Tango::DevicePipe *pipe_value_in,
+                  Tango::EventReason event_reason_in,
                   const DevErrorList &errors_in);
 
     ~PipeEventData();
@@ -537,12 +559,13 @@ class PipeEventData
     }
 
     ///@publicsection
-    DeviceProxy *device;    ///< The DeviceProxy object on which the call was executed
-    std::string pipe_name;  ///< The pipe name
-    std::string event;      ///< The event name
-    DevicePipe *pipe_value; ///< The pipe data
-    bool err;               ///< A boolean flag set to true if the request failed. False otherwise
-    DevErrorList errors;    ///< The error stack
+    DeviceProxy *device{nullptr};    ///< The DeviceProxy object on which the call was executed
+    std::string pipe_name;           ///< The pipe name
+    std::string event;               ///< The event name
+    DevicePipe *pipe_value{nullptr}; ///< The pipe data
+    bool err{false};                 ///< A boolean flag set to true if the request failed. False otherwise
+    EventReason event_reason{EventReason::Unknown}; ///< Reason for the event, see @ref EventReason
+    DevErrorList errors;                            ///< The error stack
 
   private:
     void set_time();
@@ -612,7 +635,7 @@ class EventQueue
 
     bool is_empty()
     {
-        return event_buffer.empty();
+        return size() == 0;
     }
 
     void get_events(EventDataList &event_list);
@@ -623,6 +646,10 @@ class EventQueue
     void get_events(CallBack *cb);
 
   private:
+    template <typename T, typename U>
+    void insert_event_helper(T elem, U &vec);
+    template <typename T, typename U>
+    void get_events_helper(T &output, U &vec);
     void inc_indexes();
 
     std::vector<EventData *> event_buffer;
@@ -638,6 +665,90 @@ class EventQueue
     omni_mutex modification_mutex;
 };
 
+//--------------------------------------------------------------------------------------------------------------------
+//
+// tries to execute user callback if specified and printout error, if failed, otherwise stores data in the event queue
+//
+//--------------------------------------------------------------------------------------------------------------------
+template <typename T>
+void safe_execute_callback_or_store_data(Tango::CallBack *callback,
+                                         T *event_data,
+                                         bool err_missed_event,
+                                         T *missed_data,
+                                         const std::string &method_name,
+                                         const std::string &event_name,
+                                         Tango::EventQueue *ev_queue)
+{
+    // if callback methods were specified, call them!
+    if(callback != nullptr)
+    {
+        try
+        {
+            if(err_missed_event)
+            {
+                callback->push_event(missed_data);
+            }
+            callback->push_event(event_data);
+        }
+        catch(const Tango::DevFailed &e)
+        {
+            Tango::ApiUtil *au = Tango::ApiUtil::instance();
+            std::stringstream ss;
+            ss << method_name << " got DevFailed exception: \n\n";
+            ss << e.errors[0].desc;
+            ss << "\nin callback method of: ";
+            ss << event_name;
+            au->print_error_message(ss.str().c_str());
+        }
+        catch(const std::exception &e)
+        {
+            Tango::ApiUtil *au = Tango::ApiUtil::instance();
+            std::stringstream ss;
+            ss << method_name << " got std::exception: \n\n";
+            ss << e.what();
+            ss << "\nin callback method of: ";
+            ss << event_name;
+            au->print_error_message(ss.str().c_str());
+        }
+        catch(...)
+        {
+            Tango::ApiUtil *au = Tango::ApiUtil::instance();
+            std::stringstream ss;
+            ss << method_name << " got unknown exception\n\n";
+            ss << "in callback method of: ";
+            ss << event_name;
+            au->print_error_message(ss.str().c_str());
+        }
+        delete event_data;
+    }
+
+    // no callback method, the event has to be inserted
+    // into the event queue
+    else
+    {
+        if(err_missed_event)
+        {
+            auto *missed_data_copy = new T;
+            *missed_data_copy = *missed_data;
+
+            ev_queue->insert_event(missed_data_copy);
+        }
+        ev_queue->insert_event(event_data);
+    }
+}
+
+// overload for calls without missed event
+template <typename T>
+void safe_execute_callback_or_store_data(CallBack *callback,
+                                         T *event_data,
+                                         const std::string &method_name,
+                                         const std::string &event_name,
+                                         EventQueue *ev_queue)
+{
+    safe_execute_callback_or_store_data(
+        callback, event_data, false, static_cast<T *>(nullptr), method_name, event_name, ev_queue);
+}
+
 } // namespace Tango
 
 #endif // _EVENTAPI_H
