@@ -34,7 +34,16 @@
 #ifndef _GROUP_H_
 #define _GROUP_H_
 
-#include <tango/tango.h>
+#include <tango/common/tango_const.h>
+#include <tango/server/tango_config.h>
+#include <tango/server/except.h>
+#include <tango/client/apiexcept.h>
+#include <tango/client/DeviceData.h>
+#include <tango/client/DeviceAttribute.h>
+
+#include <vector>
+#include <string>
+#include <map>
 
 namespace Tango
 {
@@ -52,6 +61,7 @@ namespace Tango
 //=============================================================================
 class Group;
 class GroupElement;
+class DeviceProxy;
 
 //=============================================================================
 // Misc. Typedefs
@@ -67,6 +77,7 @@ typedef std::vector<std::string> DeviceNames;
 class AsynchRequest
 {
     //- An asynch. request repository is maintain by each GroupDeviceElement
+    // NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
     friend class GroupDeviceElement;
 
   public:
@@ -678,6 +689,7 @@ class GroupElementFactory
 //=============================================================================
 // class GroupElement: base class for all tango group element
 //=============================================================================
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class GroupElement
 {
     friend class Group;
@@ -979,7 +991,7 @@ class Group : public GroupElement
     /**
      * Returns a reference to the specified device
      *
-     * Returns a reference to the specified device or NULL if there is no device by that name in the group. This
+     * Returns a reference to the specified device or nullptr if there is no device by that name in the group. This
      * method may throw an exception in case the specified device belongs to the group but can’t be reached (not
      * registered, down...). See example below. See also the Tango::DeviceProxy class documentation for details.
      * @code
@@ -1009,7 +1021,7 @@ class Group : public GroupElement
     /**
      * Returns a reference to the "idx-th" device in the hierarchy
      *
-     * Returns a reference to the "idx-th" device in the hierarchy or NULL if the hierarchy contains less than
+     * Returns a reference to the "idx-th" device in the hierarchy or nullptr if the hierarchy contains less than
      * "idx" devices. This method may throw an exception in case the specified device belongs to the group but
      * can’t be reached (not registered, down...). See previous example. See also the Tango::DeviceProxy class
      * documentation for details.
@@ -1026,7 +1038,7 @@ class Group : public GroupElement
     /**
      * Returns a reference to the "idx-th" device in the hierarchy
      *
-     * Returns a reference to the "idx-th" device in the hierarchy or NULL if the hierarchy contains less than "idx"
+     * Returns a reference to the "idx-th" device in the hierarchy or nullptr if the hierarchy contains less than "idx"
      * devices. See the Tango::DeviceProxy class documentation for details.
      * The request is systematically forwarded to subgroups (i.e. if the local set of devices contains less than
      * "idx" devices, the request is forwarded to subgroups).
@@ -1041,7 +1053,7 @@ class Group : public GroupElement
     /**
      * Returns a reference to the specified group
      *
-     * Returns a reference to the specified group or NULL if there is no group by that name. The group_name
+     * Returns a reference to the specified group or nullptr if there is no group by that name. The group_name
      * can be a fully qualified name.
      * Considering the following group:
      * @verbatim
@@ -1755,6 +1767,7 @@ class Group : public GroupElement
 //=============================================================================
 // class GroupDeviceElement: a device element
 //=============================================================================
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class GroupDeviceElement : public GroupElement
 {
     friend class Group;
