@@ -5,14 +5,67 @@
 
 #if defined(TANGO_USE_TELEMETRY)
 
+  #include <tango/common/tango_const.h>
+  #include <tango/common/log4tango/Appender.h>
   #include <tango/common/telemetry/configuration.h>
+  #include <tango/server/logging.h>
 
   #include <map>
-  #include <regex>
   #include <memory>
   #include <string>
   #include <cstring>
+  #include <cstdint>
   #include <variant>
+  #include <thread>
+
+//
+// telemetry_current_function
+//
+// Parse TANGO_CURRENT_FUNCTION to remove the return type and argument list from the
+// function signature, i.e., to only provide the fully qualified function name
+//
+constexpr std::string_view telemetry_current_function(const char *tango_current_function, const char *function_name)
+{
+    std::string_view fullname{tango_current_function};
+    std::string_view shortname{function_name};
+    // Find the function name from the right; everything to the right of the function
+    // name should only be types
+    size_t right_index = fullname.rfind(shortname);
+    if(right_index == std::string_view::npos || right_index < 1)
+    {
+        return fullname;
+    }
+
+    // The fully qualified method name will have a space before it, but class template
+    // descriptions may also contain spaces so we parse those too
+    size_t left_index = fullname.rfind(' ', right_index);
+    if(fullname.find('>', left_index) != std::string_view::npos)
+    {
+        size_t template_start = fullname.rfind('<', right_index);
+        if(template_start < left_index)
+        {
+            left_index = fullname.rfind(' ', template_start);
+        }
+    }
+    left_index = left_index == std::string_view::npos ? 0 : left_index + 1;
+
+    // Test for clang-like formatting of returned *function* pointers
+    if(fullname[left_index] == '(')
+    {
+        ++left_index;
+    }
+    // Test for clang-like formatting of returned pointers/references
+    if((fullname[left_index] == '*') || (fullname[left_index] == '&'))
+    {
+        ++left_index;
+    }
+    return fullname.substr(left_index, right_index - left_index + shortname.size());
+}
+
+    // clang-format off
+  #define TELEMETRY_CURRENT_FUNCTION                         \
+      std::string{telemetry_current_function(TANGO_CURRENT_FUNCTION,__func__)}
+// clang-format on
 
 namespace Tango::telemetry
 {
@@ -450,7 +503,7 @@ class Interface
     //! you know what you're doing. A misusage of the \p kind parameter can notably created some side effects on backend
     //! side.
     //
-    //! For consistency reasons, it is recommended to use the TANGO_CURRENT_FUNCTION macro to name the new span.
+    //! For consistency reasons, it is recommended to use the TELEMETRY_CURRENT_FUNCTION macro to name the new span.
     //! Some attributes can be attached to the new span. Use \ref Span::set_attribute to add an individual attribute
     //! to the span.
     //!
@@ -460,11 +513,11 @@ class Interface
     //!
     //! Example:
     //! @code
-    //! auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION, {{"key", "value"}});
+    //! auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION, {{"key", "value"}});
     //! auto scope = Tango::telemetry::Interface::Scope(span);
     //! @endcode
     //!
-    //! @param name the name of the Span - use TANGO_CURRENT_FUNCTION unless you want to specify a particular name.
+    //! @param name the name of the Span - use TELEMETRY_CURRENT_FUNCTION unless you want to specify a particular name.
     //! @param attributes a std::map of key/value pairs where the key is a std::string and the value an
     //! AttributeValue.
     //! @param kind the Span::Kind - defaults to Span::Kind::kInternal.
@@ -504,7 +557,7 @@ class Interface
     //!
     //! Example:
     //! @code
-    //! auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION);
+    //! auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION);
     //! auto scope = TANGO_TELEMETRY_SCOPE(span);
     //! @endcode
     //!
@@ -800,7 +853,7 @@ class InterfaceScope
     //!     // The scope makes use of teh RAII paradigm to control how long the span remains
     //!     // active. The active span will be the parent of any span created downstream.
     //!     //-----------------------------------------------------------------------------------
-    //!     auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION);
+    //!     auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION);
     //!     auto scope = TANGO_TELEMETRY_SCOPE(span);
     //!
     //!     // -----------------------------------------------------------------------------------
@@ -868,7 +921,7 @@ class InterfaceScope
     //!        auto interface_scope = TANGO_TELEMETRY_ACTIVE_INTERFACE(tti);
     //!
     //!        // create the client root span (i.e., the parent of any span created in this thread)
-    //!        auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION);
+    //!        auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION);
     //!        auto scope = TANGO_TELEMETRY_SCOPE(span);
     //!
     //!        while (go_on)
@@ -891,8 +944,8 @@ class InterfaceScope
     //!
     //! \code
     //!
-    //!   auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION);
-    //!   auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION, {{"myKey", "myValue"}});
+    //!   auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION);
+    //!   auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION, {{"myKey", "myValue"}});
     //!
     //! \endcode
     //!
@@ -908,7 +961,7 @@ class InterfaceScope
     //!
     //! \code
     //!
-    //!    auto span = TANGO_TELEMETRY_SPAN(TANGO_CURRENT_FUNCTION);
+    //!    auto span = TANGO_TELEMETRY_SPAN(TELEMETRY_CURRENT_FUNCTION);
     //!    auto scope = TANGO_TELEMETRY_SCOPE(span);
     //!
     //! \endcode
@@ -929,13 +982,13 @@ class InterfaceScope
     //!
     //! @param [in] MSG -- annotation to attach to the current span
     //! @ingroup TelMacros
-  #define TANGO_TELEMETRY_ADD_EVENT(MSG)                                                        \
-      {                                                                                         \
-          auto current_span = Tango::telemetry::Interface::get_current() -> get_current_span(); \
-          if(current_span)                                                                      \
-          {                                                                                     \
-              current_span->add_event(MSG);                                                     \
-          }                                                                                     \
+  #define TANGO_TELEMETRY_ADD_EVENT(MSG)                                                      \
+      {                                                                                       \
+          auto current_span = Tango::telemetry::Interface::get_current()->get_current_span(); \
+          if(current_span)                                                                    \
+          {                                                                                   \
+              current_span->add_event(MSG);                                                   \
+          }                                                                                   \
       }
 
     //! Add an attribute to the current span.
@@ -954,13 +1007,13 @@ class InterfaceScope
     //! @param [in] KEY -- telemetry attribute key
     //! @param [in] VALUE -- telemetry attribute value
     //! @ingroup TelMacros
-  #define TANGO_TELEMETRY_ADD_ATTRIBUTE(KEY, VALUE)                                             \
-      {                                                                                         \
-          auto current_span = Tango::telemetry::Interface::get_current() -> get_current_span(); \
-          if(current_span)                                                                      \
-          {                                                                                     \
-              current_span->set_attribute(KEY, VALUE);                                          \
-          }                                                                                     \
+  #define TANGO_TELEMETRY_ADD_ATTRIBUTE(KEY, VALUE)                                           \
+      {                                                                                       \
+          auto current_span = Tango::telemetry::Interface::get_current()->get_current_span(); \
+          if(current_span)                                                                    \
+          {                                                                                   \
+              current_span->set_attribute(KEY, VALUE);                                        \
+          }                                                                                   \
       }
 
     //! Set the error status of the current span.
@@ -984,13 +1037,13 @@ class InterfaceScope
     //!
     //! @param [in] DESC -- description of the error
     //! @ingroup TelMacros
-  #define TANGO_TELEMETRY_SET_ERROR_STATUS(DESC)                                                \
-      {                                                                                         \
-          auto current_span = Tango::telemetry::Interface::get_current() -> get_current_span(); \
-          if(current_span->get_status() != Tango::telemetry::Span::Status::kError)              \
-          {                                                                                     \
-              current_span->set_status(Tango::telemetry::Span::Status::kError, DESC);           \
-          }                                                                                     \
+  #define TANGO_TELEMETRY_SET_ERROR_STATUS(DESC)                                              \
+      {                                                                                       \
+          auto current_span = Tango::telemetry::Interface::get_current()->get_current_span(); \
+          if(current_span->get_status() != Tango::telemetry::Span::Status::kError)            \
+          {                                                                                   \
+              current_span->set_status(Tango::telemetry::Span::Status::kError, DESC);         \
+          }                                                                                   \
       }
 
 } // namespace Tango::telemetry
