@@ -32,17 +32,26 @@
 #ifndef _ATTRIBUTE_H
 #define _ATTRIBUTE_H
 
-#include <tango/tango.h>
+#include <tango/common/tango_type_traits.h>
 #include <tango/server/attrdesc.h>
 #include <tango/server/fwdattrdesc.h>
+#include <tango/server/classattribute.h>
 #include <tango/server/encoded_attribute.h>
 #include <tango/server/tango_clock.h>
+#include <tango/server/attrprop.h>
+#include <tango/server/logging.h>
 #include <tango/client/apiexcept.h>
+#include <tango/client/DbDatum.h>
 #include <tango/server/exception_reason_consts.h>
+#include <tango/common/utils/assert.h>
+#include <tango/server/tango_config.h>
 
-#include <functional>
 #include <iterator>
 #include <type_traits>
+#include <variant>
+#include <vector>
+#include <map>
+#include <string>
 
 namespace Tango
 {
@@ -68,69 +77,161 @@ typedef union _Attr_CheckVal
      * Does not manage memory.
      */
     template <class T>
-    const T &get_value();
+    const T &get_value() const;
 } Attr_CheckVal;
 
 template <>
-inline const Tango::DevShort &Attr_CheckVal::get_value()
+inline const Tango::DevShort &Attr_CheckVal::get_value() const
 {
     return sh;
 }
 
 template <>
-inline const Tango::DevLong &Attr_CheckVal::get_value()
+inline const Tango::DevLong &Attr_CheckVal::get_value() const
 {
     return lg;
 }
 
 template <>
-inline const Tango::DevDouble &Attr_CheckVal::get_value()
+inline const Tango::DevDouble &Attr_CheckVal::get_value() const
 {
     return db;
 }
 
 template <>
-inline const Tango::DevFloat &Attr_CheckVal::get_value()
+inline const Tango::DevFloat &Attr_CheckVal::get_value() const
 {
     return fl;
 }
 
 template <>
-inline const Tango::DevUShort &Attr_CheckVal::get_value()
+inline const Tango::DevUShort &Attr_CheckVal::get_value() const
 {
     return ush;
 }
 
 template <>
-inline const Tango::DevUChar &Attr_CheckVal::get_value()
+inline const Tango::DevUChar &Attr_CheckVal::get_value() const
 {
     return uch;
 }
 
 template <>
-inline const Tango::DevLong64 &Attr_CheckVal::get_value()
+inline const Tango::DevLong64 &Attr_CheckVal::get_value() const
 {
     return lg64;
 }
 
 template <>
-inline const Tango::DevULong &Attr_CheckVal::get_value()
+inline const Tango::DevULong &Attr_CheckVal::get_value() const
 {
     return ulg;
 }
 
 template <>
-inline const Tango::DevULong64 &Attr_CheckVal::get_value()
+inline const Tango::DevULong64 &Attr_CheckVal::get_value() const
 {
     return ulg64;
 }
 
 template <>
-inline const Tango::DevState &Attr_CheckVal::get_value()
+inline const Tango::DevState &Attr_CheckVal::get_value() const
 {
     return d_sta;
 }
 
+class AttrValue
+{
+  public:
+    // Define a variant type that holds unique pointers to each allowed array type.
+    using ValueVariant = std::variant<std::monostate, // Represents an empty state.
+                                      std::unique_ptr<DevVarShortArray>,
+                                      std::unique_ptr<DevVarLongArray>,
+                                      std::unique_ptr<DevVarFloatArray>,
+                                      std::unique_ptr<DevVarDoubleArray>,
+                                      std::unique_ptr<DevVarStringArray>,
+                                      std::unique_ptr<DevVarUShortArray>,
+                                      std::unique_ptr<DevVarBooleanArray>,
+                                      std::unique_ptr<DevVarCharArray>,
+                                      std::unique_ptr<DevVarLong64Array>,
+                                      std::unique_ptr<DevVarULongArray>,
+                                      std::unique_ptr<DevVarULong64Array>,
+                                      std::unique_ptr<DevVarStateArray>,
+                                      std::unique_ptr<DevVarEncodedArray>>;
+
+    AttrValue() :
+        data_{std::monostate{}}
+    {
+    }
+
+    // Setter: accepts a smart pointer to one of the allowed types.
+    template <typename T>
+    void set(std::unique_ptr<T> value)
+    {
+        TANGO_LOG_DEBUG << "AttrValue::set()" << std::endl;
+        static_assert(is_valid<T>(), "Type not allowed in AttrValue");
+        data_ = std::move(value);
+    }
+
+    // Getter: returns a raw pointer (or nullptr if the stored type doesn't match).
+    template <typename T>
+    T *get()
+    {
+        TANGO_LOG_DEBUG << "AttrValue::get()" << std::endl;
+        static_assert(is_valid<T>(), "Type not allowed in AttrValue");
+        if(auto ptr = std::get_if<std::unique_ptr<T>>(&data_))
+        {
+            return ptr->get(); //
+        }
+        return nullptr;
+    }
+
+    template <typename T>
+    std::unique_ptr<T> release()
+    {
+        TANGO_LOG_DEBUG << "AttrValue::release()" << std::endl;
+
+        static_assert(is_valid<T>(), "Type not allowed in AttrValue");
+        if(auto ptr = std::get_if<std::unique_ptr<T>>(&data_))
+        {
+            std::unique_ptr<T> temp = std::move(*ptr);
+            data_ = std::monostate{};
+            return temp;
+        }
+        return nullptr;
+    }
+
+    // Reset clears any stored value. After calling reset, has_value() returns false.
+    void reset()
+    {
+        TANGO_LOG_DEBUG << "AttrValue::reset()" << std::endl;
+        data_ = std::monostate{};
+    }
+
+    // Check if any value is set.
+    bool has_value() const
+    {
+        TANGO_LOG_DEBUG << "AttrValue::has_value()" << std::endl;
+        return !std::holds_alternative<std::monostate>(data_);
+    }
+
+  private:
+    ValueVariant data_;
+
+    // Helper to restrict the types that can be stored.
+    template <typename T>
+    static constexpr bool is_valid()
+    {
+        return std::is_same_v<T, DevVarShortArray> || std::is_same_v<T, DevVarLongArray> ||
+               std::is_same_v<T, DevVarFloatArray> || std::is_same_v<T, DevVarDoubleArray> ||
+               std::is_same_v<T, DevVarStringArray> || std::is_same_v<T, DevVarUShortArray> ||
+               std::is_same_v<T, DevVarBooleanArray> || std::is_same_v<T, DevVarCharArray> ||
+               std::is_same_v<T, DevVarLong64Array> || std::is_same_v<T, DevVarULongArray> ||
+               std::is_same_v<T, DevVarULong64Array> || std::is_same_v<T, DevVarStateArray> ||
+               std::is_same_v<T, DevVarEncodedArray>;
+    }
+};
+
 typedef union _Attr_Value
 {
     DevVarShortArray *sh_seq;
@@ -163,16 +264,6 @@ struct LastAttrValue
                DevFailed *);
 };
 
-typedef enum prop_type
-{
-    MIN_VALUE = 0,
-    MAX_VALUE,
-    MIN_WARNING,
-    MAX_WARNING,
-    MIN_ALARM,
-    MAX_ALARM
-} PropType;
-
 class EventSupplier;
 
 //=============================================================================
@@ -638,8 +729,8 @@ class Attribute
      *
      * @param props A MultiAttrProp object.
      */
-    template <typename T>
-    void get_properties(Tango::MultiAttrProp<T> &props);
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
+    void get_properties(MultiAttrProp<T> &);
     /**
      * Set all modifiable attribute properties in one call
      *
@@ -648,8 +739,8 @@ class Attribute
      *
      * @param props A MultiAttrProp object.
      */
-    template <typename T>
-    void set_properties(Tango::MultiAttrProp<T> &props);
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
+    void set_properties(const MultiAttrProp<T> &);
     /**
      * Set attribute serialization model
      *
@@ -716,9 +807,31 @@ class Attribute
      * @exception DevFailed If the attribute data type is not coherent, enum labels are not defined, wrong size of data,
      * or wrong Enum value.
      */
-    template <class T, std::enable_if_t<!std::is_enum_v<T> || std::is_same_v<T, Tango::DevState>, T> * = nullptr>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void set_value(T *p_data, long x = 1, long y = 0, bool release = false);
 
+    /**
+     * This method stores the attribute value inside the Attribute object and set current time as readout time
+     *
+     * The value will be later send to the client either as result of attribute readout of event value,
+     * or utilized to define current device State (when reading device State and warning/alarm levels are defined)
+     *
+     * After readout value will be destroyed.
+     *
+     * When release is true, we expect p_data to be allocated with operator new for SCALAR attributes and operator new[]
+     * otherwise. For the DevString's, when release is true we expect value to have been allocated with
+     * Tango::string_dup or equivalent.
+     *
+     * @param Tango::DevEncoded *p_data: pointer to value
+     * @param long x=1: the attribute x dimension
+     * @param long y=0: the attribute y dimension
+     * @param bool release: The release flag. If true, memory pointed to by p_data will be
+     *           freed after being send to the client. Default value is false.
+     * @exception DevFailed If the attribute data type is not coherent, enum labels are not defined, wrong size of data,
+     * or wrong Enum value.
+     */
+    void set_value(Tango::DevEncoded *p_data, long x = 1, long y = 0, bool release = false);
+
     /**
      * This is special realization for scalar C++11 scoped enum with short as underlying data type or old enum of
      * set_value method to store the attribute value inside the Attribute object, and set current time as readout time
@@ -1165,8 +1278,9 @@ class Attribute
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    template <typename T>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void set_min_alarm(const T &new_min_alarm);
+    void set_min_alarm(const std::string &new_min_alarm);
 
     /**
      * Set attribute minimum alarm.
@@ -1198,7 +1312,7 @@ class Attribute
      * @param min_al Reference to a variable which value will be set to the attribute's
      * minimum alarm
      */
-    template <typename T>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void get_min_alarm(T &min_al);
 
     /**
@@ -1211,8 +1325,10 @@ class Attribute
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    template <typename T>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void set_max_alarm(const T &new_max_alarm);
+    void set_max_alarm(const std::string &new_max_alarm);
+
     /**
      * Set attribute maximum alarm.
      *
@@ -1243,7 +1359,7 @@ class Attribute
      * @param max_al Reference to a variable which value will be set to the attribute's
      * maximum alarm
      */
-    template <typename T>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void get_max_alarm(T &max_al);
 
     /**
@@ -1256,8 +1372,10 @@ class Attribute
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    template <typename T>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void set_min_warning(const T &new_min_warning);
+    void set_min_warning(const std::string &new_min_warning);
+
     /**
      * Set attribute minimum warning.
      *
@@ -1288,8 +1406,8 @@ class Attribute
      * @param min_war Reference to a variable which value will be set to the attribute's
      * minimum warning
      */
-    template <typename T>
-    void get_min_warning(T &min_war);
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
+    void get_min_warning(T &min_warning);
 
     /**
      * Set attribute maximum warning.
@@ -1301,8 +1419,10 @@ class Attribute
      * Click <a href="https://tango-controls.readthedocs.io/en/latest/development/advanced/IDL.html#exceptions">here</a>
      * to read <b>DevFailed</b> exception specification
      */
-    template <typename T>
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
     void set_max_warning(const T &new_max_warning);
+    void set_max_warning(const std::string &new_max_warning);
+
     /**
      * Set attribute maximum warning.
      *
@@ -1333,17 +1453,13 @@ class Attribute
      * @param max_war Reference to a variable which value will be set to the attribute's
      * maximum warning
      */
-    template <typename T>
-    void get_max_warning(T &max_war);
+    template <class T, std::enable_if_t<Tango::is_tango_base_type_v<T>> * = nullptr>
+    void get_max_warning(T &max_warning);
     //@}
 
   protected:
     /**@name Class data members */
     //@{
-    /**
-     * A flag set to true if the attribute value has been updated
-     */
-    bool value_flag;
     /**
      * The date when attribute was read
      */
@@ -1484,7 +1600,7 @@ class Attribute
     /**
      * The attribute value
      */
-    Tango::Attr_Value value;
+    Tango::AttrValue attribute_value;
     /**
      * The attribute data size
      */
@@ -1519,10 +1635,13 @@ class Attribute
     /// @privatesection
     /**
      * Returns the internal buffer to keep data of this type.
-     * It does not do any memory management
+     * Buffer is saved in as std::unique_ptr
      */
     template <class T>
-    T **get_value_storage();
+    T *get_value_storage()
+    {
+        return attribute_value.get<T>(); // Temporary, non-owning access
+    }
 
     //
     // methods not usable for the external world (outside the lib)
@@ -1560,8 +1679,12 @@ class Attribute
         set_upd_properties(_c, d_name);
     }
 
-    template <typename T>
-    void set_upd_properties(const T &, const std::string &, bool f_s = false);
+    void set_upd_properties(const AttributeConfig &);
+    void set_upd_properties(const AttributeConfig_3 &);
+    void set_upd_properties(const AttributeConfig_5 &);
+    void set_upd_properties(const AttributeConfig &, const std::string &, bool f_s = false);
+    void set_upd_properties(const AttributeConfig_3 &, const std::string &, bool f_s = false);
+    void set_upd_properties(const AttributeConfig_5 &, const std::string &, bool f_s = false);
 
     template <typename T>
     void delete_data_if_needed(T *data, bool release);
@@ -1590,67 +1713,67 @@ class Attribute
 
     Tango::DevVarShortArray *get_short_value()
     {
-        return value.sh_seq;
+        return attribute_value.get<Tango::DevVarShortArray>();
     }
 
     Tango::DevVarLongArray *get_long_value()
     {
-        return value.lg_seq;
+        return attribute_value.get<Tango::DevVarLongArray>();
     }
 
     Tango::DevVarDoubleArray *get_double_value()
     {
-        return value.db_seq;
+        return attribute_value.get<Tango::DevVarDoubleArray>();
     }
 
     Tango::DevVarStringArray *get_string_value()
     {
-        return value.str_seq;
+        return attribute_value.get<Tango::DevVarStringArray>();
     }
 
     Tango::DevVarFloatArray *get_float_value()
     {
-        return value.fl_seq;
+        return attribute_value.get<Tango::DevVarFloatArray>();
     }
 
     Tango::DevVarBooleanArray *get_boolean_value()
     {
-        return value.boo_seq;
+        return attribute_value.get<Tango::DevVarBooleanArray>();
     }
 
     Tango::DevVarUShortArray *get_ushort_value()
     {
-        return value.ush_seq;
+        return attribute_value.get<Tango::DevVarUShortArray>();
     }
 
     Tango::DevVarCharArray *get_uchar_value()
     {
-        return value.cha_seq;
+        return attribute_value.get<Tango::DevVarCharArray>();
     }
 
     Tango::DevVarLong64Array *get_long64_value()
     {
-        return value.lg64_seq;
+        return attribute_value.get<Tango::DevVarLong64Array>();
     }
 
     Tango::DevVarULongArray *get_ulong_value()
     {
-        return value.ulg_seq;
+        return attribute_value.get<Tango::DevVarULongArray>();
     }
 
     Tango::DevVarULong64Array *get_ulong64_value()
     {
-        return value.ulg64_seq;
+        return attribute_value.get<Tango::DevVarULong64Array>();
     }
 
     Tango::DevVarStateArray *get_state_value()
     {
-        return value.state_seq;
+        return attribute_value.get<Tango::DevVarStateArray>();
     }
 
     Tango::DevVarEncodedArray *get_encoded_value()
     {
-        return value.enc_seq;
+        return attribute_value.get<Tango::DevVarEncodedArray>();
     }
 
     unsigned long get_name_size()
@@ -1663,14 +1786,14 @@ class Attribute
         return name_lower;
     }
 
-    void set_value_flag(bool val)
+    void reset_value()
     {
-        value_flag = val;
+        attribute_value.reset();
     }
 
-    bool get_value_flag()
+    bool value_is_set() const
     {
-        return value_flag;
+        return attribute_value.has_value();
     }
 
     DispLevel get_disp_level()
@@ -2053,7 +2176,6 @@ class Attribute
 
     bool check_level_alarm();
     bool check_warn_alarm();
-    void upd_att_prop_db(const Tango::Attr_CheckVal &, const char *);
     DeviceClass *get_att_device_class(const std::string &);
 
     template <typename T>
@@ -2064,12 +2186,7 @@ class Attribute
 
     void check_hard_coded(const AttributeConfig_5 &);
 
-    void delete_startup_exception(std::string, std::string str = std::string("None"));
-
     void throw_hard_coded_prop(const char *);
-    void throw_err_format(const char *, const std::string &, const char *);
-    void throw_incoherent_val_err(const char *, const char *, const std::string &, const char *);
-    void throw_err_data_type(const char *, const std::string &, const char *);
     void validate_change_properties(const std::string &,
                                     const char *,
                                     std::string &,
@@ -2077,17 +2194,12 @@ class Attribute
                                     std::vector<bool> &,
                                     std::vector<bool> &);
     void validate_change_properties(const std::string &, const char *, std::string &, std::vector<double> &);
-    bool prop_in_list(const char *, std::string &, size_t, const std::vector<AttrProperty> &);
     void set_format_notspec();
     bool is_format_notspec(const char *);
     void def_format_in_dbdatum(DbDatum &);
 
-    void avns_in_db(const char *, const std::string &);
-    void avns_in_att(prop_type);
-
     void convert_prop_value(const char *, std::string &, Attr_CheckVal &, const std::string &);
 
-    void check_range_coherency(const std::string &);
     void db_access(const struct CheckOneStrProp &, const std::string &);
     void set_prop_5_specific(const AttributeConfig_5 &, const std::string &, bool, std::vector<AttPropDb> &);
     void build_check_enum_labels(const std::string &);
@@ -2343,51 +2455,6 @@ inline void Attribute::throw_startup_exception(const char *origin)
     }
 }
 
-//+------------------------------------------------------------------------------------------------------------------
-//
-// method :
-//        Attribute::prop_in_list
-//
-// description :
-//        Search for a property in a list
-//
-// args:
-//        in :
-//            - prop_name : The property name
-//          - list_size : The size list
-//          - list : The list
-//      out :
-//            - prop_str : String initialized with prop. value (if found)
-//
-//------------------------------------------------------------------------------------------------------------------
-
-inline bool Attribute::prop_in_list(const char *prop_name,
-                                    std::string &prop_str,
-                                    size_t list_size,
-                                    const std::vector<AttrProperty> &list)
-{
-    bool ret = false;
-
-    if(list_size != 0)
-    {
-        size_t i;
-        for(i = 0; i < list_size; i++)
-        {
-            if(list[i].get_name() == prop_name)
-            {
-                break;
-            }
-        }
-        if(i != list_size)
-        {
-            prop_str = list[i].get_value();
-            ret = true;
-        }
-    }
-
-    return ret;
-}
-
 inline void Attribute::set_change_event_sub(int cl_lib)
 {
     switch(cl_lib)
@@ -2577,6 +2644,61 @@ inline void Attribute::delete_data_if_needed<Tango::DevString>(Tango::DevString
     }
 }
 
+/*
+ * method: Attribute::set_value_date_quality
+ *
+ * These methods store the attribute value inside the Attribute object,
+ * with readout time and attribute quality factor provided by user.
+ *
+ *
+ */
+
+template <class T>
+inline void
+    Attribute::set_value_date_quality(T *p_data, time_t t, Tango::AttrQuality qual, long x, long y, bool release)
+{
+    set_value(p_data, x, y, release);
+    set_quality(qual, false);
+    set_date(t);
+
+    if(qual == Tango::ATTR_INVALID)
+    {
+        delete_seq();
+    }
+}
+
+template <class T>
+inline void Attribute::set_value_date_quality(
+    T *p_data, const TangoTimestamp &t, Tango::AttrQuality qual, long x, long y, bool release)
+{
+    set_value(p_data, x, y, release);
+    set_quality(qual, false);
+    set_date(t);
+
+    if(qual == Tango::ATTR_INVALID)
+    {
+        delete_seq();
+    }
+}
+
+template <>
+inline void Attribute::set_value_date_quality(
+    Tango::DevEncoded *p_data, time_t t, Tango::AttrQuality qual, long x, long y, bool release)
+{
+    set_value(p_data, x, y, release);
+    set_quality(qual, false);
+    set_date(t);
+}
+
+template <>
+inline void Attribute::set_value_date_quality(
+    Tango::DevEncoded *p_data, const TangoTimestamp &t, Tango::AttrQuality qual, long x, long y, bool release)
+{
+    set_value(p_data, x, y, release);
+    set_quality(qual, false);
+    set_date(t);
+}
+
 //
 // Macro to help coding
 //
@@ -2597,11 +2719,11 @@ inline void Attribute::delete_data_if_needed<Tango::DevString>(Tango::DevString
 //
 
 #define CHECK_PTR(A, B)                                         \
-    if(A == NULL)                                               \
+    if(A == nullptr)                                            \
     {                                                           \
         std::stringstream o;                                    \
         o << "Data pointer for attribute " << B << " is NULL!"; \
-        TANGO_THROW_EXCEPTION(API_AttrOptProp, o.str());        \
+        TANGO_THROW_EXCEPTION(Tango::API_AttrOptProp, o.str()); \
     }                                                           \
     else                                                        \
         (void) 0
