@@ -33,11 +33,11 @@
 #ifndef _DINTRTHREAD_H
 #define _DINTRTHREAD_H
 
+#include <tango/server/devintr.h>
+
 namespace Tango
 {
 
-class DevIntr;
-
 //=================================================================================================================
 //
 //            The DevIntrThCmd structure
@@ -63,7 +63,7 @@ struct _ShDevIntrTh
     #undef interface
   #endif
 #endif
-    DevIntr interface; // Device interface
+    Tango::DevIntr interface; // Device interface
 };
 typedef struct _ShDevIntrTh ShDevIntrTh;
 
@@ -86,6 +86,7 @@ enum DevIntrCmdType
 
 class TangoMonitor;
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class DevIntrThread : public omni_thread
 {
   public:
@@ -103,6 +104,9 @@ class DevIntrThread : public omni_thread
     DeviceImpl *dev;
 
     ShDevIntrTh local_cmd;
+
+  private:
+    ~DevIntrThread() override = default;
 };
 
 } // namespace Tango
