@@ -37,12 +37,22 @@
 #ifndef _DSERVER_H
 #define _DSERVER_H
 
-#include <tango/tango.h>
+#include <tango/common/tango_const.h>
+#include <tango/common/tango_base_class.h>
+#include <tango/server/tango_config.h>
 #include <tango/server/event_subscription_state.h>
 #include <tango/server/tango_clock.h>
 
+#include <algorithm>
+#include <string>
+#include <vector>
+#include <map>
+
 namespace Tango
 {
+class DeviceClass;
+class DServer;
+struct PollingThreadInfo;
 
 void call_delete(DeviceClass *dev_class_ptr);
 
@@ -71,6 +81,7 @@ struct MulticastParameters
 
 typedef void (*ClassFactoryFuncPtr)(DServer *);
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class KillThread;
 
 class DServer : public TANGO_BASE_CLASS
@@ -82,6 +93,8 @@ class DServer : public TANGO_BASE_CLASS
     Tango::DevVarStringArray *query_class();
     Tango::DevVarStringArray *query_device();
     Tango::DevVarStringArray *query_sub_device();
+    Tango::DevString query_event_system();
+    void enable_event_system_perf_mon(Tango::DevBoolean enabled);
     void kill();
     void restart(const std::string &);
     void restart_server();
@@ -280,6 +293,7 @@ class DServer : public TANGO_BASE_CLASS
     static KillThread *kill_thread;
 };
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class KillThread : public omni_thread
 {
   public:
@@ -289,8 +303,12 @@ class KillThread : public omni_thread
     {
         start_undetached();
     }
+
+  private:
+    ~KillThread() override = default;
 };
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class ServRestartThread : public omni_thread
 {
   public:
@@ -300,6 +318,9 @@ class ServRestartThread : public omni_thread
     }
 
     void run(void *) override;
+
+  private:
+    ~ServRestartThread() override = default;
 };
 
 struct Pol
