@@ -41,7 +41,9 @@
 #ifndef _DSERVERCLASS_H
 #define _DSERVERCLASS_H
 
-#include <tango/tango.h>
+#include <tango/server/command.h>
+
+#include <string>
 
 namespace Tango
 {
@@ -151,6 +153,55 @@ class DevQuerySubDeviceCmd : public Command
     CORBA::Any *execute(DeviceImpl *device, const CORBA::Any &in_any) override;
 };
 
+//=============================================================================
+//
+//            The DevQueryEventSystemCmd class
+//
+// description :    Class to implement the DevQueryEventSystem command. This
+//            command does not take any input argument and returns a
+//            single string containing a JSON object holding information about
+//            the ZMQ event supplier and consumer.
+//
+//=============================================================================
+
+class DevQueryEventSystemCmd : public Command
+{
+  public:
+    DevQueryEventSystemCmd(const char *cmd_name, Tango::CmdArgType argin, Tango::CmdArgType argout, const char *desc);
+
+    ~DevQueryEventSystemCmd() override = default;
+
+    CORBA::Any *execute(DeviceImpl *device, const CORBA::Any &in_any) override;
+};
+
+//=============================================================================
+//
+//            The DevEnableEventSystemPerfMonCmd class
+//
+// description :    Class to implement the EnableEventSystemPerfMon command. This
+//            command does takes a boolean input argument and does not return anything.
+//
+//            If called with true, performance samples will be collected for
+//            events being published and received by the server.  These
+//            performance samples can then be queried with the QueryEventSystem.
+//
+//            If called with false, collection of performance samples with stop.
+//
+//=============================================================================
+
+class DevEnableEventSystemPerfMonCmd : public Command
+{
+  public:
+    DevEnableEventSystemPerfMonCmd(const char *cmd_name,
+                                   Tango::CmdArgType argin,
+                                   Tango::CmdArgType argout,
+                                   const char *desc);
+
+    ~DevEnableEventSystemPerfMonCmd() override = default;
+
+    CORBA::Any *execute(DeviceImpl *device, const CORBA::Any &in_any) override;
+};
+
 //=============================================================================
 //
 //            The DevKillCmd class
