@@ -37,12 +37,25 @@
 #ifndef _DSERVERSIGNAL_H
 #define _DSERVERSIGNAL_H
 
-#include <tango/tango.h>
-#include <signal.h>
+#include <tango/common/omnithread_wrapper.h>
+
+#include <vector>
+#include <condition_variable>
+#include <deque>
+#include <memory>
+#include <csignal>
+
+#ifdef _TG_WINDOWS_
+struct sigaction
+{
+    void (*sa_handler)(int);
+};
+#endif
 
 namespace Tango
 {
-
+class DeviceClass;
+class DeviceImpl;
 //=============================================================================
 //
 //            The DServerSignal class
@@ -52,7 +65,7 @@ namespace Tango
 //
 //=============================================================================
 
-#if(defined(_TG_WINDOWS_) || (defined __APPLE__) || (defined __freebsd__))
+#if (defined(_TG_WINDOWS_) || (defined __APPLE__) || (defined __freebsd__))
   #define _NSIG NSIG
 #endif
 
@@ -60,23 +73,52 @@ typedef struct
 {
     std::vector<DeviceClass *> registered_classes;
     std::vector<DeviceImpl *> registered_devices;
-    bool own_handler;
 } DevSigAction;
 
-class DServerSignal : public TangoMonitor
+template <typename T>
+class SynchronisedQueue
+{
+    std::condition_variable cv;
+    std::mutex mutex;
+    std::deque<T> values;
+
+  public:
+    void put(T value)
+    {
+        {
+            std::lock_guard<std::mutex> lock{mutex};
+            values.push_back(value);
+        }
+        cv.notify_one();
+    }
+
+    T get()
+    {
+        std::unique_lock<std::mutex> lock{mutex};
+        cv.wait(lock, [this] { return !values.empty(); });
+        auto value = values.front();
+        values.pop_front();
+        lock.unlock();
+        return value;
+    }
+};
+
+class DServerSignal
 {
   public:
     static DServerSignal *instance();
     static void cleanup_singleton();
+    static void initialise_signal_names();
 
     ~DServerSignal();
 
+    void initialise();
+
 #ifndef _TG_WINDOWS_
     void register_class_signal(long, bool, DeviceClass *);
     void register_dev_signal(long, bool, DeviceImpl *);
 
     void register_handler(long, bool);
-    pid_t get_sig_thread_pid();
 #else
     void register_class_signal(long, DeviceClass *);
     void register_dev_signal(long, DeviceImpl *);
@@ -91,50 +133,34 @@ class DServerSignal : public TangoMonitor
 
     void unregister_handler(long);
 
-    static void main_sig_handler(int);
-
+    // NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
     class ThSig : public omni_thread
     {
         DServerSignal *ds;
 
       public:
         ThSig(DServerSignal *d) :
-            ds(d),
-            my_pid(0)
-
+            ds(d)
         {
         }
 
-        ~ThSig() override { }
-
-        TangoSys_Pid my_pid;
-        bool th_data_created{false};
-#ifndef _TG_WINDOWS_
-        pthread_t my_thread;
-#endif
         void *run_undetached(void *) override;
 
         void start()
         {
             start_undetached();
         }
+
+      private:
+        ~ThSig() override = default;
     };
     friend class ThSig;
     ThSig *sig_th;
 
   protected:
-    DServerSignal();
+    DServerSignal() = default;
     static DevSigAction reg_sig[_NSIG];
-
-    bool sig_to_install;
-    bool sig_to_remove;
-    bool sig_th_should_stop = false;
-    int inst_sig;
-    int rem_sig;
-#ifdef _TG_WINDOWS_
-    static HANDLE win_ev;
-    static int win_signo;
-#endif
+    static void deliver_to_registered_handlers(int signo);
 
   private:
     static std::unique_ptr<DServerSignal> _instance;
@@ -144,26 +170,26 @@ class DServerSignal : public TangoMonitor
     std::vector<DeviceClass *>::iterator find_class(long, DeviceClass *);
     std::vector<DeviceClass *>::iterator find_delayed_class(long, DeviceClass *);
 
-#ifdef _TG_WINDOWS_
-    static inline bool auto_signal(long s)
-    {
-        if((s == SIGINT) || (s == SIGTERM) || (s == SIGABRT) || (s == SIGBREAK))
-        {
-            return true;
-        }
-        else
-        {
-            return false;
-        }
-    }
-#else
     static bool auto_signal(long s)
     {
-        return (s == SIGQUIT) || (s == SIGINT) || (s == SIGHUP) || (s == SIGTERM);
-    }
+#ifdef _TG_WINDOWS_
+        return (s == SIGINT) || (s == SIGTERM) || (s == SIGABRT) || (s == SIGBREAK);
+#else
+        return (s == SIGINT) || (s == SIGTERM) || (s == SIGQUIT) || (s == SIGHUP);
 #endif
+    }
 
     static std::string sig_name[_NSIG];
+    struct sigaction enqueueing_sa;
+    struct sigaction direct_sa;
+    struct sigaction default_sa;
+
+    void handle_on_signal_thread(int signo);
+    void handle_directly(int signo);
+    void handle_with_default(int signo);
+
+    SynchronisedQueue<int> signal_queue;
+    static constexpr int STOP_SIGNAL_THREAD = -1;
 };
 
 } // End of namespace Tango
