@@ -44,6 +44,7 @@
 
 #include <tango/server/except.h>
 #include <tango/server/tango_clock.h>
+#include <tango/server/blackbox.h>
 
 #if defined(_TG_WINDOWS_) && defined(_USRDLL) && !defined(_TANGO_LIB)
   #define USE_stub_in_nt_dll
@@ -61,12 +62,13 @@
 
 #include <tango/client/eventconsumer.h>
 
-#include <omnithread.h>
+#include <tango/common/omnithread_wrapper.h>
 #ifndef _TG_WINDOWS_
   #include <sys/time.h>
 #endif
 
 #include <chrono>
+#include <list>
 
 namespace Tango
 {
@@ -397,6 +399,9 @@ class ZmqEventSupplier : public EventSupplier
                                        const std::string &obj_name_lower,
                                        bool intr_change);
 
+    void query_event_system(std::ostream &os);
+    static void enable_perf_mon(Tango::DevBoolean enabled);
+
   protected:
     ZmqEventSupplier(Util *);
 
