@@ -37,6 +37,8 @@
 #include <tango/common/tango_const.h>
 
 #include <tango/server/tango_current_function.h>
+#include <ostream>
+#include <vector>
 
 namespace Tango
 {
@@ -122,6 +124,17 @@ class Except
      */
     static void print_error_stack(const Tango::DevErrorList &ex);
 
+    /**@name Error stack related method */
+    //@{
+    /**
+     * Print a TANGO error stack.
+     *
+     * Print all the details of a TANGO error stack to os.
+     *
+     * @param ex The error stack reference
+     */
+    static void print_error_stack(const Tango::DevErrorList &ex, std::ostream &os);
+
     //@}
 
     /**@name Throw exception inline methods (static) */
