@@ -32,12 +32,25 @@
 #ifndef _PIPE_H
 #define _PIPE_H
 
-#include <tango/tango.h>
+#include <tango/common/tango_const.h>
+#include <tango/client/DevicePipe.h>
+#include <tango/server/attribute.h>
+#include <tango/server/classpipe.h>
 
-#include <stdarg.h>
+#include <cstdarg>
+#include <string>
+#include <vector>
 
 namespace Tango
 {
+class UserDefaultPipeProp;
+
+enum PipeSerialModel
+{
+    PIPE_NO_SYNC = 0,
+    PIPE_BY_KERNEL,
+    PIPE_BY_USER
+};
 
 /**
  * This class is a class representing a pipe in the TANGO device server pattern. It is an abstract class.
@@ -589,7 +602,7 @@ Pipe &operator<<(Pipe &, DataElement<T> &);
 //
 
 #define PIPE_CHECK_PTR(A, B, C)                                                      \
-    if(A == NULL)                                                                    \
+    if(A == nullptr)                                                                 \
     {                                                                                \
         std::stringstream o;                                                         \
         o << "Data pointer for pipe " << B << ", data element " << C << " is NULL!"; \
