@@ -35,9 +35,7 @@
 #ifndef _POLLTHREAD_H
 #define _POLLTHREAD_H
 
-#include <tango/tango.h>
 #include <tango/server/pollobj.h>
-#include <tango/server/utils.h>
 #include <tango/server/tango_clock.h>
 
 #include <list>
@@ -62,8 +60,8 @@ namespace Tango
 
 struct PollThCmd
 {
-    bool cmd_pending;            // The new command flag
-    bool trigger;                // The external trigger flag
+    bool cmd_pending{false};     // The new command flag
+    bool trigger{false};         // The external trigger flag
     PollCmdCode cmd_code;        // The command code
     DeviceImpl *dev;             // The device pointer (servant)
     long index;                  // Index in the device poll_list
@@ -101,6 +99,7 @@ enum PollCmdType
 
 class TangoMonitor;
 
+// NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
 class PollThread : public omni_thread
 {
   public:
@@ -181,6 +180,8 @@ class PollThread : public omni_thread
     ClntIdent dummy_cl_id;
     CppClntIdent cci;
 
+    ~PollThread() override = default;
+
   public:
     static DeviceImpl *dev_to_del;
     static std::string name_to_del;
