@@ -33,10 +33,17 @@
 #ifndef _ROOTATTREG_H
 #define _ROOTATTREG_H
 
-#include <tango/tango.h>
+#include <tango/common/tango_const.h>
+#include <tango/client/CallBack.h>
+#include <tango/server/readers_writers_lock.h>
+
+#include <string>
+#include <map>
 
 namespace Tango
 {
+class FwdAttr;
+class DeviceProxy;
 
 struct NameFwdAttr
 {
@@ -62,6 +69,8 @@ class RootAttRegistry
     {
     }
 
+    ~RootAttRegistry();
+
     void add_root_att(
         const std::string &, const std::string &, const std::string &, const std::string &, FwdAttr *, DeviceImpl *);
     void remove_root_att(const std::string &, const std::string &);
@@ -125,6 +134,8 @@ class RootAttRegistry
             ci.cpp_clnt(0);
         }
 
+        ~RootAttConfCallBack() override;
+
         void push_event(Tango::AttrConfEventData *) override;
 
         void add_att(const std::string &, const std::string &, const std::string &, FwdAttr *, DeviceImpl *);
