@@ -1,6 +1,9 @@
 #ifndef _TANGO_CLOCK_H
 #define _TANGO_CLOCK_H
 
+#include <tango/common/tango_const.h>
+#include <tango/server/tango_config.h>
+
 #include <chrono>
 #include <ratio>
 #include <type_traits>
@@ -8,12 +11,11 @@
 
 #ifdef _TG_WINDOWS_
   #include <sys/timeb.h>
+  #include <winsock2.h> // struct timeval
 #else
   #include <sys/time.h>
 #endif
 
-#include <tango/idl/tango.h>
-
 namespace Tango
 {
 
@@ -104,6 +106,11 @@ inline std::chrono::system_clock::time_point make_system_time(::timeval tv)
     return detail::make_system_time(tv.tv_sec, tv.tv_usec, 0);
 }
 
+inline std::chrono::system_clock::time_point make_system_time(TimeVal tv)
+{
+    return detail::make_system_time(tv.tv_sec, tv.tv_usec, tv.tv_nsec);
+}
+
 template <typename Rep, typename Period>
 double constexpr duration_s(std::chrono::duration<Rep, Period> dur)
 {
