@@ -32,8 +32,8 @@
 #ifndef _TANGO_CONFIG_H
 #define _TANGO_CONFIG_H
 
-#include <chrono>
-#include <thread>
+#include <sstream>
+#include <ostream>
 
 //
 // Add some define for Win32 and omniORB
@@ -92,8 +92,8 @@
 //
 
 #ifdef _TG_WINDOWS_
-  #if((defined _USRDLL) || (defined TANGO_HAS_DLL))
-    #if(defined _TANGO_LIB)
+  #if ((defined _USRDLL) || (defined TANGO_HAS_DLL))
+    #if (defined _TANGO_LIB)
       // basically never used as we have CMAKE_WINDOWS_EXPORT_ALL_SYMBOLS set
       #define TANGO_IMP_EXP __declspec(dllexport)
       #define TANGO_IMP
@@ -106,7 +106,7 @@
     #define TANGO_IMP
   #endif /* TANGO_HAS_DLL */
 
-  #if(defined _TANGO_LIB)
+  #if (defined _TANGO_LIB)
     #define TANGO_REV_EXP
   #else
     #define TANGO_REV_EXP __declspec(dllexport)
