@@ -34,12 +34,13 @@
 #ifndef _UTILS_H
 #define _UTILS_H
 
-#include <tango/tango.h>
+#include <tango/server/tango_config.h>
 #include <tango/server/pollext.h>
-#include <tango/server/subdev_diag.h>
-#include <new>
-#include <tango/server/rootattreg.h>
 #include <tango/server/pollthread.h>
+#include <tango/server/subdev_diag.h>
+#include <tango/server/rootattreg.h>
+#include <tango/server/tango_monitor.h>
+#include <tango/client/ApiUtil.h>
 
 #ifndef _TG_WINDOWS_
   #include <unistd.h>
@@ -47,6 +48,9 @@
   #include <tango/windows/coutbuf.h>
   #include <tango/windows/w32win.h>
 #endif /* _TG_WINDOWS_ */
+#include <iostream>
+#include <new>
+#include <algorithm>
 
 namespace Tango
 {
@@ -60,6 +64,7 @@ class NotifdEventSupplier;
 class ZmqEventSupplier;
 class DbServerCache;
 class SubDevDiag;
+class FwdAttr;
 
 struct PollingThreadInfo;
 struct DevDbUpd;
@@ -187,15 +192,8 @@ class Util
      * @return The Util object reference
      */
     static Util *instance(bool exit = true);
-    //@}
 
-    /**@name Destructor
-     * Only one destructor is defined for this class */
-    //@{
-    /**
-     * The class destructor.
-     */
-    ~Util();
+    //@}
 
     //@}
 
@@ -865,6 +863,9 @@ class Util
     //
 
   private:
+    // Private destructor as the class is a singleton
+    ~Util();
+
     class UtilExt
     {
       public:
@@ -1183,6 +1184,7 @@ class Util
     void build_argc_argv();
     void install_cons_handler();
 
+    // NOLINTNEXTLINE(cppcoreguidelines-virtual-class-destructor)
     class ORBWin32Loop : public omni_thread
     {
         Util *util;
@@ -1193,8 +1195,6 @@ class Util
         {
         }
 
-        virtual ~ORBWin32Loop() { }
-
         void *run_undetached(void *);
 
         void start()
@@ -1204,6 +1204,8 @@ class Util
 
       private:
         void wait_for_go();
+
+        ~ORBWin32Loop() override = default;
     };
     friend class ORBWin32Loop;
     ORBWin32Loop *loop_th;
@@ -1226,7 +1228,7 @@ class Util
 
     std::string database_file_name;
 
-    Database *db; // The db proxy
+    Database *db{nullptr}; // The db proxy
 
     void effective_job(int, char *[]);
     void create_CORBA_objects();
@@ -1234,7 +1236,6 @@ class Util
     void init_host_name();
     void server_perform_work();
     void server_already_running();
-    void print_usage(char *);
     static void print_err_message(const char *, Tango::MessBoxType type = Tango::STOP);
 
     void print_err_message(const std::string &mess, Tango::MessBoxType type = Tango::STOP)
@@ -1243,13 +1244,14 @@ class Util
     }
 
     void check_args(int, char *[]);
-    void display_help_message();
+    void print_help_message(bool extended, bool with_database = false);
+
     DeviceImpl *find_device_name_core(const std::string &);
     void check_orb_endpoint(int, char **);
     void validate_sort(const std::vector<std::string> &);
     void check_end_point_specified(int, char **);
 
-    bool display_help;                                      // display help message flag
+    bool print_help_once_connected;                         // Print the help message once we are connected to db.
     const std::vector<DeviceClass *> *cl_list_ptr{nullptr}; // Ptr to server device class list
     std::unique_ptr<UtilExt> ext;                           // Class extension
     std::vector<DeviceClass *> cl_list;                     // Full class list ptr
@@ -1346,7 +1348,7 @@ inline bool Util::is_device_restarting(const std::string &d_name)
     if(!restarting_devices.empty())
     {
         std::vector<std::string>::iterator pos;
-        pos = find(restarting_devices.begin(), restarting_devices.end(), d_name);
+        pos = std::find(restarting_devices.begin(), restarting_devices.end(), d_name);
         if(pos != restarting_devices.end())
         {
             ret = true;
@@ -1390,7 +1392,7 @@ inline void Util::check_orb_endpoint(int argc, char *argv[])
             if((pos = endpoint.rfind(':')) == std::string::npos)
             {
                 std::cerr << "Strange ORB endPoint specification" << std::endl;
-                print_usage(argv[0]);
+                print_help_message(false);
             }
             svr_port_num = endpoint.substr(++pos);
             break;
@@ -1399,7 +1401,7 @@ inline void Util::check_orb_endpoint(int argc, char *argv[])
     if(arg_nb == argc)
     {
         std::cerr << "Missing ORB endPoint specification" << std::endl;
-        print_usage(argv[0]);
+        print_help_message(false);
     }
 }
 
@@ -1503,21 +1505,6 @@ inline CORBA::Any *return_empty_any(const char *cmd)
     return (out_any);
 }
 
-inline DbDevice *DeviceImpl::get_db_device()
-{
-    if(!Tango::Util::instance()->use_db())
-    {
-        TangoSys_OMemStream desc_mess;
-        desc_mess << "Method not available for device ";
-        desc_mess << device_name;
-        desc_mess << " which is a non database device";
-
-        TANGO_THROW_EXCEPTION(API_NonDatabaseDevice, desc_mess.str());
-    }
-
-    return db_dev;
-}
-
 void clear_att_dim(Tango::AttributeValue_3 &att_val);
 void clear_att_dim(Tango::AttributeValue_4 &att_val);
 void clear_att_dim(Tango::AttributeValue_5 &att_val);
