@@ -103,7 +103,7 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
     }
 
     //
-    // If the attribute is not READ_WRITE, the ptr to written part should always be NULL
+    // If the attribute is not READ_WRITE, the ptr to written part should always be nullptr
     //
 
     size_t nb_elt = data.length();
@@ -129,12 +129,12 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
     //
 
     long idl_vers = dev->get_dev_idl_version();
-    if((att.get_data_type() == DEV_ENCODED) && (idl_vers == 3))
+    if((att.get_data_type() == DEV_ENCODED) && (idl_vers <= 3))
     {
         TangoSys_OMemStream o;
         o << "The attribute " << att_name;
         o << " for device " << dev->get_name();
-        o << " is of type DEV_ENCODED. Your device supports only IDL V3.";
+        o << " is of type DEV_ENCODED. Your device supports only IDL V" << idl_vers << ".";
         o << " DEV_ENCODED data type is supported starting with IDL V4" << std::ends;
 
         TANGO_THROW_EXCEPTION(API_NotSupportedFeature, o.str());
@@ -344,10 +344,22 @@ void Util::fill_attr_polling_buffer(DeviceImpl *dev, std::string &att_name, Attr
                             if(att.get_data_format() == Tango::SCALAR)
                             {
                                 delete(data.get_data())[i].wr_ptr;
+                                (data.get_data())[i].wr_ptr = nullptr;
                             }
                             else
                             {
+                                if constexpr(std::is_same_v<T, Tango::DevString>)
+                                {
+                                    CORBA::Long len =
+                                        (data.get_data())[i].wr_x * std::max(1l, (data.get_data())[i].wr_y);
+                                    for(CORBA::Long j = 0; j < len; j += 1)
+                                    {
+                                        Tango::string_free((data.get_data())[i].wr_ptr[j]);
+                                    }
+                                }
+
                                 delete[](data.get_data())[i].wr_ptr;
+                                (data.get_data())[i].wr_ptr = nullptr;
                             }
                         }
                     }
