@@ -103,8 +103,8 @@ void WAttribute::get_write_value(const T *&ptr)
 template <typename T>
 void WAttribute::check_type(const std::string &origin)
 {
-    bool short_enum = std::is_same<short, std::underlying_type_t<T>>::value;
-    bool uns_int_enum = std::is_same<unsigned int, std::underlying_type_t<T>>::value;
+    bool short_enum = std::is_same_v<short, std::underlying_type_t<T>>;
+    bool uns_int_enum = std::is_same_v<unsigned int, std::underlying_type_t<T>>;
 
     if(!short_enum && !uns_int_enum)
     {
@@ -119,7 +119,7 @@ void WAttribute::check_type(const std::string &origin)
     // Check if the input type is an enum and if it is from the valid type
     //
 
-    if(std::is_enum<T>::value == false)
+    if(std::is_enum_v<T> == false)
     {
         Except::throw_exception(
             API_IncompatibleArgumentType, "The input argument data type is not an enumeration", origin);
@@ -211,56 +211,5 @@ inline void WAttribute::set_write_value(T *val, size_t x, size_t y)
         throw;
     }
 }
-
-template <class T, std::enable_if_t<!std::is_enum_v<T> || std::is_same_v<T, Tango::DevState>, T> *>
-inline void WAttribute::set_write_value(T *val, size_t x, size_t y)
-{
-    size_t nb_data;
-
-    if(y == 0)
-    {
-        nb_data = x;
-    }
-    else
-    {
-        nb_data = x * y;
-    }
-
-    typename tango_type_traits<T>::ArrayType tmp_seq(
-        static_cast<CORBA::ULong>(nb_data), static_cast<CORBA::ULong>(nb_data), val, false);
-
-    CORBA::Any tmp_any;
-    tmp_any <<= tmp_seq;
-    check_written_value(tmp_any, x, y);
-    copy_data(tmp_any);
-    set_user_set_write_value(true);
-}
-
-template <class T>
-inline void WAttribute::set_write_value(std::vector<T> &val, size_t x, size_t y)
-{
-    if constexpr(std::is_same_v<T, bool> || std::is_same_v<T, std::string>)
-    {
-        typename tango_type_traits<T>::ArrayType tmp_seq;
-        tmp_seq << val;
-
-        CORBA::Any tmp_any;
-        tmp_any <<= tmp_seq;
-        check_written_value(tmp_any, x, y);
-        copy_data(tmp_any);
-        set_user_set_write_value(true);
-    }
-    else
-    {
-        set_write_value(val.data(), x, y);
-    }
-}
-
-template <class T>
-inline void WAttribute::set_write_value(T val)
-{
-    set_write_value(&val, 1, 0);
-}
-
 } // namespace Tango
 #endif // _WATTRSETVAL_TPP
