@@ -29,13 +29,10 @@
 //
 //====================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/server/attribute.h>
 #include <tango/server/classattribute.h>
 #include <tango/server/eventsupplier.h>
-
-#include <functional>
-#include <algorithm>
+#include <tango/server/tango_config.h>
 
 #ifdef _TG_WINDOWS_
   #include <sys/types.h>
@@ -58,6 +55,8 @@ namespace Tango
 
 void Attribute::set_value(Tango::DevString *p_data_str, Tango::DevUChar *p_data, long size, bool release)
 {
+    TANGO_LOG_DEBUG << "Attribute::set_value() called " << std::endl;
+
     if(p_data_str == nullptr || p_data == nullptr)
     {
         TangoSys_OMemStream o;
@@ -85,6 +84,8 @@ void Attribute::set_value(Tango::DevString *p_data_str, Tango::DevUChar *p_data,
 
 void Attribute::set_value(Tango::EncodedAttribute *attr)
 {
+    TANGO_LOG_DEBUG << "Attribute::set_value() called " << std::endl;
+
     CHECK_PTR(attr, name);
 
     Tango::DevString *f = attr->get_format();
