@@ -29,8 +29,10 @@
 //
 //====================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/server/auto_tango_monitor.h>
+#include <tango/server/tango_monitor.h>
+#include <tango/server/device.h>
+#include <tango/server/utils.h>
 
 namespace Tango
 {
@@ -120,6 +122,11 @@ AutoTangoMonitor::~AutoTangoMonitor()
     }
 }
 
+AutoTangoMonitor::AutoTangoMonitor(const std::shared_ptr<Tango::TangoMonitor> &m) :
+    AutoTangoMonitor(m.get())
+{
+}
+
 //---------------------------------------------------------------------------------------------------------------
 //
 // class :
