@@ -38,6 +38,11 @@
 //-===========================================================================
 
 #include <tango/server/dserver.h>
+
+#ifdef _TG_WINDOWS_
+  #include <tango/server/utils.h>
+#endif
+
 #ifdef __APPLE__
   #include <dlfcn.h>
   #include <cstdlib>
@@ -49,6 +54,8 @@
   #include <regex>
 #endif
 
+#include <iostream>
+
 namespace Tango
 {
 
@@ -101,7 +108,7 @@ void DServer::class_factory()
     convertor conv;
     PTR tmp;
 
-    if((mod = GetModuleHandle(exe_name.c_str())) == NULL)
+    if((mod = GetModuleHandle(exe_name.c_str())) == nullptr)
     {
         std::cerr << "Oops, no class defined in this server. Exiting ..." << std::endl;
         exit(-1);
@@ -115,9 +122,9 @@ void DServer::class_factory()
     //
 
   #ifdef _WIN64
-    if((proc = GetProcAddress(mod, "?class_factory@DServer@Tango@@AEAAXXZ")) == NULL)
+    if((proc = GetProcAddress(mod, "?class_factory@DServer@Tango@@AEAAXXZ")) == nullptr)
   #elif defined(_WIN32) /* WIN32 */
-    if((proc = GetProcAddress(mod, "?class_factory@DServer@Tango@@AAEXXZ")) == NULL)
+    if((proc = GetProcAddress(mod, "?class_factory@DServer@Tango@@AAEXXZ")) == nullptr)
   #endif
     {
         std::cerr << "Oops, no class defined in this server. Exiting ..." << std::endl;
@@ -183,9 +190,7 @@ void DServer::class_factory()
         const std::string full_path{path + "/" + shortened_exe_name};
         // Check if the executable exists in the path and that it is not
         // a directory of the same name.
-        struct stat exec_file_stat
-        {
-        };
+        struct stat exec_file_stat{};
         if((stat(full_path.c_str(), &exec_file_stat) == 0) && ((exec_file_stat.st_mode & S_IFDIR) == 0))
         {
             // full_path should contain the full path to the Device
