@@ -36,8 +36,10 @@
 //
 //-============================================================================
 
-#include <tango/tango.h>
 #include <tango/server/device_2.h>
+#include <tango/server/dserver.h>
+#include <tango/server/command.h>
+#include <tango/server/utils.h>
 #include <tango/server/tango_clock.h>
 #include <new>
 
@@ -1204,9 +1206,9 @@ Tango::AttributeConfigList_2 *Device_2Impl::get_attribute_config_2(const Tango::
     // attribute), decrement attribute number
     //
 
-    std::string in_name(names[0]);
     if(nb_attr == 1)
     {
+        std::string in_name(names[0]);
         if(in_name == AllAttr)
         {
             all_attr = true;
@@ -1382,10 +1384,7 @@ Tango::DevCmdHistoryList *Device_2Impl::command_inout_history_2(const char *comm
     //
 
     long in_buf = polled_cmd->get_elt_nb_in_buffer();
-    if(n > in_buf)
-    {
-        n = in_buf;
-    }
+    n = std::min<long>(n, in_buf);
 
     //
     // Allocate memory for the returned value
@@ -1558,10 +1557,7 @@ Tango::DevAttrHistoryList *Device_2Impl::read_attribute_history_2(const char *na
     //
 
     long in_buf = polled_attr->get_elt_nb_in_buffer();
-    if(n > in_buf)
-    {
-        n = in_buf;
-    }
+    n = std::min<long>(n, in_buf);
 
     //
     // Allocate memory for the returned value
