@@ -36,31 +36,9 @@
 //
 //-============================================================================
 
-#if defined(__GNUC__) && !defined(__clang__)
-  #pragma GCC diagnostic push
-  #pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
-  #pragma GCC diagnostic ignored "-Wunused-parameter"
-#endif
-
-#if defined(__clang__)
-  #pragma clang diagnostic push
-  #pragma clang diagnostic ignored "-Wsometimes-uninitialized"
-  #pragma clang diagnostic ignored "-Wunused-variable"
-#endif
-
-#include <tango/tango.h>
-
-#if defined(__clang__)
-  #pragma clang diagnostic pop
-#endif
-
-#if defined(__GNUC__) && !defined(__clang__)
-  #pragma GCC diagnostic pop
-#endif
-
 #include <tango/server/device_4.h>
+#include <tango/server/command.h>
 #include <tango/server/eventsupplier.h>
-#include <tango/server/device_3_templ.h>
 #include <tango/internal/telemetry/telemetry_kernel_macros.h>
 
 namespace Tango
@@ -193,10 +171,7 @@ Tango::DevAttrHistory_4 *Device_4Impl::read_attribute_history_4(const char *name
     //
 
     long in_buf = polled_attr->get_elt_nb_in_buffer();
-    if(n > in_buf)
-    {
-        n = in_buf;
-    }
+    n = std::min<long>(n, in_buf);
 
     //
     // Allocate memory for the returned value
@@ -344,10 +319,7 @@ Tango::DevCmdHistory_4 *Device_4Impl::command_inout_history_4(const char *comman
     //
 
     long in_buf = polled_cmd->get_elt_nb_in_buffer();
-    if(n > in_buf)
-    {
-        n = in_buf;
-    }
+    n = std::min<long>(n, in_buf);
 
     //
     // Allocate memory for the returned value
@@ -858,7 +830,7 @@ void Device_4Impl::set_attribute_config_4(const Tango::AttributeConfigList_3 &ne
     //
 
     store_in_bb = false;
-    set_attribute_config_3_local(new_conf, new_conf[0], false, idl_version);
+    set_attribute_config_3_local(new_conf, false, idl_version);
 
     TANGO_TELEMETRY_TRACE_END();
 }
