@@ -30,9 +30,7 @@
 //
 //-================================================================================================================
 
-#include <tango/tango.h>
 #include <new>
-#include <iterator>
 
 #include <tango/server/basiccommand.h>
 #include <tango/server/blackbox.h>
@@ -40,10 +38,15 @@
 #include <tango/server/classattribute.h>
 #include <tango/server/classpipe.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/server/device_3.h>
+#include <tango/server/pipe.h>
+#include <tango/server/dserver.h>
 
 #include <tango/client/apiexcept.h>
+#include <tango/client/Database.h>
 
 #include <tango/server/logging.h>
+#include <tango/server/log4tango.h>
 
 namespace Tango
 {
@@ -53,18 +56,6 @@ static void lower_cmd_name(std::string &cmd)
     std::transform(cmd.begin(), cmd.end(), cmd.begin(), ::tolower);
 }
 
-bool less_than_pipe(Pipe *a, Pipe *b)
-{
-    if(a->get_name() < b->get_name())
-    {
-        return true;
-    }
-    else
-    {
-        return false;
-    }
-}
-
 //+------------------------------------------------------------------------------------------------------------------
 //
 // method :
@@ -78,10 +69,11 @@ bool less_than_pipe(Pipe *a, Pipe *b)
 DeviceClass::DeviceClass(const std::string &s) :
     name(s),
     ext(new DeviceClassExt),
-    only_one("class"),
-    default_cmd(NULL),
-    device_factory_done(false)
+    only_one("class " + s)
+
 {
+    TANGO_LOG_DEBUG << "Entering DeviceClass::DeviceClass for class " << name << std::endl;
+
     //
     // Create the associated DbClass object
     //
@@ -102,7 +94,7 @@ DeviceClass::DeviceClass(const std::string &s) :
     }
     catch(std::bad_alloc &)
     {
-        if(command_list.empty() == false)
+        if(!command_list.empty())
         {
             for(unsigned long i = 0; i < command_list.size(); i++)
             {
@@ -136,6 +128,8 @@ DeviceClass::DeviceClass(const std::string &s) :
     //
 
     type = NotSet;
+
+    TANGO_LOG_DEBUG << "Leaving DeviceClass::DeviceClass for class " << name << std::endl;
 }
 
 //+-------------------------------------------------------------------------------------------------------------------
@@ -160,12 +154,12 @@ void DeviceClass::get_class_system_resource()
         Database *db = tg->get_database();
         DbData db_data;
 
-        db_data.push_back(DbDatum("doc_url"));
-        db_data.push_back(DbDatum("cvs_tag"));
-        db_data.push_back(DbDatum("cvs_location"));
-        db_data.push_back(DbDatum("AllowedAccessCmd"));
-        db_data.push_back(DbDatum("svn_tag"));
-        db_data.push_back(DbDatum("svn_location"));
+        db_data.emplace_back("doc_url");
+        db_data.emplace_back("cvs_tag");
+        db_data.emplace_back("cvs_location");
+        db_data.emplace_back("AllowedAccessCmd");
+        db_data.emplace_back("svn_tag");
+        db_data.emplace_back("svn_location");
 
         try
         {
@@ -179,11 +173,11 @@ void DeviceClass::get_class_system_resource()
             TANGO_THROW_EXCEPTION(API_DatabaseAccess, o.str());
         }
 
-        if(db_data[1].is_empty() == false)
+        if(!db_data[1].is_empty())
         {
             db_data[1] >> cvs_tag;
         }
-        if(db_data[2].is_empty() == false)
+        if(!db_data[2].is_empty())
         {
             db_data[2] >> cvs_location;
         }
@@ -192,13 +186,13 @@ void DeviceClass::get_class_system_resource()
         // Init allowed commands vector (in lowercase letters)
         //
 
-        if(db_data[3].is_empty() == false)
+        if(!db_data[3].is_empty())
         {
             db_data[3] >> allowed_cmds;
             for_each(allowed_cmds.begin(), allowed_cmds.end(), lower_cmd_name);
         }
 
-        if(db_data[0].is_empty() == true)
+        if(db_data[0].is_empty())
         {
             TANGO_LOG_DEBUG << "doc_url property for class " << name << " is not defined in database" << std::endl;
             try
@@ -213,7 +207,7 @@ void DeviceClass::get_class_system_resource()
                 TANGO_THROW_EXCEPTION(API_DatabaseAccess, o.str());
             }
 
-            if(db_data[0].is_empty() == true)
+            if(db_data[0].is_empty())
             {
                 doc_url = DefaultDocUrl;
             }
@@ -227,11 +221,11 @@ void DeviceClass::get_class_system_resource()
             db_data[0] >> doc_url;
         }
 
-        if(db_data[4].is_empty() == false)
+        if(!db_data[4].is_empty())
         {
             db_data[4] >> svn_tag;
         }
-        if(db_data[5].is_empty() == false)
+        if(!db_data[5].is_empty())
         {
             db_data[5] >> svn_location;
         }
@@ -312,7 +306,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
     //
 
     unsigned long start, stop;
-    if(all == true)
+    if(all)
     {
         start = 0;
         stop = device_list.size();
@@ -346,7 +340,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
         {
             WAttribute &att = device_list[i]->get_device_attr()->get_w_attr_by_ind(att_list[j]);
 
-            if(att.is_memorized() == true)
+            if(att.is_memorized())
             {
                 std::string &mem_value = att.get_mem_value();
                 if(mem_value != MemNotUsed)
@@ -367,7 +361,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                     //
 
                     TangoSys_MemStream str;
-                    if(from_init == false)
+                    if(!from_init)
                     {
                         str << mem_value << std::ends;
                     }
@@ -378,7 +372,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                         {
                         case Tango::DEV_SHORT:
                         case Tango::DEV_ENUM:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> sh))
                                 {
@@ -396,7 +390,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_LONG:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> lg))
                                 {
@@ -414,7 +408,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_DOUBLE:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> db))
                                 {
@@ -432,7 +426,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_STRING:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 att.set_write_value(mem_value);
 
@@ -447,7 +441,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_FLOAT:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> fl))
                                 {
@@ -465,7 +459,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_BOOLEAN:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> std::boolalpha >> boo))
                                 {
@@ -483,7 +477,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_USHORT:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> ush))
                                 {
@@ -501,7 +495,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_UCHAR:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 short tmp_sh;
                                 if(!(str >> tmp_sh))
@@ -521,7 +515,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_ULONG:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> ulg))
                                 {
@@ -539,7 +533,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_LONG64:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> lg64))
                                 {
@@ -557,7 +551,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                             break;
 
                         case Tango::DEV_ULONG64:
-                            if(from_init == false)
+                            if(!from_init)
                             {
                                 if(!(str >> ulg64))
                                 {
@@ -581,7 +575,7 @@ void DeviceClass::set_memorized_values(bool all, long idx, bool from_init)
                         // attribute.
                         //
 
-                        if(att.is_memorized_init() == false)
+                        if(!att.is_memorized_init())
                         {
                             nb_wr--;
                             att_val.length(nb_wr);
@@ -798,7 +792,7 @@ DeviceClass::~DeviceClass()
                 tg->clean_cmd_polled_prop();
             }
 
-            std::vector<DeviceImpl *>::iterator it = device_list.begin();
+            auto it = device_list.begin();
             device_list.erase(it);
         }
         device_list.clear();
@@ -825,8 +819,10 @@ DeviceClass::~DeviceClass()
         for(size_t loop = 0; loop < ite->second.size(); loop++)
         {
             delete(ite->second)[loop];
+            (ite->second)[loop] = nullptr;
         }
     }
+    ext->dev_pipe_list.clear();
 
     //
     // Destroy the MultiClassAttribute object
@@ -877,7 +873,7 @@ void DeviceClass::delete_dev(long idx, Tango::Util *tg, PortableServer::POA_ptr
     // If the polling thread is alive and if device is polled, ask polling thread to stop polling
     //
 
-    if((tg->get_polling_threads_info().empty() == false) && (device_list[idx]->is_polled() == true))
+    if((!tg->get_polling_threads_info().empty()) && (device_list[idx]->is_polled()))
     {
         device_list[idx]->stop_polling(false);
     }
@@ -888,7 +884,7 @@ void DeviceClass::delete_dev(long idx, Tango::Util *tg, PortableServer::POA_ptr
 
     bool exported_device = device_list[idx]->get_exported_flag();
 
-    if(exported_device == true)
+    if(exported_device)
     {
         r_poa->deactivate_object(device_list[idx]->get_obj_id().in());
     }
@@ -897,9 +893,9 @@ void DeviceClass::delete_dev(long idx, Tango::Util *tg, PortableServer::POA_ptr
     // Wait for CORBA to call the device dtor
     //
 
-    if(device_list[idx] != NULL && exported_device == true)
+    if(device_list[idx] != nullptr && exported_device)
     {
-        while(device_list[idx] != NULL)
+        while(device_list[idx] != nullptr)
         {
             std::this_thread::sleep_for(std::chrono::milliseconds(10));
         }
@@ -1024,7 +1020,7 @@ void DeviceClass::export_device(DeviceImpl *dev, const char *corba_obj_name)
 
         std::string &dev_name = dev->get_name_lower();
         TANGO_LOG_DEBUG << "DeviceClass::export_device::dev_name=" << dev_name << std::endl;
-        if((get_device_factory_done() == false) && (dev_name.find("dserver") != 0))
+        if((!get_device_factory_done()) && (dev_name.find("dserver") != 0))
         {
             dev->get_dev_monitor().get_monitor();
         }
@@ -1153,7 +1149,7 @@ void DeviceClass::export_device(DeviceImpl *dev, const char *corba_obj_name)
 
 CORBA::Any *DeviceClass::command_handler(DeviceImpl *device, const std::string &command, const CORBA::Any &in_any)
 {
-    CORBA::Any *ret = NULL;
+    CORBA::Any *ret = nullptr;
     std::vector<Command *>::iterator i_cmd;
 
     std::string command_lower(command);
@@ -1177,7 +1173,7 @@ CORBA::Any *DeviceClass::command_handler(DeviceImpl *device, const std::string &
         }
     }
 
-    if(found == false)
+    if(!found)
     {
         std::vector<Command *> &dev_command_list = device->get_local_command_list();
         for(i_cmd = dev_command_list.begin(); i_cmd < dev_command_list.end(); ++i_cmd)
@@ -1190,7 +1186,7 @@ CORBA::Any *DeviceClass::command_handler(DeviceImpl *device, const std::string &
         }
     }
 
-    if(found == true)
+    if(found)
     {
         //
         // Call the always executed method
@@ -1202,7 +1198,7 @@ CORBA::Any *DeviceClass::command_handler(DeviceImpl *device, const std::string &
         // Check if command is allowed
         //
 
-        if((*i_cmd)->is_allowed(device, in_any) == false)
+        if(!(*i_cmd)->is_allowed(device, in_any))
         {
             TangoSys_OMemStream o;
             o << "Command " << command << " not allowed when the device is in "
@@ -1217,13 +1213,13 @@ CORBA::Any *DeviceClass::command_handler(DeviceImpl *device, const std::string &
         ret = (*i_cmd)->execute(device, in_any);
     }
 
-    if(found == false)
+    if(!found)
     {
         TANGO_LOG_DEBUG << "DeviceClass::command_handler(): command " << command << " not found in class/device command"
                         << std::endl;
 
         Command *def_cmd = get_default_command();
-        if(def_cmd != NULL)
+        if(def_cmd != nullptr)
         {
             //
             // Set name in default command object
@@ -1241,7 +1237,7 @@ CORBA::Any *DeviceClass::command_handler(DeviceImpl *device, const std::string &
             // Check if command is allowed
             //
 
-            if(def_cmd->is_allowed(device, in_any) == false)
+            if(!def_cmd->is_allowed(device, in_any))
             {
                 TangoSys_OMemStream o;
                 o << "Command " << command << " not allowed when the device is in "
@@ -1439,7 +1435,7 @@ void DeviceClass::device_destroyer(const std::string &dev_name)
     // Check if the device is polled. If yes, ask polling thread to stop polling it
     //
 
-    if(device_list[k]->is_polled() == true)
+    if(device_list[k]->is_polled())
     {
         device_list[k]->stop_polling();
     }
@@ -1452,7 +1448,7 @@ void DeviceClass::device_destroyer(const std::string &dev_name)
 
     PortableServer::POA_ptr r_poa = tg->get_poa();
     delete_dev(k, tg, r_poa);
-    std::vector<DeviceImpl *>::iterator it = device_list.begin();
+    auto it = device_list.begin();
     it += k;
     device_list.erase(it);
     CORBA::release(r_poa);
@@ -1461,7 +1457,7 @@ void DeviceClass::device_destroyer(const std::string &dev_name)
 void DeviceClass::device_destroyer(const char *dev_name)
 {
     std::string name_str(dev_name);
-    return device_destroyer(name_str);
+    device_destroyer(name_str);
 }
 
 //+-------------------------------------------------------------------------------------------------------------------
@@ -1486,7 +1482,7 @@ bool DeviceClass::is_command_allowed(const char *cmd)
     std::string tmp_cmd(cmd);
     std::transform(tmp_cmd.begin(), tmp_cmd.end(), tmp_cmd.begin(), ::tolower);
 
-    std::vector<std::string>::iterator pos = find(allowed_cmds.begin(), allowed_cmds.end(), tmp_cmd);
+    auto pos = find(allowed_cmds.begin(), allowed_cmds.end(), tmp_cmd);
     if(pos == allowed_cmds.end())
     {
         ret = false;
@@ -1520,7 +1516,7 @@ void DeviceClass::get_mcast_event(DServer *dserv)
         for(unsigned int j = 0; j < att_list.size(); ++j)
         {
             dserv->mcast_event_for_att(device_list[i]->get_name_lower(), att_list[j]->get_name_lower(), m_cast);
-            if(m_cast.empty() == false)
+            if(!m_cast.empty())
             {
                 att_list[j]->set_mcast_event(m_cast);
             }
@@ -1588,7 +1584,7 @@ Command &DeviceClass::get_cmd_by_name(const std::string &cmd_name)
 
 Pipe &DeviceClass::get_pipe_by_name(const std::string &pipe_name, const std::string &dev_name)
 {
-    std::map<std::string, std::vector<Pipe *>>::iterator ite = ext->dev_pipe_list.find(dev_name);
+    auto ite = ext->dev_pipe_list.find(dev_name);
     if(ite == ext->dev_pipe_list.end())
     {
         TANGO_LOG_DEBUG << "DeviceClass::get_pipe_by_name throwing exception" << std::endl;
@@ -1734,16 +1730,26 @@ void DeviceClass::create_device_pipe(DeviceClass *cl, DeviceImpl *dev)
 
     cl->pipe_factory();
 
-    if(ext->dev_pipe_list.empty() == true)
+    if(ext->dev_pipe_list.empty())
     {
         MultiClassPipe *c_pipe = get_class_pipe();
         c_pipe->init_class_pipe(this);
     }
 
-    sort(pipe_list.begin(), pipe_list.end(), less_than_pipe);
+    sort(pipe_list.begin(), pipe_list.end(), [](Pipe *a, Pipe *b) { return a->get_name() < b->get_name(); });
 
     std::string dev_name = dev->get_name_lower();
-    ext->dev_pipe_list.insert(make_pair(dev_name, pipe_list));
+
+    auto ret = ext->dev_pipe_list.insert(make_pair(dev_name, pipe_list));
+    if(!ret.second)
+    {
+        // insertion was not successful, we now own the memory in pipe_list
+        for(auto *elem : pipe_list)
+        {
+            delete elem;
+            elem = nullptr;
+        }
+    }
 
     pipe_list.clear();
 }
@@ -1767,7 +1773,7 @@ std::vector<Pipe *> &DeviceClass::get_pipe_list(const std::string &dev_name)
     std::string local_dev_name(dev_name);
     std::transform(local_dev_name.begin(), local_dev_name.end(), local_dev_name.begin(), ::tolower);
 
-    std::map<std::string, std::vector<Pipe *>>::iterator ite = ext->dev_pipe_list.find(local_dev_name);
+    auto ite = ext->dev_pipe_list.find(local_dev_name);
     if(ite == ext->dev_pipe_list.end())
     {
         TANGO_LOG_DEBUG << "DeviceClass::get_pipe_by_name throwing exception" << std::endl;
