@@ -31,13 +31,18 @@
 //
 //-=================================================================================================================
 
-#include <tango/tango.h>
+#include <tango/server/dserver.h>
 #include <tango/server/eventsupplier.h>
 #include <tango/server/devintr.h>
+#include <tango/server/deviceclass.h>
+#include <tango/server/command.h>
+#include <tango/server/seqvec.h>
+#include <tango/client/DbDevice.h>
+#include <tango/client/Database.h>
 
 #include <new>
 #include <algorithm>
-#include <iterator>
+#include <memory>
 #include <sstream>
 
 #ifndef _TG_WINDOWS_
@@ -113,11 +118,6 @@ DServer::DServer(DeviceClass *cl_ptr, const char *n, const char *d, Tango::DevSt
     TANGO_LOG_DEBUG << "Leaving DServer::DServer constructor" << std::endl;
 }
 
-bool less_than(Command *a, Command *b)
-{
-    return a->get_name() < b->get_name();
-}
-
 void DServer::init_device()
 {
     //
@@ -219,8 +219,9 @@ void DServer::init_device()
                 // Sort the Command list array
                 //
 
-                sort(class_list[i]->get_command_list().begin(), class_list[i]->get_command_list().end(), less_than);
-
+                sort(class_list[i]->get_command_list().begin(),
+                     class_list[i]->get_command_list().end(),
+                     [](Command *a, Command *b) { return a->get_name() < b->get_name(); });
                 //
                 // Build class attributes
                 //
@@ -305,7 +306,7 @@ void DServer::init_device()
                     //
 
                     std::vector<std::string> &list = class_list[i]->get_nodb_name_list();
-                    auto *dev_list_nodb = new Tango::DevVarStringArray();
+                    auto dev_list_nodb = std::make_unique<Tango::DevVarStringArray>();
 
                     tg->get_cmd_line_name_list(class_list[i]->get_name(), list);
                     if(i == class_list.size() - 1)
@@ -335,11 +336,9 @@ void DServer::init_device()
                     class_list[i]->set_device_factory_done(false);
                     {
                         AutoTangoMonitor sync(class_list[i]);
-                        class_list[i]->device_factory(dev_list_nodb);
+                        class_list[i]->device_factory(dev_list_nodb.get());
                     }
                     class_list[i]->set_device_factory_done(true);
-
-                    delete dev_list_nodb;
                 }
             }
         }
@@ -716,6 +715,71 @@ Tango::DevVarStringArray *DServer::query_sub_device()
     return (ret);
 }
 
+//+-----------------------------------------------------------------------------------------------------------------
+//
+// method :
+//        DServer::query_event_system()
+//
+// description :
+//        command to query debugging information about the event system
+//
+// returns :
+//        The information about the ZMQ event supplier and consumer in a JSON
+//        string
+//
+//------------------------------------------------------------------------------------------------------------------
+
+Tango::DevString DServer::query_event_system()
+{
+    NoSyncModelTangoMonitor mon(this);
+
+    TANGO_LOG_DEBUG << "In query_event_system command" << std::endl;
+
+    std::stringstream out;
+    out << "{\"version\":1";
+
+    out << ",\"server\":";
+    Tango::Util *tg = Tango::Util::instance();
+    auto *supplier = tg->get_zmq_event_supplier();
+    if(supplier == nullptr)
+    {
+        out << "null";
+    }
+    else
+    {
+        supplier->query_event_system(out);
+    }
+
+    out << ",\"client\":";
+
+    Tango::ApiUtil *api = Tango::ApiUtil::instance();
+    auto consumer = api->get_zmq_event_consumer();
+    if(consumer == nullptr)
+    {
+        out << "null";
+    }
+    else
+    {
+        consumer->query_event_system(out);
+    }
+
+    out << "}";
+
+    Tango::DevString ret = string_dup(out.str());
+
+    return ret;
+}
+
+void DServer::enable_event_system_perf_mon(Tango::DevBoolean enabled)
+{
+    NoSyncModelTangoMonitor mon(this);
+
+    TANGO_LOG_DEBUG << "In enable_event_system_perf_mon command" << std::endl;
+
+    ZmqEventSupplier::enable_perf_mon(enabled);
+    ZmqEventConsumer::enable_perf_mon(enabled);
+}
+
 //+-----------------------------------------------------------------------------------------------------------------
 //
 // method :
@@ -1147,6 +1211,7 @@ void ServRestartThread::run(void *ptr)
     // Setup telemetry
     //
 #if defined(TANGO_USE_TELEMETRY)
+    dev->cleanup_telemetry_interface();
     // initialize the telemetry interface
     dev->initialize_telemetry_interface();
     // attach the device's telemetry interface
@@ -1475,23 +1540,23 @@ void DServer::create_cpp_class(const std::string &class_name,
 
         DWORD l_err = GetLastError();
         ::FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
-                        NULL,
+                        nullptr,
                         l_err,
                         MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
                         (char *) &str,
                         0,
-                        NULL);
+                        nullptr);
 
         error_msgs.emplace(key, str);
         ::LocalFree((HLOCAL) str);
     };
-    if((mod = LoadLibrary(lib_name.c_str())) == NULL)
+    if((mod = LoadLibrary(lib_name.c_str())) == nullptr)
     {
         fetch_error_msg(lib_name);
-        for(const auto &prefix : prefixes)
+        for(const auto &prefix : local_prefixes)
         {
             lib_name = prefix + class_name;
-            if((mod = LoadLibrary(lib_name.c_str())) != NULL)
+            if((mod = LoadLibrary(lib_name.c_str())) != nullptr)
             {
                 lib_loaded = true;
                 break;
@@ -1514,7 +1579,7 @@ void DServer::create_cpp_class(const std::string &class_name,
     TANGO_LOG_DEBUG << "Symbol name = " << sym_name << std::endl;
     FARPROC proc;
 
-    if((proc = GetProcAddress(mod, sym_name.c_str())) == NULL)
+    if((proc = GetProcAddress(mod, sym_name.c_str())) == nullptr)
     {
         TangoSys_OMemStream o;
         o << "Class " << class_name << " does not have the C creator function (_create_<Class name>_class)"
@@ -1539,7 +1604,7 @@ void DServer::create_cpp_class(const std::string &class_name,
     if(lib_ptr == nullptr)
     {
         fetch_error_msg(lib_name);
-        for(const auto &prefix : prefixes)
+        for(const auto &prefix : local_prefixes)
         {
             auto tmp_lib_name = prefix + lib_name;
             lib_ptr = dlopen(tmp_lib_name.c_str(), RTLD_NOW);
@@ -1547,7 +1612,7 @@ void DServer::create_cpp_class(const std::string &class_name,
             {
                 break;
             }
-            fetch_error_msg(lib_name);
+            fetch_error_msg(tmp_lib_name);
         }
         if(lib_ptr == nullptr)
         {
