@@ -35,13 +35,15 @@
 //
 //-=============================================================================
 
-#include <algorithm>
-
-#include <tango/tango.h>
 #include <tango/server/dserverclass.h>
 #include <tango/server/pollcmds.h>
 #include <tango/server/logcmds.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/server/dserver.h>
+#include <tango/client/Database.h>
+
+#include <algorithm>
+#include <memory>
 
 namespace Tango
 {
@@ -312,6 +314,81 @@ CORBA::Any *DevQuerySubDeviceCmd::execute(DeviceImpl *device, TANGO_UNUSED(const
     return (out_any);
 }
 
+//+----------------------------------------------------------------------------
+//
+// method :         DevQueryEventSystemCmd::DevQuerySubDeviceCmd()
+//
+// description :     method to trigger the execution of the "QueryEventSystem"
+//                    command
+//
+//-----------------------------------------------------------------------------
+
+DevQueryEventSystemCmd::DevQueryEventSystemCmd(const char *name,
+                                               Tango::CmdArgType argin,
+                                               Tango::CmdArgType argout,
+                                               const char *out_desc) :
+    Command(name, argin, argout)
+{
+    set_out_type_desc(out_desc);
+}
+
+//+----------------------------------------------------------------------------
+//
+// method :         DevQueryEventSystemCmd::execute()
+//
+// description :     constructor for the DevQueryEventSystem command of the
+//                    DServer.
+//
+//-----------------------------------------------------------------------------
+
+CORBA::Any *DevQueryEventSystemCmd::execute(DeviceImpl *device, TANGO_UNUSED(const CORBA::Any &in_any))
+{
+    auto *out_any = new CORBA::Any();
+
+    Tango::DevString ret = (static_cast<DServer *>(device))->query_event_system();
+    (*out_any) <<= ret;
+
+    return out_any;
+}
+
+//+----------------------------------------------------------------------------
+//
+// method :         DevEnableEventSystemPerfMonCmd::DevEnableEventSystemPerfMonCmd()
+//
+// description :     method to trigger the execution of the "EnableEventSystemPerfMon"
+//                    command
+//
+//-----------------------------------------------------------------------------
+
+DevEnableEventSystemPerfMonCmd::DevEnableEventSystemPerfMonCmd(const char *name,
+                                                               Tango::CmdArgType argin,
+                                                               Tango::CmdArgType argout,
+                                                               const char *in_desc) :
+    Command(name, argin, argout)
+{
+    set_in_type_desc(in_desc);
+}
+
+//+----------------------------------------------------------------------------
+//
+// method :         DevEnableEventSystemPerfMonCmd::execute()
+//
+// description :     constructor for the DevEnableEventSystemPerfMon command of the
+//                    DServer.
+//
+//-----------------------------------------------------------------------------
+
+CORBA::Any *DevEnableEventSystemPerfMonCmd::execute(DeviceImpl *device, const CORBA::Any &in_any)
+{
+    Tango::DevBoolean enabled;
+    in_any >>= enabled;
+
+    (static_cast<DServer *>(device))->enable_event_system_perf_mon(enabled);
+
+    CORBA::Any *ret = return_empty_any("DevEnableEventSystemPerfMonCmd");
+    return ret;
+}
+
 //+----------------------------------------------------------------------------
 //
 // method :         DevKillCmd::DevKillCmd()
@@ -385,9 +462,6 @@ CORBA::Any *DevSetTraceLevelCmd::execute(TANGO_UNUSED(DeviceImpl *device), TANGO
     TANGO_LOG_DEBUG << "DevSetTraceLevelCmd::execute(): arrived" << std::endl;
 
     TANGO_THROW_EXCEPTION(API_DeprecatedCommand, "SetTraceLevel is no more supported, please use SetLoggingLevel");
-
-    CORBA::Any *ret = return_empty_any("DevSetTraceLevelCmd");
-    return ret;
 }
 
 //+----------------------------------------------------------------------------
@@ -422,13 +496,6 @@ CORBA::Any *DevGetTraceLevelCmd::execute(TANGO_UNUSED(DeviceImpl *device), TANGO
     TANGO_LOG_DEBUG << "DevGetTraceLevelCmd::execute(): arrived" << std::endl;
 
     TANGO_THROW_EXCEPTION(API_DeprecatedCommand, "GetTraceLevel is no more supported, please use GetLoggingLevel");
-
-    //
-    // Make the compiler happy
-    //
-
-    CORBA::Any *ret = return_empty_any("DevGetTraceLevelCmd");
-    return ret;
 }
 
 //+----------------------------------------------------------------------------
@@ -463,9 +530,6 @@ CORBA::Any *DevGetTraceOutputCmd::execute(TANGO_UNUSED(DeviceImpl *device), TANG
     TANGO_LOG_DEBUG << "DevGetTraceOutputCmd::execute(): arrived" << std::endl;
 
     TANGO_THROW_EXCEPTION(API_DeprecatedCommand, "GetTraceOutput is no more supported, please use GetLoggingTarget");
-
-    CORBA::Any *ret = return_empty_any("DevGetTraceOutputCmd");
-    return ret;
 }
 
 //+----------------------------------------------------------------------------
@@ -500,9 +564,6 @@ CORBA::Any *DevSetTraceOutputCmd::execute(TANGO_UNUSED(DeviceImpl *device), TANG
     TANGO_LOG_DEBUG << "DevSetTraceOutputCmd::execute(): arrived" << std::endl;
 
     TANGO_THROW_EXCEPTION(API_DeprecatedCommand, "SetTraceOutput is no more supported, please use AddLoggingTarget");
-
-    CORBA::Any *ret = return_empty_any("DevSetTraceOutputCmd");
-    return ret;
 }
 
 //+----------------------------------------------------------------------------
@@ -1286,11 +1347,6 @@ DServerClass *DServerClass::_instance = nullptr;
 //
 //-----------------------------------------------------------------------------
 
-bool less_than_dserver(Command *a, Command *b)
-{
-    return a->get_name() < b->get_name();
-}
-
 DServerClass::DServerClass(const std::string &s) :
     DeviceClass(s)
 {
@@ -1307,7 +1363,9 @@ DServerClass::DServerClass(const std::string &s) :
         // Sort commands
         //
 
-        sort(get_command_list().begin(), get_command_list().end(), less_than_dserver);
+        sort(get_command_list().begin(),
+             get_command_list().end(),
+             [](Command *a, Command *b) { return a->get_name() < b->get_name(); });
 
         //
         // Create device name from device server name
@@ -1408,6 +1466,13 @@ void DServerClass::command_factory()
     command_list.push_back(new DevQuerySubDeviceCmd(
         "QuerySubDevice", Tango::DEV_VOID, Tango::DEVVAR_STRINGARRAY, "Device server sub device(s) list"));
     command_list.push_back(new DevKillCmd("Kill", Tango::DEV_VOID, Tango::DEV_VOID));
+    command_list.push_back(new DevQueryEventSystemCmd(
+        "QueryEventSystem", Tango::DEV_VOID, Tango::DEV_STRING, "JSON object with information about the event system"));
+    command_list.push_back(
+        new DevEnableEventSystemPerfMonCmd("EnableEventSystemPerfMon",
+                                           Tango::DEV_BOOLEAN,
+                                           Tango::DEV_VOID,
+                                           "Enable or disable the collection of performance samples for events"));
 
     //
     // Now, commands related to polling
@@ -1541,12 +1606,12 @@ void DServerClass::device_factory(const Tango::DevVarStringArray *devlist_ptr)
         //
         // Create device and add it into the device list
         //
-        DServer *dserver =
-            new DServer(this, (*devlist_ptr)[i], "A device server device !!", Tango::ON, "The device is ON");
+        auto dserver = std::make_unique<DServer>(
+            this, (*devlist_ptr)[i], "A device server device !!", Tango::ON, "The device is ON");
 
         dserver->init_device();
 
-        device_list.push_back(dserver);
+        device_list.push_back(dserver.release());
 
         //
         // Export device to the outside world
