@@ -35,7 +35,8 @@
 //
 //-=============================================================================
 
-#include <tango/tango.h>
+#include <tango/server/dserver.h>
+#include <tango/server/utils.h>
 
 namespace Tango
 {
