@@ -30,8 +30,12 @@
 //
 //-=================================================================================================================
 
-#include <tango/tango.h>
+#include <tango/server/dserver.h>
 #include <tango/server/tango_clock.h>
+#include <tango/server/command.h>
+#include <tango/server/fwdattribute.h>
+#include <tango/client/Database.h>
+#include <tango/client/DbDevice.h>
 
 #include <iomanip>
 
@@ -1005,7 +1009,7 @@ void DServer::add_obj_polling(const Tango::DevVarLongStringArray *argin, bool wi
 
             for(iter = ppc.begin(); iter != ppc.end(); ++iter)
             {
-                std::string v_entry = *iter;
+                const std::string &v_entry = *iter;
                 unsigned int length = v_entry.size();
                 int nb_lines = (length / MaxDevPropLength) + 1;
 
