@@ -33,6 +33,10 @@
 //=============================================================================
 
 #include <tango/server/encoded_attribute.h>
+#include <tango/common/utils/assert.h>
+#include <tango/client/DeviceAttribute.h>
+#include <tango/server/except.h>
+#include <tango/client/apiexcept.h>
 
 #ifdef TANGO_USE_JPEG
   #include <iostream>
@@ -45,7 +49,7 @@ using namespace Tango;
     if(x)            \
     {                \
         free(x);     \
-        x = NULL;    \
+        x = nullptr; \
     }
 
 // ----------------------------------------------------------------------------
@@ -154,7 +158,7 @@ void EncodedAttribute::encode_jpeg_rgb24(unsigned char *rgb24, int width, int he
 
 void EncodedAttribute::encode_gray8(const unsigned char *gray8, int width, int height)
 {
-    long unsigned int newSize = width * height + 4;
+    long unsigned int newSize = (width * height) + 4;
 
     if(manage_exclusion)
     {
@@ -186,7 +190,7 @@ void EncodedAttribute::encode_gray8(const unsigned char *gray8, int width, int h
 
 void EncodedAttribute::encode_gray16(const unsigned short *gray16, int width, int height)
 {
-    long unsigned int newSize = width * height * 2 + 4;
+    long unsigned int newSize = (width * height * 2) + 4;
 
     if(manage_exclusion)
     {
@@ -228,7 +232,7 @@ void EncodedAttribute::encode_gray16(const unsigned short *gray16, int width, in
 
 void EncodedAttribute::encode_rgb24(const unsigned char *rgb24, int width, int height)
 {
-    long unsigned int newSize = width * height * 3 + 4;
+    long unsigned int newSize = (width * height * 3) + 4;
 
     if(manage_exclusion)
     {
