@@ -28,8 +28,12 @@
 //
 //-=================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/server/dserver.h>
+#include <tango/server/utils.h>
+#include <tango/server/pipe.h>
+#include <tango/server/fwdattribute.h>
+#include <tango/internal/utils.h>
 
 namespace Tango
 {
@@ -106,7 +110,7 @@ DevLong DServer::event_subscription_change(const Tango::DevVarStringArray *argin
     //
     // Check if the request comes from a Tango 6 client (without client identification)
     // If true, the event has to be sent using AttributeValue_3 data structure
-    // If cl is NULL, this means that the call is local (Two tango classes within the same process and with events
+    // If cl is nullptr, this means that the call is local (Two tango classes within the same process and with events
     // between device from class 1 and device from classs 2)
     //
 
@@ -714,14 +718,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         // Check event type validity
         //
 
-        std::string check_event = event;
-        std::transform(check_event.begin(), check_event.end(), check_event.begin(), ::tolower);
-
-        std::string::size_type pos_check = check_event.find(EVENT_COMPAT);
-        if(pos_check != std::string::npos)
-        {
-            check_event.erase(0, EVENT_COMPAT_IDL5_SIZE);
-        }
+        std::string check_event = detail::remove_idl_prefix(detail::to_lower(event));
 
         size_t nb_event_type = sizeof(EventName) / sizeof(char *);
         bool found = false;
@@ -772,14 +769,11 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
 
             if(client_release == 0)
             {
-                std::string::size_type pos = event.find(EVENT_COMPAT);
-                if(pos != std::string::npos)
+                auto client_release_opt = detail::extract_idl_version_from_event_name(event);
+                if(client_release_opt.has_value())
                 {
-                    std::string client_lib_str = event.substr(pos + 3, 1);
-                    std::stringstream ss;
-                    ss << client_lib_str;
-                    ss >> client_release;
-                    event.erase(0, EVENT_COMPAT_IDL5_SIZE);
+                    client_release = client_release_opt.value();
+                    event = detail::remove_idl_prefix(event);
                 }
                 else
                 {
@@ -796,8 +790,8 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
                         //
                         // Check if the request comes from a Tango 6 client (without client identification)
                         // If true, the event has to be sent using AttributeValue_3 data structure
-                        // If cl is NULL, this means that the call is local (Two tango classes within the same process
-                        // and with events between device from class 1 and device from classs 2)
+                        // If cl is nullptr, this means that the call is local (Two tango classes within the same
+                        // process and with events between device from class 1 and device from classs 2)
                         //
 
                         client_addr *cl = get_client_ident();
@@ -869,7 +863,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         }
 
         long idl_vers = dev->get_dev_idl_version();
-        if(idl_vers < 4)
+        if(idl_vers < MIN_IDL_ZMQ_EVENT)
         {
             TangoSys_OMemStream o;
 
@@ -878,20 +872,12 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
             TANGO_THROW_EXCEPTION(API_CommandNotFound, o.str());
         }
 
-        if(client_release > idl_vers)
-        {
-            client_release = idl_vers;
-        }
+        client_release = std::min<long>(client_release, idl_vers);
 
         //
         // Call common method (common between old and new command)
         //
-
-        std::string::size_type pos = event.find(EVENT_COMPAT);
-        if(pos != std::string::npos)
-        {
-            event.erase(0, EVENT_COMPAT_IDL5_SIZE);
-        }
+        event = detail::remove_idl_prefix(event);
 
         event_subscription(*dev, obj_name, action, event, ZMQ, client_release);
 
@@ -1062,7 +1048,7 @@ DevVarLongStringArray *DServer::zmq_event_subscription_change(const Tango::DevVa
         if(client_release >= 5 &&
            add_compat_info) // client_release here is the minimum of the client release and dev IDL version
         {
-            event_topic = ev->create_full_event_name(dev, EVENT_COMPAT_IDL5 + event, obj_name_lower, intr_change);
+            event_topic = ev->create_full_event_name(dev, detail::add_idl_prefix(event), obj_name_lower, intr_change);
         }
         else
         {
@@ -1148,16 +1134,12 @@ void DServer::event_confirm_subscription(const Tango::DevVarStringArray *argin)
 
         std::string action("subscribe");
         int client_lib = 0;
-        std::string client_lib_str;
 
-        std::string::size_type pos = event.find(EVENT_COMPAT);
-        if(pos != std::string::npos)
+        auto client_lib_opt = detail::extract_idl_version_from_event_name(event);
+        if(client_lib_opt.has_value())
         {
-            client_lib_str = event.substr(pos + 3, 1);
-            std::stringstream ss;
-            ss << client_lib_str;
-            ss >> client_lib;
-            event.erase(0, EVENT_COMPAT_IDL5_SIZE);
+            client_lib = client_lib_opt.value();
+            event = detail::remove_idl_prefix(event);
         }
         else
         {
