@@ -31,10 +31,12 @@
 //
 //====================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/server/eventsupplier.h>
 #include <tango/client/apiexcept.h>
 #include <tango/server/exception_reason_consts.h>
+#include <tango/server/device.h>
+#include <tango/client/Database.h>
+#include <tango/internal/utils.h>
 
 #ifdef _TG_WINDOWS_
   #include <float.h>
@@ -124,7 +126,7 @@ EventSupplier::EventSupplier(Util *tg)
 //        in :
 //            - device_impl : The device
 //            - attr_value : The attribute value
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //            - attr_name : The attribute name
 //          - time_bef_attr : Exact date when the attribute has been read
 //
@@ -366,7 +368,7 @@ SendEventType EventSupplier::detect_and_push_events(DeviceImpl *device_impl,
 //            - attr_value : The attribute value
 //            - attr : The attribute object
 //            - attr_name : The attribute name
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //             - user_push : Flag set to true if it is a user push
 //
 //--------------------------------------------------------------------------------------------------------------------
@@ -419,6 +421,7 @@ bool EventSupplier::detect_and_push_change_event(DeviceImpl *device_impl,
 
     if(!attr.prev_change_event.inited)
     {
+        TANGO_LOG_DEBUG << "EventSupplier::detect_and_push_change_event(): no previous value" << std::endl;
         attr.prev_change_event.store(
             attr_value.attr_val_5, attr_value.attr_val_4, attr_value.attr_val_3, attr_value.attr_val, except);
         is_change = true;
@@ -504,7 +507,7 @@ bool EventSupplier::detect_and_push_change_event(DeviceImpl *device_impl,
             case 5:
             {
                 convert_att_event_to_5(attr_value, sent_value, need_free, attr);
-                ev_name = EVENT_COMPAT_IDL5 + ev_name;
+                ev_name = detail::add_idl_prefix(ev_name);
                 name_changed = true;
             }
             break;
@@ -575,7 +578,7 @@ bool EventSupplier::detect_and_push_change_event(DeviceImpl *device_impl,
  *      - attr_value: The attribute value
  *      - attr: The attribute object
  *      - attr_name: The attribute name
- *      - except: The exception thrown during the last attribute reading. NULL
+ *      - except: The exception thrown during the last attribute reading. nullptr
  *                  if no exception.
  *      - user_push : Flag set to true if it is a user push. Note that this
  *                  flag is ignored because alarm events cannot be manually
@@ -712,7 +715,7 @@ bool EventSupplier::detect_and_push_alarm_event(DeviceImpl *device_impl,
 //            - attr_value : The attribute value
 //            - attr : The attribute object
 //            - attr_name : The attribute name
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //            - time_bef_attr : Date before the attribute was read
 //            - user_push : Flag set to true if it's the user who fires the event
 //
@@ -910,7 +913,7 @@ bool EventSupplier::detect_and_push_archive_event(DeviceImpl *device_impl,
             case 5:
             {
                 convert_att_event_to_5(attr_value, sent_value, need_free, attr);
-                ev_name = EVENT_COMPAT_IDL5 + ev_name;
+                ev_name = detail::add_idl_prefix(ev_name);
                 name_changed = true;
             }
             break;
@@ -985,7 +988,7 @@ bool EventSupplier::detect_and_push_archive_event(DeviceImpl *device_impl,
 //            - attr_value : The attribute value
 //            - attr : The attribute object
 //            - attr_name : The attribute name
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //            - time_bef_attr : Date before the attribute was read
 //
 //------------------------------------------------------------------------------------------------------------------
@@ -1072,7 +1075,7 @@ bool EventSupplier::detect_and_push_periodic_event(DeviceImpl *device_impl,
             case 5:
             {
                 convert_att_event_to_5(attr_value, sent_value, need_free, attr);
-                ev_name = EVENT_COMPAT_IDL5 + ev_name;
+                ev_name = detail::add_idl_prefix(ev_name);
                 name_changed = true;
             }
             break;
@@ -1148,7 +1151,7 @@ bool EventSupplier::detect_and_push_periodic_event(DeviceImpl *device_impl,
 //            - archive :
 //            - delta_change_rel :
 //            - delta_change_abs :
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //            - force_change : A flag set to true if the change is due to a non mathematical reason
 //                       (array size change, from exception to classic...)
 //            - dev : Pointer to the device
@@ -1722,9 +1725,8 @@ bool EventSupplier::detect_change(Attribute &attr,
                             if((*curr_seq_sh)[i] != (*prev_seq_sh)[i])
                             {
                                 delta_change_rel = delta_change_abs = 100.;
-                                is_change = true;
+                                return true;
                             }
-                            return is_change;
                         }
                     }
                     else
@@ -2455,7 +2457,7 @@ void EventSupplier::push_att_data_ready_event(DeviceImpl *device_impl,
 //        in :
 //            - device_impl : The device
 //            - attr_conf : The attribute configuration
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //          - attr_name : The attribute name
 //
 //------------------------------------------------------------------------------------------------------------------
@@ -2523,7 +2525,7 @@ void EventSupplier::push_att_conf_events(DeviceImpl *device_impl,
     std::string ev_type = CONF_TYPE_EVENT;
     if(vers >= 5)
     {
-        ev_type = EVENT_COMPAT_IDL5 + ev_type;
+        ev_type = detail::add_idl_prefix(ev_type);
     }
 
     push_event(device_impl,
