@@ -32,7 +32,12 @@
 //
 //-=============================================================================
 
-#include <tango/tango.h>
+#include <tango/server/except.h>
+#include <tango/server/tango_config.h>
+#include <tango/server/device.h>
+#include <tango/client/apiexcept.h>
+
+#include <tango/internal/utils.h>
 
 namespace Tango
 {
@@ -93,26 +98,7 @@ void Except::print_exception(const CORBA::Exception &e, std::ostream &os)
                 os << "   Index of object in call (starting at 0) = " << mdf->err_list[i].idx_in_call << std::endl;
                 for(unsigned long j = 0; j < mdf->err_list[i].err_stack.length(); j++)
                 {
-                    os << "       Severity = ";
-                    switch(mdf->err_list[i].err_stack[j].severity)
-                    {
-                    case Tango::WARN:
-                        os << "WARNING ";
-                        break;
-
-                    case Tango::ERR:
-                        os << "ERROR ";
-                        break;
-
-                    case Tango::PANIC:
-                        os << "PANIC ";
-                        break;
-
-                    default:
-                        os << "Unknown severity code";
-                        break;
-                    }
-                    os << std::endl;
+                    os << "       Severity = " << mdf->err_list[i].err_stack[j].severity << std::endl;
                     os << "       Error reason = " << mdf->err_list[i].err_stack[j].reason.in() << std::endl;
                     os << "       Desc : " << mdf->err_list[i].err_stack[j].desc.in() << std::endl;
                     os << "       Origin : " << mdf->err_list[i].err_stack[j].origin.in() << std::endl;
@@ -121,26 +107,7 @@ void Except::print_exception(const CORBA::Exception &e, std::ostream &os)
             os << "   Summary exception" << std::endl;
             for(unsigned long j = 0; j < mdf->errors.length(); j++)
             {
-                os << "       Severity = ";
-                switch(mdf->errors[j].severity)
-                {
-                case Tango::WARN:
-                    os << "WARNING ";
-                    break;
-
-                case Tango::ERR:
-                    os << "ERROR ";
-                    break;
-
-                case Tango::PANIC:
-                    os << "PANIC ";
-                    break;
-
-                default:
-                    os << "Unknown severity code";
-                    break;
-                }
-                os << std::endl;
+                os << "       Severity = " << mdf->errors[j].severity << std::endl;
                 os << "       Error reason = " << mdf->errors[j].reason.in() << std::endl;
                 os << "       Desc : " << mdf->errors[j].desc.in() << std::endl;
                 os << "       Origin : " << mdf->errors[j].origin.in() << std::endl;
@@ -157,26 +124,7 @@ void Except::print_exception(const CORBA::Exception &e, std::ostream &os)
             for(unsigned long i = 0; i < te->errors.length(); i++)
             {
                 os << "Tango exception" << std::endl;
-                os << "Severity = ";
-                switch(te->errors[i].severity)
-                {
-                case Tango::WARN:
-                    os << "WARNING ";
-                    break;
-
-                case Tango::ERR:
-                    os << "ERROR ";
-                    break;
-
-                case Tango::PANIC:
-                    os << "PANIC ";
-                    break;
-
-                default:
-                    os << "Unknown severity code";
-                    break;
-                }
-                os << std::endl;
+                os << "Severity = " << te->errors[i].severity << std::endl;
                 os << "Error reason = " << te->errors[i].reason.in() << std::endl;
                 os << "Desc : " << te->errors[i].desc.in() << std::endl;
                 os << "Origin : " << te->errors[i].origin.in() << std::endl;
@@ -831,6 +779,11 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
     return error_msg;
 }
 
+void Except::print_error_stack(const Tango::DevErrorList &e)
+{
+    print_error_stack(e, std::cerr);
+}
+
 //+----------------------------------------------------------------------------
 //
 // method :         print_error_stack
@@ -840,36 +793,16 @@ char *Except::print_CORBA_SystemException_r(const CORBA::SystemException *e, cha
 // in :            e : Reference to the error stack
 //
 //-----------------------------------------------------------------------------
-
-void Except::print_error_stack(const Tango::DevErrorList &e)
+void Except::print_error_stack(const Tango::DevErrorList &e, std::ostream &os)
 {
     for(unsigned long i = 0; i < e.length(); i++)
     {
-        std::cerr << "Tango error stack" << std::endl;
-        std::cerr << "Severity = ";
-        switch(e[i].severity)
-        {
-        case Tango::WARN:
-            std::cerr << "WARNING ";
-            break;
-
-        case Tango::ERR:
-            std::cerr << "ERROR ";
-            break;
-
-        case Tango::PANIC:
-            std::cerr << "PANIC ";
-            break;
-
-        default:
-            std::cerr << "Unknown severity code";
-            break;
-        }
-        std::cerr << std::endl;
-        std::cerr << "Error reason = " << e[i].reason.in() << std::endl;
-        std::cerr << "Desc : " << e[i].desc.in() << std::endl;
-        std::cerr << "Origin : " << e[i].origin.in() << std::endl;
-        std::cerr << std::endl;
+        os << "Tango error stack" << std::endl;
+        os << "Severity = " << e[i].severity << std::endl;
+        os << "Error reason = " << e[i].reason.in() << std::endl;
+        os << "Desc : " << e[i].desc.in() << std::endl;
+        os << "Origin : " << e[i].origin.in() << std::endl;
+        os << std::endl;
     }
 }
 
