@@ -31,7 +31,16 @@
 //
 //-=============================================================================
 
-#include <tango/tango.h>
+#include <tango/server/logstream.h>
+#include <tango/common/log4tango/LoggerStream.h>
+
+#include <tango/common/tango_const.h>
+#include <tango/server/tango_config.h>
+#include <tango/server/attribute.h>
+#include <tango/server/attrmanip.h>
+#include <tango/server/dserver.h>
+#include <tango/server/device.h>
+#include <tango/client/DeviceProxy.h>
 
 namespace Tango
 {
@@ -247,13 +256,18 @@ log4tango::LoggerStream &operator<<(log4tango::LoggerStream &ls, const Attribute
         break;
     }
 
-    if(conf.writable == static_cast<unsigned char>(true))
+    switch(conf.writable)
     {
+    case WRITE:
+    case READ_WITH_WRITE:
+    case READ_WRITE:
         ls << "Attribute is writable" << std::endl;
-    }
-    else
-    {
+        break;
+    case READ:
+    case WT_UNKNOWN:
+    default:
         ls << "Attribute is not writable" << std::endl;
+        break;
     }
     ls << "Attribute label: " << conf.label.in() << std::endl;
     ls << "Attribute description: " << conf.description.in() << std::endl;
