@@ -36,8 +36,12 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <tango/tango.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/server/dserver.h>
+#include <tango/server/device.h>
+#include <tango/client/Database.h>
+
+#include <tango/internal/utils.h>
 
 #include <COS/CosNotification.hh>
 #include <COS/CosNotifyChannelAdmin.hh>
@@ -883,7 +887,7 @@ void NotifdEventSupplier::disconnect_from_notifd()
 //                    filterable_data :
 //                    attr_value : The attribute value
 //                    except : The exception thrown during the last
-//                        attribute reading. NULL if no exception
+//                        attribute reading. nullptr if no exception
 //
 //-----------------------------------------------------------------------------
 
@@ -919,11 +923,7 @@ void NotifdEventSupplier::push_event(DeviceImpl *device_impl,
     std::transform(loc_attr_name.begin(), loc_attr_name.end(), loc_attr_name.begin(), ::tolower);
     domain_name = device_impl->get_name_lower() + "/" + loc_attr_name;
 
-    std::string::size_type pos = event_type.find(EVENT_COMPAT);
-    if(pos != std::string::npos)
-    {
-        event_type.erase(0, EVENT_COMPAT_IDL5_SIZE);
-    }
+    event_type = detail::remove_idl_prefix(event_type);
 
     struct_event.header.fixed_header.event_type.domain_name = Tango::string_dup(domain_name.c_str());
     struct_event.header.fixed_header.event_type.type_name = Tango::string_dup(fqdn_prefix.c_str());
