@@ -29,9 +29,15 @@
 //
 //-==================================================================================================================
 
-#include <tango/tango.h>
+#include <tango/internal/utils.h>
 #include <tango/server/rootattreg.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/server/device.h>
+#include <tango/server/device_5.h>
+#include <tango/server/fwdattribute.h>
+#include <tango/server/dserver.h>
+#include <tango/client/event.h>
+#include <tango/client/Database.h>
 
 namespace Tango
 {
@@ -97,13 +103,15 @@ void RootAttRegistry::RootAttConfCallBack::push_event(Tango::AttrConfEventData *
 
                                 auto *ev_fwd = static_cast<FwdAttrConfEventData *>(ev);
                                 AttributeConfig_5 *ptr = const_cast<AttributeConfig_5 *>(ev_fwd->get_fwd_attr_conf());
+                                bool need_release{false};
                                 if(ptr == nullptr)
                                 {
                                     ptr = AttributeConfigList_5::allocbuf(1);
                                     ApiUtil::AttributeInfoEx_to_AttributeConfig(ev->attr_conf, ptr);
+                                    need_release = true;
                                 }
 
-                                AttributeConfigList_5 conf_list(1, 1, ptr, false);
+                                AttributeConfigList_5 conf_list(1, 1, ptr, need_release);
 
                                 //
                                 // The attribute name, root_attr_name and label are local values
@@ -280,7 +288,7 @@ void RootAttRegistry::RootAttUserCallBack::push_event(Tango::EventData *ev)
         EventSupplier::SuppliedEventData ad;
         ::memset(&ad, 0, sizeof(ad));
 
-        std::string event_name = EVENT_COMPAT_IDL5 + ev->event;
+        std::string event_name = detail::add_idl_prefix(ev->event);
 
         if(ev->err)
         {
@@ -382,6 +390,15 @@ void RootAttRegistry::RootAttUserCallBack::push_event(Tango::DataReadyEventData
 //
 //--------------------------------------------------------------------------------------------------------------------
 
+RootAttRegistry::RootAttConfCallBack::~RootAttConfCallBack()
+{
+    for(auto it = map_attrdesc.begin(); it != map_attrdesc.end(); it++)
+    {
+        delete it->second.fwd_attr;
+        it->second.fwd_attr = nullptr;
+    }
+}
+
 void RootAttRegistry::RootAttConfCallBack::add_att(const std::string &root_att_name,
                                                    const std::string &local_dev_name,
                                                    const std::string &local_att_name,
@@ -463,6 +480,8 @@ void RootAttRegistry::RootAttConfCallBack::remove_att(const std::string &root_at
     if(ite != map_attrdesc.end())
     {
         std::string local_dev_name = ite->second.local_name;
+        delete ite->second.fwd_attr;
+        ite->second.fwd_attr = nullptr;
         map_attrdesc.erase(ite);
 
         bool used_elsewhere = false;
@@ -517,6 +536,7 @@ void RootAttRegistry::RootAttConfCallBack::clear_attrdesc(const std::string &roo
     ite = map_attrdesc.find(root_att_name);
     if(ite != map_attrdesc.end())
     {
+        delete ite->second.fwd_attr;
         ite->second.fwd_attr = nullptr;
     }
     else
@@ -700,6 +720,15 @@ bool RootAttRegistry::RootAttConfCallBack::is_root_dev_not_started_err()
 //
 //--------------------------------------------------------------------------------------------------------------------
 
+RootAttRegistry::~RootAttRegistry()
+{
+    for(auto it = dps.begin(); it != dps.end(); it++)
+    {
+        delete it->second;
+        it->second = nullptr;
+    }
+}
+
 void RootAttRegistry::add_root_att(const std::string &device_name,
                                    const std::string &att_name,
                                    const std::string &local_dev_name,
