@@ -32,7 +32,12 @@
 //
 //-=============================================================================
 
-#include <tango/tango.h>
+#include <tango/server/subdev_diag.h>
+#include <tango/server/dserver.h>
+#include <tango/server/device.h>
+#include <tango/internal/parse.h>
+
+#include <tango/client/Database.h>
 
 namespace Tango
 {
@@ -273,11 +278,6 @@ Tango::DevVarStringArray *SubDevDiag::get_sub_devices()
     {
         TANGO_THROW_EXCEPTION(API_MemoryAllocation, "Can't allocate memory in server");
     }
-
-    // Should never reach here. To make compiler happy
-
-    ret = nullptr;
-    return ret;
 }
 
 //+----------------------------------------------------------------------------
@@ -440,7 +440,7 @@ void SubDevDiag::get_sub_devices_from_cache()
             try
             {
                 const DevVarStringArray *property_values = db_cache->get_dev_property(property_names);
-                if(atol((*property_values)[3]) > 0)
+                if(detail::parse_as<long>((*property_values)[3].in()) > 0)
                 {
                     // if the device is the admin device, set dev_name to ""
                     // to have the same syntax as in the dynamically created
