@@ -29,8 +29,10 @@
 //
 //-==================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/server/tango_clock.h>
+#include <tango/server/dserver.h>
+#include <tango/server/command.h>
+#include <tango/client/Database.h>
 
 #include <iostream>
 #include <algorithm>
@@ -174,10 +176,7 @@ void Util::polling_configure()
                 }
                 else
                 {
-                    if(upd < smallest_upd)
-                    {
-                        smallest_upd = upd;
-                    }
+                    smallest_upd = std::min(upd, smallest_upd);
                 }
 
                 v_poll_cmd.push_back(send);
@@ -226,10 +225,7 @@ void Util::polling_configure()
                     }
                     else
                     {
-                        if(upd < smallest_upd)
-                        {
-                            smallest_upd = upd;
-                        }
+                        smallest_upd = std::min(upd, smallest_upd);
                     }
                     v_poll_cmd.push_back(send);
                 }
@@ -905,10 +901,8 @@ int Util::create_poll_thread(const char *dev_name, bool startup, bool polling_9,
         if(smallest_upd != -1)
         {
             PollingThreadInfo *th_info = get_polling_thread_info_by_id(ite->second);
-            if(smallest_upd < th_info->smallest_upd)
-            {
-                th_info->smallest_upd = smallest_upd;
-            }
+
+            th_info->smallest_upd = std::min(smallest_upd, th_info->smallest_upd);
         }
         return ret;
     }
@@ -951,10 +945,7 @@ int Util::create_poll_thread(const char *dev_name, bool startup, bool polling_9,
                     th_info->nb_polled_objects++;
                     if(smallest_upd != -1)
                     {
-                        if(smallest_upd < th_info->smallest_upd)
-                        {
-                            th_info->smallest_upd = smallest_upd;
-                        }
+                        th_info->smallest_upd = std::min(smallest_upd, th_info->smallest_upd);
                     }
                     ret = ind;
                     return ret;
@@ -1022,10 +1013,7 @@ int Util::create_poll_thread(const char *dev_name, bool startup, bool polling_9,
                         PollingThreadInfo *th_info = get_polling_thread_info_by_id(ite->second);
                         th_info->polled_devices.push_back(local_dev_name);
                         th_info->nb_polled_objects++;
-                        if(smallest_upd < th_info->smallest_upd)
-                        {
-                            th_info->smallest_upd = smallest_upd;
-                        }
+                        th_info->smallest_upd = std::min(smallest_upd, th_info->smallest_upd);
                     }
                     ret = ind;
                     return ret;
@@ -1098,10 +1086,7 @@ int Util::create_poll_thread(const char *dev_name, bool startup, bool polling_9,
         dev_poll_th_map.insert(make_pair(local_dev_name, (*lower_iter)->thread_id));
         if(smallest_upd != -1)
         {
-            if(smallest_upd < (*lower_iter)->smallest_upd)
-            {
-                (*lower_iter)->smallest_upd = smallest_upd;
-            }
+            (*lower_iter)->smallest_upd = std::min(smallest_upd, (*lower_iter)->smallest_upd);
         }
         ret = ind;
     }
@@ -1780,7 +1765,7 @@ void Util::upd_polling_prop(const std::vector<DevDbUpd> &upd_devs, DServer *admi
 
                     for(iter = poll_pool_conf.begin(); iter != poll_pool_conf.end(); ++iter)
                     {
-                        std::string v_entry = *iter;
+                        const std::string &v_entry = *iter;
                         unsigned int length = v_entry.size();
                         int nb_lines = (length / MaxDevPropLength) + 1;
                         if(nb_lines > 1)
@@ -1992,7 +1977,7 @@ int Util::get_dev_entry_in_pool_conf(const std::string &dev_name)
 
     for(iter = poll_pool_conf.begin(); iter != poll_pool_conf.end(); ++iter)
     {
-        std::string tmp = *iter;
+        const std::string &tmp = *iter;
         std::string::size_type pos, end_pos;
         pos = tmp.find(dev_name);
         if(pos != std::string::npos)
