@@ -32,9 +32,11 @@
 //
 //-=============================================================================
 
-#include <tango/tango.h>
 #include <tango/client/eventconsumer.h>
+#include <tango/server/utils.h>
+#include <tango/server/dserver.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/client/Database.h>
 
 namespace Tango
 {
@@ -63,7 +65,6 @@ void Util::shutdown_ds()
     //          they have been started to receive events
     //        - Force writing file database in case of
     //        - Shutdown the ORB
-    //        - Cleanup Logging
     //
 
     set_svr_shutting_down(true);
@@ -100,22 +101,7 @@ void Util::shutdown_ds()
     //
 
     ApiUtil *au = ApiUtil::instance();
-    if(au->is_notifd_event_consumer_created())
-    {
-        NotifdEventConsumer *ec = ApiUtil::instance()->get_notifd_event_consumer();
-        if(ec != nullptr)
-        {
-            ec->shutdown();
-        }
-    }
-    if(au->is_zmq_event_consumer_created())
-    {
-        ZmqEventConsumer *ec = ApiUtil::instance()->get_zmq_event_consumer();
-        if(ec != nullptr)
-        {
-            ec->shutdown();
-        }
-    }
+    au->shutdown_event_consumers();
 
     //
     // Disconnect the server from the notifd, when it was connected
@@ -164,11 +150,6 @@ void Util::shutdown_ds()
     loc_orb->shutdown(true);
 
     TANGO_LOG_DEBUG << "ORB shutdown" << std::endl;
-
-    // clean-up the logging system
-
-    Logging::cleanup();
-    TANGO_LOG_DEBUG << "Logging cleaned-up" << std::endl;
 }
 
 } // namespace Tango
