@@ -30,11 +30,17 @@
 //
 //+==================================================================================================================
 
-#include <tango/tango.h>
 #include <tango/internal/net.h>
+#include <tango/internal/utils.h>
 #include <tango/server/eventsupplier.h>
+#include <tango/server/pipe.h>
+#include <tango/server/device.h>
+#include <tango/server/dserver.h>
+#include <tango/server/utils.h>
+#include <tango/client/apiexcept.h>
 
 #include <omniORB4/internal/giopStream.h>
+#include <tango/internal/perf_mon.h>
 
 #include <iterator>
 #include <future>
@@ -195,6 +201,12 @@ ZmqEventSupplier::ZmqEventSupplier(Util *tg) :
     {
         tango_bind(heartbeat_pub_sock, heartbeat_endpoint);
     }
+    catch(Tango::DevFailed &ex)
+    {
+        delete heartbeat_pub_sock;
+        heartbeat_pub_sock = nullptr;
+        TANGO_RETHROW_DETAILED_EXCEPTION(EventSystemExcept, ex, API_ZmqInitFailed, "Failed to bind heartbeat socket");
+    }
     catch(...)
     {
         delete heartbeat_pub_sock;
@@ -417,9 +429,17 @@ void ZmqEventSupplier::tango_bind(zmq::socket_t *sock, std::string &endpoint)
             endpoint = endpoint + port_str;
         }
     }
+    catch(const zmq::error_t &ex)
+    {
+        std::stringstream ss;
+        ss << "Cannot bind to ZMQ endpoint \"" << base_endpoint << "\": " << ex.what();
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_ZmqInitFailed, ss.str());
+    }
     catch(...)
     {
-        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_ZmqInitFailed, "Can't bind the ZMQ socket!");
+        std::stringstream ss;
+        ss << "Cannot bind to ZMQ endpoint \"" << base_endpoint << "\"";
+        TANGO_THROW_DETAILED_EXCEPTION(EventSystemExcept, API_ZmqInitFailed, ss.str());
     }
 }
 
@@ -516,6 +536,12 @@ void ZmqEventSupplier::create_event_socket()
         {
             tango_bind(event_pub_sock, event_endpoint);
         }
+        catch(Tango::DevFailed &ex)
+        {
+            delete event_pub_sock;
+            event_pub_sock = nullptr;
+            TANGO_RETHROW_DETAILED_EXCEPTION(EventSystemExcept, ex, API_ZmqInitFailed, "Failed to bind event socket");
+        }
         catch(...)
         {
             delete event_pub_sock;
@@ -815,6 +841,92 @@ void ZmqEventSupplier::init_event_cptr(const std::string &event_name)
     }
 }
 
+// Performance monitoring
+namespace
+{
+struct PerfMonSample
+{
+    std::int64_t micros_since_last_event{k_invalid_duration};
+    std::int64_t push_event_micros{0};
+
+    void json_dump(std::ostream &os)
+    {
+        os << "{\"micros_since_last_event\":";
+        if(micros_since_last_event != k_invalid_duration)
+        {
+            os << micros_since_last_event;
+        }
+        else
+        {
+            os << "null";
+        }
+        os << ",\"push_event_micros\":" << push_event_micros;
+        os << "}";
+    }
+};
+
+DoubleBuffer<PerfMonSample> g_perf_mon;
+
+// Must hold g_perf_mon.lock to access
+PerfClock::time_point g_last_event_timestamp;
+} // namespace
+
+//---------------------------------------------------------------------------------------------------------------------
+//
+// method :
+//        ZmqEventSupplier::query_event_system()
+//
+// description :
+//  Report information about the event supplier as a JSON object.
+//
+// argument :
+//        in :
+//          - os : Output stream to write the JSON object to
+//
+//--------------------------------------------------------------------------------------------------------------------
+
+void ZmqEventSupplier::query_event_system(std::ostream &os)
+{
+    // We don't need to lock access to `event_cptr` because the only time the
+    // map is modified is during the ZmqEventSubscriptionChange() command
+    // where we are holding the `DServer` lock, which we are holding now.  We
+    // might miss an increment of the value from a `push_event` if it is called
+    // from some other thread, but that doesn't really matter.
+    os << R"({"event_counters":{)";
+    bool first = true;
+    for(const auto &pair : event_cptr)
+    {
+        if(!first)
+        {
+            os << ",";
+        }
+        os << "\"" << pair.first << "\":" << pair.second;
+        first = false;
+    }
+    os << R"(},"perf":)";
+    g_perf_mon.json_dump(os);
+    os << "}";
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+//
+// method :
+//        ZmqEventSupplier::enable_perf_mon()
+//
+// description :
+//  Enable or disable collection of performance counters for supplier
+//
+// argument :
+//        in :
+//          - enabled : If true, enable sampling otherwise disable sampling
+//
+//--------------------------------------------------------------------------------------------------------------------
+
+void ZmqEventSupplier::enable_perf_mon(Tango::DevBoolean enabled)
+{
+    g_perf_mon.enable(enabled);
+}
+
 //+-------------------------------------------------------------------------------------------------------------------
 //
 // method :
@@ -998,7 +1110,7 @@ void ZmqEventSupplier::push_heartbeat_event()
 //            - filterable_data :
 //            - attr_value : The attribute value
 //            - obj_name : The attribute/pipe name
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //
 //-------------------------------------------------------------------------------------------------------------------
 
@@ -1014,7 +1126,7 @@ void ZmqEventSupplier::push_heartbeat_event()
 // value. Setting the value of the promise (i.e., of the underlying std::future) will wakeup any thread waiting on this
 // future. Contrary to what could happen with a condition variable, the std::future garantees that the thread calling
 // std::future::wait will never be deadlocked.
-void tg_unlock(TANGO_UNUSED(void *data), void *hint)
+static void tg_unlock(TANGO_UNUSED(void *data), void *hint)
 {
     std::promise<void> *p = static_cast<std::promise<void> *>(hint);
     p->set_value();
@@ -1032,6 +1144,26 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
                                   DevFailed *except,
                                   bool inc_cptr)
 {
+    PerfMonSample sample;
+    SamplePusher<PerfMonSample> pusher{false, sample, *g_perf_mon.front, g_perf_mon.lock};
+    TimeBlockMicros perf_mon;
+    if(g_perf_mon.lock.try_lock())
+    {
+        if(g_perf_mon.enabled)
+        {
+            perf_mon = TimeBlockMicros{true, &sample.push_event_micros};
+            pusher.enabled = true;
+
+            if(g_last_event_timestamp != PerfClock::time_point{})
+            {
+                sample.micros_since_last_event = duration_micros(g_last_event_timestamp, perf_mon.start);
+            }
+            g_last_event_timestamp = perf_mon.start;
+        }
+
+        g_perf_mon.lock.unlock();
+    }
+
     if(device_impl == nullptr)
     {
         return;
@@ -1063,13 +1195,7 @@ void ZmqEventSupplier::push_event(DeviceImpl *device_impl,
     // Don't forget case where we have notifd client (thus with a fqdn_prefix modified)
     //
 
-    std::string local_event_type = event_type;
-
-    std::string::size_type pos = local_event_type.find(EVENT_COMPAT);
-    if(pos != std::string::npos)
-    {
-        local_event_type.erase(0, EVENT_COMPAT_IDL5_SIZE);
-    }
+    std::string local_event_type = detail::remove_idl_prefix(event_type);
 
     bool intr_change = false;
     if(local_event_type == EventName[INTERFACE_CHANGE_EVENT])
@@ -1736,7 +1862,7 @@ bool ZmqEventSupplier::update_connected_client(client_addr *cl)
 //            - filterable_data :
 //            - attr_value : The attribute value
 //            - att : The attribute object reference
-//            - except : The exception thrown during the last attribute reading. NULL if no exception
+//            - except : The exception thrown during the last attribute reading. nullptr if no exception
 //
 //-------------------------------------------------------------------------------------------------------------------
 
@@ -1770,7 +1896,7 @@ void ZmqEventSupplier::push_event_loop(DeviceImpl *device_impl,
 
         if(*ite >= 5 && event_type != ALARM_EVENT)
         {
-            ev_name = EVENT_COMPAT_IDL5 + ev_name;
+            ev_name = detail::add_idl_prefix(ev_name);
             name_changed = true;
         }
 
