@@ -308,7 +308,6 @@ int main(int argc, char **argv)
         dbd.push_back(DbDatum("archive_rel_change"));
         dbd.push_back(DbDatum("archive_period"));
         dba.delete_property(dbd);
-        exit(0);
         dbd.clear();
         a << (short) 2;
         dbd.push_back(a);
@@ -378,14 +377,14 @@ int main(int argc, char **argv)
         std::this_thread::sleep_for(std::chrono::seconds(2));
 
         TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 1);
+        assert(cb.cb_executed == 2);
 
         device->command_inout("IOIncValue");
         device->command_inout("IOIncValue");
 
         std::this_thread::sleep_for(std::chrono::seconds(1));
 
-        assert(cb.cb_executed == 2);
+        assert(cb.cb_executed == 3);
         assert(cb.val == 33);
         assert(cb.val_size == 4);
 
@@ -405,21 +404,21 @@ int main(int argc, char **argv)
 
         // 3 instead of 2 due to the archive_period property
 
-        assert(cb.cb_executed == 3);
+        assert(cb.cb_executed == 4);
 
         device->command_inout("IODecValue");
         device->command_inout("IODecValue");
 
         std::this_thread::sleep_for(std::chrono::seconds(1));
 
-        assert(cb.cb_executed == 3);
+        assert(cb.cb_executed == 4);
 
         device->command_inout("IODecValue");
         device->command_inout("IODecValue");
 
         std::this_thread::sleep_for(std::chrono::seconds(2));
 
-        assert(cb.cb_executed == 4);
+        assert(cb.cb_executed == 5);
         assert(cb.val == 28);
         assert(cb.val_size == 4);
 
@@ -515,148 +514,6 @@ int main(int argc, char **argv)
 
         // start the polling first!
         device->poll_attribute(att_name, 1000);
-#ifdef NOTIFD
-        eve_id = device->subscribe_event(att_name, Tango::ARCHIVE_EVENT, &cb, filters);
-
-        //
-        // Check that the attribute is still polled at 1000 mS
-        //
-
-        po = device->is_attribute_polled(att_name);
-        TEST_LOG << "attribute polled : " << po << std::endl;
-        assert(po == true);
-
-        poll_period = device->get_attribute_poll_period(att_name);
-        TEST_LOG << "att polling period : " << poll_period << std::endl;
-        assert(poll_period == 1000);
-
-        TEST_LOG << "   subscribe_event (with filter) --> OK" << std::endl;
-
-        //
-        // Check that first point has been received
-        //
-
-        assert(cb.cb_executed == 1);
-        assert(cb.val == 30);
-        assert(cb.val_size == 4);
-        TEST_LOG << "   first point received (with filter) --> OK" << std::endl;
-
-        //
-        // Generates a positive change
-        //
-
-        std::this_thread::sleep_for(std::chrono::seconds(1));
-
-        device->command_inout("IOIncValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(1));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 1);
-
-        // Let's hope the polling thread will not start just between the two command_inout
-
-        device->command_inout("IOIncValue");
-        device->command_inout("IOIncValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        assert(cb.cb_executed == 2);
-        assert(cb.val == 33);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   CallBack executed for positive delta (with filter) --> OK" << std::endl;
-
-        //
-        // Generates a negative change
-        //
-
-        device->command_inout("IODecValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 2);
-
-        device->command_inout("IODecValue");
-        device->command_inout("IODecValue");
-        device->command_inout("IODecValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        assert(cb.cb_executed == 3);
-        assert(cb.val == 29);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   CallBack executed for negative delta (with filter) --> OK" << std::endl;
-
-        //
-        // Check that callback was called after adding one elt to the spectrum
-        //
-
-        device->command_inout("IOAddOneElt");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 4);
-        assert(cb.val == 29);
-        assert(cb.val_size == 5);
-
-        TEST_LOG << "   CallBack executed when spectrum size increases (with filter) --> OK" << std::endl;
-
-        //
-        // Check that callback was called after removing one elt to the spectrum
-        //
-
-        device->command_inout("IORemoveOneElt");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 5);
-        assert(cb.val == 29);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   CallBack executed when spectrum size decreases (with filter) --> OK" << std::endl;
-
-        //
-        // Force the attribute to throw exception
-        //
-
-        data_in[0] = 1;
-        data_in[1] = 1;
-        di << data_in;
-
-        device->command_inout("IOAttrThrowEx", di);
-
-        //
-        // Check that callback was called
-        //
-
-        std::this_thread::sleep_for(std::chrono::seconds(3));
-        TEST_LOG << "Callback cb_err = " << cb.cb_err << std::endl;
-        assert(cb.cb_err == 1);
-
-        TEST_LOG << "   CallBack executed when attribute throw exception only once (with filter) --> OK" << std::endl;
-
-        //
-        // Attribute does not send exception any more
-        //
-
-        data_in[0] = 1;
-        data_in[1] = 0;
-        di << data_in;
-
-        device->command_inout("IOAttrThrowEx", di);
-
-        //
-        // unsubscribe to the event
-        //
-
-        device->unsubscribe_event(eve_id);
-        TEST_LOG << "   unsubscribe_event --> OK" << std::endl;
-#endif
 
         //
         // Change the event parameters. This means restart the device to take
@@ -701,75 +558,6 @@ int main(int argc, char **argv)
 
         // start the polling first!
         device->poll_attribute(att_name, 250);
-#ifdef NOTIFD
-        eve_id = device->subscribe_event(att_name, Tango::ARCHIVE_EVENT, &cb, filters);
-
-        //
-        // Check that the attribute is still polled at 1000 mS
-        //
-
-        po = device->is_attribute_polled(att_name);
-        TEST_LOG << "attribute polled : " << po << std::endl;
-        assert(po == true);
-
-        poll_period = device->get_attribute_poll_period(att_name);
-        TEST_LOG << "att polling period : " << poll_period << std::endl;
-        assert(poll_period == 250);
-
-        TEST_LOG << "   subscribe_event (with filter on delta_event) --> OK" << std::endl;
-
-        //
-        // Check that first point has been received
-        //
-
-        assert(cb.cb_executed == 1);
-        assert(cb.val == 30);
-        assert(cb.val_size == 4);
-        TEST_LOG << "   first point received (with delta_event filter) --> OK" << std::endl;
-
-        device->command_inout("IOIncValue");
-
-        std::this_thread::sleep_for(std::chrono::milliseconds(100));
-
-        //
-        // Generates a positive change
-        //
-
-        device->command_inout("IOIncValue");
-        std::this_thread::sleep_for(std::chrono::milliseconds(100));
-        device->command_inout("IOIncValue");
-        std::this_thread::sleep_for(std::chrono::milliseconds(100));
-        device->command_inout("IOIncValue");
-        std::this_thread::sleep_for(std::chrono::milliseconds(700));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 1);
-        assert(cb.val == 30);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   Event filtered with delta_event filter set --> OK" << std::endl;
-
-        //
-        // Change once more the value and wait for the event
-
-        device->command_inout("IOIncValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(1));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 2);
-        assert(cb.val == 35);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   Event received with delta_event filter set --> OK" << std::endl;
-
-        //
-        // unsubscribe to the event
-        //
-
-        device->unsubscribe_event(eve_id);
-        TEST_LOG << "   unsubscribe_event --> OK" << std::endl;
-#endif
 
         //
         // Stop polling
