@@ -1,6 +1,8 @@
+// NOLINTBEGIN(*)
+
 #include <time.h>
 
-#include "common.h"
+#include "old_common.h"
 
 void check_description(
     Tango::DeviceProxy &d, Tango::DeviceProxy &, string &, const char *, const char *, const char *, const char *);
@@ -1015,3 +1017,5 @@ void check_delta_val_value(Tango::DeviceProxy &dev,
         aie = dev.get_attribute_config(att);
         assert (aie.alarms.delta_val == class_desc); */
 }
+
+// NOLINTEND(*)
