@@ -1,5 +1,7 @@
 #include "utils/utils.h"
 
+#include "common.h"
+
 #include <tango/tango.h>
 
 #include <catch2/matchers/catch_matchers_string.hpp>
@@ -53,26 +55,6 @@ struct LoggerSwapper
     std::unique_ptr<TangoTest::Logger> logger;
 };
 
-std::vector<std::string> env_with_log_file(const char *class_name)
-{
-    std::vector<std::string> result;
-    result.reserve(2);
-
-    {
-        std::stringstream ss;
-        ss << TangoTest::detail::k_log_file_env_var << "=" << TangoTest::get_current_log_file_path();
-        result.emplace_back(ss.str());
-    }
-
-    {
-        std::stringstream ss;
-        ss << TangoTest::detail::k_enabled_classes_env_var << "=" << class_name;
-        result.emplace_back(ss.str());
-    }
-
-    return result;
-}
-
 } // namespace
 
 template <class Base>
@@ -97,7 +79,8 @@ SCENARIO("test servers can be started and stopped")
     GIVEN("a server started with basic device class")
     {
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "Empty::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("Empty");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "Empty");
 
         TestServer server;
         server.start("self_test", extra_args, env);
@@ -115,7 +98,7 @@ SCENARIO("test servers can be started and stopped")
 
                 AND_THEN("the logs should only (maybe) contain messages about ports in use")
                 {
-                    using Catch::Matchers::IsEmpty;
+                    using namespace Catch::Matchers;
                     logger->remove_port_in_use_logs();
                     REQUIRE_THAT(logger->logs, IsEmpty());
                 }
@@ -165,8 +148,7 @@ SCENARIO("test servers can be started and stopped")
 
                 AND_THEN("we find a warning about the port being in use")
                 {
-                    using Catch::Matchers::IsEmpty;
-                    using Catch::Matchers::StartsWith;
+                    using namespace Catch::Matchers;
 
                     REQUIRE_THAT(logger->logs, !IsEmpty());
 
@@ -183,7 +165,7 @@ SCENARIO("test servers can be started and stopped")
 
                     AND_THEN("we only find logs about other ports in use (if any)")
                     {
-                        using Catch::Matchers::IsEmpty;
+                        using namespace Catch::Matchers;
                         logger->remove_port_in_use_logs();
                         REQUIRE_THAT(logger->logs, IsEmpty());
                     }
@@ -193,13 +175,22 @@ SCENARIO("test servers can be started and stopped")
 
 #endif
 
+        WHEN("we can restart the server via the admin server")
+        {
+            auto fqtrl = TangoTest::make_nodb_fqtrl(server.get_port(), "TestServer/tests/1");
+
+            auto device = std::make_unique<Tango::DeviceProxy>(fqtrl);
+            auto adm_device = std::unique_ptr<Tango::DeviceProxy>{device->get_adm_device()};
+            REQUIRE_NOTHROW(adm_device->command_inout("RestartServer"));
+        }
+
         WHEN("we stop the server")
         {
             REQUIRE_NOTHROW(server.stop());
 
             THEN("there should be no logs generated")
             {
-                using Catch::Matchers::IsEmpty;
+                using namespace Catch::Matchers;
                 REQUIRE_THAT(logger->logs, IsEmpty());
             }
         }
@@ -224,6 +215,23 @@ class InitCrash : public Base
     void init_device() override { }
 };
 
+template <class Base>
+class InitDeviceException : public Base
+{
+  public:
+    InitDeviceException(Tango::DeviceClass *device_class, const std::string &dev_name) :
+        Base(device_class, dev_name)
+    {
+    }
+
+    ~InitDeviceException() override { }
+
+    void init_device() override
+    {
+        TANGO_THROW_EXCEPTION(Tango::API_StdException, k_helpful_message);
+    }
+};
+
 template <class Base>
 class ExitCrash : public Base
 {
@@ -304,12 +312,13 @@ class ExitTimeout : public Base
 };
 
 TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(InitCrash<TANGO_BASE_CLASS>, InitCrash)
+TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(InitDeviceException<TANGO_BASE_CLASS>, InitDeviceException)
 TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(ExitCrash<TANGO_BASE_CLASS>, ExitCrash)
 TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(DuringCrash<TANGO_BASE_CLASS>, DuringCrash)
 TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(InitTimeout<TANGO_BASE_CLASS>, InitTimeout)
 TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(ExitTimeout<TANGO_BASE_CLASS>, ExitTimeout)
 
-SCENARIO("test server crashes and timeouts are reported")
+SCENARIO("test server crashes, exceptions and timeouts are reported")
 {
     using TestServer = TangoTest::TestServer;
     LoggerSwapper ls;
@@ -319,7 +328,8 @@ SCENARIO("test server crashes and timeouts are reported")
     {
         TestServer server;
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "InitCrash::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("InitCrash");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "InitCrash");
 
         WHEN("we start the server")
         {
@@ -335,7 +345,7 @@ SCENARIO("test server crashes and timeouts are reported")
 
             THEN("a exception should be raised, reporting the helpful message and exit status")
             {
-                using Catch::Matchers::ContainsSubstring;
+                using namespace Catch::Matchers;
                 REQUIRE(what);
                 REQUIRE_THAT(*what, ContainsSubstring(k_helpful_message));
                 REQUIRE_THAT(*what, ContainsSubstring("exit status 0"));
@@ -343,7 +353,43 @@ SCENARIO("test server crashes and timeouts are reported")
 
             THEN("there should be no (non-port-in-use) logs")
             {
-                using Catch::Matchers::IsEmpty;
+                using namespace Catch::Matchers;
+                logger->remove_port_in_use_logs();
+                REQUIRE_THAT(logger->logs, IsEmpty());
+            }
+        }
+    }
+
+    GIVEN("a server that throws in init_device")
+    {
+        TestServer server;
+        std::vector<std::string> extra_args = {"-nodb", "-dlist", "InitDeviceException::TestServer/tests/1"};
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "InitDeviceException");
+
+        WHEN("we start the server")
+        {
+            std::optional<std::string> what = std::nullopt;
+            try
+            {
+                server.start("self_test", extra_args, env);
+            }
+            catch(std::exception &ex)
+            {
+                what = ex.what();
+            }
+
+            THEN("a exception should be raised, reporting the helpful message and exit status")
+            {
+                using namespace Catch::Matchers;
+                REQUIRE(what);
+                REQUIRE_THAT(*what, ContainsSubstring(k_helpful_message));
+                REQUIRE_THAT(*what, ContainsSubstring("exit status 2"));
+            }
+
+            THEN("there should be no (non-port-in-use) logs")
+            {
+                using namespace Catch::Matchers;
                 logger->remove_port_in_use_logs();
                 REQUIRE_THAT(logger->logs, IsEmpty());
             }
@@ -354,7 +400,8 @@ SCENARIO("test server crashes and timeouts are reported")
     {
         TestServer server;
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "DuringCrash::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("DuringCrash");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "DuringCrash");
 
         server.start("self_test", extra_args, env);
 
@@ -372,8 +419,7 @@ SCENARIO("test server crashes and timeouts are reported")
 
                 THEN("there should be a single (non-port-in-use) log containing the helpful diagnostic and exit status")
                 {
-                    using Catch::Matchers::ContainsSubstring;
-                    using Catch::Matchers::SizeIs;
+                    using namespace Catch::Matchers;
 
                     logger->remove_port_in_use_logs();
                     REQUIRE_THAT(logger->logs, SizeIs(1));
@@ -388,7 +434,8 @@ SCENARIO("test server crashes and timeouts are reported")
     {
         TestServer server;
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "ExitCrash::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("ExitCrash");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "ExitCrash");
 
         server.start("self_test", extra_args, env);
 
@@ -398,8 +445,7 @@ SCENARIO("test server crashes and timeouts are reported")
 
             THEN("there should be a single (non-port-in-use) log containing the helpful diagnostic and exit status")
             {
-                using Catch::Matchers::ContainsSubstring;
-                using Catch::Matchers::SizeIs;
+                using namespace Catch::Matchers;
 
                 logger->remove_port_in_use_logs();
                 REQUIRE_THAT(logger->logs, SizeIs(1));
@@ -413,7 +459,8 @@ SCENARIO("test server crashes and timeouts are reported")
     {
         TestServer server;
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "ExitTimeout::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("ExitTimeout");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "ExitTimeout");
 
         server.start("self_test", extra_args, env);
 
@@ -424,8 +471,7 @@ SCENARIO("test server crashes and timeouts are reported")
 
             THEN("there should be a single (non-port-in-use) log, reporting the timeout the helpful diagnostic")
             {
-                using Catch::Matchers::ContainsSubstring;
-                using Catch::Matchers::SizeIs;
+                using namespace Catch::Matchers;
 
                 logger->remove_port_in_use_logs();
                 REQUIRE_THAT(logger->logs, SizeIs(1));
@@ -446,7 +492,8 @@ SCENARIO("test server timeouts during startup are reported", "[!mayfail]")
     {
         TestServer server;
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "InitTimeout::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("InitTimeout");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "InitTimeout");
 
         WHEN("we start the server")
         {
@@ -463,7 +510,7 @@ SCENARIO("test server timeouts during startup are reported", "[!mayfail]")
 
             THEN("a exception should be raised, reporting the timeout and the helpful message")
             {
-                using Catch::Matchers::ContainsSubstring;
+                using namespace Catch::Matchers;
                 REQUIRE(what);
                 REQUIRE_THAT(*what, ContainsSubstring("Timeout waiting for TestServer to start"));
                 REQUIRE_THAT(*what, ContainsSubstring(k_helpful_message));
@@ -471,7 +518,7 @@ SCENARIO("test server timeouts during startup are reported", "[!mayfail]")
 
             THEN("there should be no (non-port-in-use) logs")
             {
-                using Catch::Matchers::IsEmpty;
+                using namespace Catch::Matchers;
                 logger->remove_port_in_use_logs();
                 REQUIRE_THAT(logger->logs, IsEmpty());
             }
@@ -518,13 +565,18 @@ SCENARIO("The env parameter for starting the server works")
     {
         TestServer server;
         std::vector<std::string> extra_args = {"-nodb", "-dlist", "TestEnvDS::TestServer/tests/1"};
-        std::vector<std::string> env = env_with_log_file("TestEnvDS");
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "TestEnvDS");
+
         env.emplace_back("TANGO_TEST_ENV=abcd");
         server.start("self_test", extra_args, env);
 
         std::string fqtrl = TangoTest::make_nodb_fqtrl(server.get_port(), "TestServer/tests/1");
 
         auto device = std::make_unique<Tango::DeviceProxy>(fqtrl);
+
+        REQUIRE(idlver == device->get_idl_version());
+
         WHEN("we read the attribute")
         {
             std::string att{"env"};
@@ -545,3 +597,162 @@ SCENARIO("The env parameter for starting the server works")
         }
     }
 }
+
+SCENARIO("Environment variable forwarding produces valid environment tables")
+{
+    using namespace Catch::Matchers;
+
+    constexpr const size_t k_size = 4;
+    auto buffer = std::make_unique<char[]>(k_size);
+    memcpy(buffer.get(), "foo", k_size);
+    auto get_env = [&](const char *name)
+    {
+        if(strcmp(name, "missing") == 0)
+        {
+            return static_cast<char *>(nullptr);
+        }
+
+        return buffer.get();
+    };
+
+    GIVEN("an empty list of environment variables")
+    {
+        std::string names;
+        std::vector<std::string> env;
+
+        WHEN("we append the forwarded environment variables")
+        {
+            TangoTest::append_forwarded_envvars(env, names, get_env);
+
+            THEN("the environment table is empty")
+            {
+                REQUIRE_THAT(env, IsEmpty());
+            }
+        }
+    }
+
+    GIVEN("list of environment variables with a single element")
+    {
+        std::string names = "a";
+        std::vector<std::string> env;
+
+        WHEN("we append the forwarded environment variables")
+        {
+            TangoTest::append_forwarded_envvars(env, names, get_env);
+
+            THEN("the environment table has a single entry")
+            {
+                std::vector<std::string> expected = {"a=foo"};
+                REQUIRE_THAT(env, UnorderedRangeEquals(expected));
+            }
+        }
+    }
+
+    GIVEN("a comma-separated list of forwarded environment variables")
+    {
+        std::string names = "a,b,c,d";
+        std::vector<std::string> env;
+
+        WHEN("we append the forwarded environment variables")
+        {
+            TangoTest::append_forwarded_envvars(env, names, get_env);
+
+            THEN("we find all the environment variables in the env table")
+            {
+                std::vector<std::string> expected = {"a=foo", "b=foo", "c=foo", "d=foo"};
+                REQUIRE_THAT(env, UnorderedRangeEquals(expected));
+            }
+        }
+    }
+
+    GIVEN("a comma-separated list of forwarded environment variables with a missing environment variable")
+    {
+        std::string names = "a,b,missing,d";
+        std::vector<std::string> env;
+
+        WHEN("we append the forwarded environment variables")
+        {
+            TangoTest::append_forwarded_envvars(env, names, get_env);
+
+            THEN("the missing variable is skipped")
+            {
+                std::vector<std::string> expected = {"a=foo", "b=foo", "d=foo"};
+                REQUIRE_THAT(env, UnorderedRangeEquals(expected));
+            }
+        }
+    }
+
+    GIVEN("a comma-separated list of forwarded environment variables with a trailing comma")
+    {
+        std::string names = "a,b,c,d,";
+        std::vector<std::string> env;
+
+        WHEN("we append the forwarded environment variables")
+        {
+            TangoTest::append_forwarded_envvars(env, names, get_env);
+
+            THEN("the missing variable is skipped")
+            {
+                std::vector<std::string> expected = {"a=foo", "b=foo", "c=foo", "d=foo"};
+                REQUIRE_THAT(env, UnorderedRangeEquals(expected));
+            }
+        }
+    }
+}
+
+template <class Base>
+class EnvInspector : public Base
+{
+  public:
+    using Base::Base;
+
+    ~EnvInspector() override { }
+
+    void init_device() override { }
+
+    Tango::DevString foo_from_env()
+    {
+        return Tango::string_dup(getenv("foo"));
+    }
+
+    static void command_factory(std::vector<Tango::Command *> &cmds)
+    {
+        cmds.push_back(new TangoTest::AutoCommand<&EnvInspector::foo_from_env>("FooFromEnv"));
+    }
+};
+
+TANGO_TEST_AUTO_DEV_CLASS_INSTANTIATE(EnvInspector<TANGO_BASE_CLASS>, EnvInspector)
+
+SCENARIO("Environment variables can be forwarded")
+{
+    constexpr const char *k_name = "foo";
+    constexpr const char *k_expected = "bar";
+    GIVEN("a server started with an env inspector device class")
+    {
+        TangoTest::TestServer server;
+        std::vector<std::string> extra_args = {"-nodb", "-dlist", "EnvInspector::TestServer/tests/1"};
+        std::vector<std::string> env;
+        TangoTest::append_std_entries_to_env(env, "EnvInspector");
+
+        set_env(k_name, k_expected, true);
+        set_env(TangoTest::k_forwarded_envvars_env, k_name, true);
+
+        server.start("self_test", extra_args, env);
+
+        std::string fqtrl = TangoTest::make_nodb_fqtrl(server.get_port(), "TestServer/tests/1");
+
+        auto device = std::make_unique<Tango::DeviceProxy>(fqtrl);
+
+        WHEN("we query the envrionment variable on the server")
+        {
+            Tango::DeviceData dd = device->command_inout("FooFromEnv");
+            std::string found;
+            dd >> found;
+
+            THEN("we get the expected value")
+            {
+                REQUIRE(found == k_expected);
+            }
+        }
+    }
+}
