@@ -5,6 +5,8 @@
 
 #include "catch2_common.h"
 
+constexpr static Tango::DevLong k_polling_period = TANGO_TEST_CATCH2_DEFAULT_POLL_PERIOD;
+
 constexpr static Tango::DevDouble ATTR_INIT_VALUE = 0.0;
 static const Tango::DevDouble ATTR_NAN_VALUE = std::nan("nan");
 
@@ -60,7 +62,7 @@ class ChangeEventOnNanDev_Double : public Base
         Tango::UserDefaultAttrProp abs_props;
         abs_props.set_event_abs_change("0.01");
         attr_abs->set_default_properties(abs_props);
-        attr_abs->set_polling_period(100);
+        attr_abs->set_polling_period(k_polling_period);
         attrs.push_back(attr_abs);
 
         // attribute with relative change
@@ -68,7 +70,7 @@ class ChangeEventOnNanDev_Double : public Base
         Tango::UserDefaultAttrProp rel_props;
         rel_props.set_event_rel_change("0.01");
         attr_rel->set_default_properties(rel_props);
-        attr_rel->set_polling_period(100);
+        attr_rel->set_polling_period(k_polling_period);
         attrs.push_back(attr_rel);
     }
 
@@ -137,7 +139,7 @@ class ChangeEventOnNanDev_Float : public Base
         Tango::UserDefaultAttrProp abs_props;
         abs_props.set_event_abs_change("0.01");
         attr_abs->set_default_properties(abs_props);
-        attr_abs->set_polling_period(100);
+        attr_abs->set_polling_period(k_polling_period);
         attrs.push_back(attr_abs);
 
         // attribute with relative change
@@ -145,7 +147,7 @@ class ChangeEventOnNanDev_Float : public Base
         Tango::UserDefaultAttrProp rel_props;
         rel_props.set_event_rel_change("0.01");
         attr_rel->set_default_properties(rel_props);
-        attr_rel->set_polling_period(100);
+        attr_rel->set_polling_period(k_polling_period);
         attrs.push_back(attr_rel);
     }
 
@@ -170,7 +172,7 @@ SCENARIO("Change events for DevDouble are generated on NaN with absolute change"
     GIVEN("a device proxy to a simple IDLv" << idlver << " device")
     {
         TangoTest::Context ctx{"change_event_on_nan", "ChangeEventOnNanDev_Double", idlver};
-        auto device = ctx.get_proxy();
+        std::shared_ptr<Tango::DeviceProxy> device = ctx.get_proxy();
 
         REQUIRE(idlver == device->get_idl_version());
 
@@ -183,30 +185,11 @@ SCENARIO("Change events for DevDouble are generated on NaN with absolute change"
             AND_GIVEN("a change event subscription")
             {
                 TangoTest::CallbackMock<Tango::EventData> callback;
-                REQUIRE_NOTHROW(device->subscribe_event(att, Tango::CHANGE_EVENT, &callback));
+                TangoTest::Subscription sub{device, att, Tango::CHANGE_EVENT, &callback};
 
                 THEN("we receive some events with the initial value")
                 {
-                    using Catch::Matchers::IsNaN;
-                    using Catch::Matchers::WithinAbs;
-                    using TangoTest::AnyLikeMatches;
-                    // We get the following two initial events (the fact there
-                    // are two is a side effect of the fix for #369):
-                    //
-                    // 1. In `subscribe_event` we do a `read_attribute` to
-                    // generate the first event
-                    // 2. Because we are the first subscriber to `"attr"`, the
-                    // polling loop starts and sends an event because it is the
-                    // first time it has read the attribute
-
-                    auto maybe_initial_event = callback.pop_next_event();
-                    REQUIRE(maybe_initial_event.has_value());
-                    REQUIRE(!maybe_initial_event->err);
-                    REQUIRE(maybe_initial_event->attr_value != nullptr);
-                    REQUIRE_THAT(*maybe_initial_event->attr_value,
-                                 AnyLikeMatches(WithinAbs(ATTR_INIT_VALUE, 0.0000001)));
-
-                    maybe_initial_event = callback.pop_next_event();
+                    require_initial_events(callback, ATTR_INIT_VALUE);
 
                     WHEN("we set the attribute value to NaN")
                     {
@@ -214,23 +197,26 @@ SCENARIO("Change events for DevDouble are generated on NaN with absolute change"
 
                         THEN("a change event is generated")
                         {
+                            using namespace Catch::Matchers;
+                            using namespace TangoTest::Matchers;
+
                             auto maybe_new_event = callback.pop_next_event();
-                            REQUIRE(maybe_new_event.has_value());
-                            REQUIRE(!maybe_new_event->err);
-                            REQUIRE(maybe_new_event->attr_value != nullptr);
-                            REQUIRE_THAT(*maybe_new_event->attr_value, AnyLikeMatches(IsNaN()));
+                            REQUIRE(maybe_new_event != std::nullopt);
+                            REQUIRE_THAT(maybe_new_event, EventValueMatches(AnyLikeMatches(IsNaN())));
                             AND_WHEN("we unset the attribute value from NaN")
                             {
                                 REQUIRE_NOTHROW(device->command_inout("unset_abs_nan"));
 
                                 THEN("a change event is generated")
                                 {
+                                    using namespace Catch::Matchers;
+                                    using namespace TangoTest::Matchers;
+
                                     auto maybe_new_event = callback.pop_next_event();
-                                    REQUIRE(maybe_new_event.has_value());
-                                    REQUIRE(!maybe_new_event->err);
-                                    REQUIRE(maybe_new_event->attr_value != nullptr);
-                                    REQUIRE_THAT(*maybe_new_event->attr_value,
-                                                 AnyLikeMatches(WithinAbs(ATTR_INIT_VALUE, 0.0000001)));
+                                    REQUIRE(maybe_new_event != std::nullopt);
+                                    REQUIRE_THAT(
+                                        maybe_new_event,
+                                        EventValueMatches(AnyLikeMatches(WithinAbs(ATTR_INIT_VALUE, 0.0000001))));
                                 }
                             }
                         }
@@ -247,7 +233,7 @@ SCENARIO("Change events for DevDouble are generated on NaN with relative change"
     GIVEN("a device proxy to a simple IDLv" << idlver << " device")
     {
         TangoTest::Context ctx{"change_event_on_nan", "ChangeEventOnNanDev_Double", idlver};
-        auto device = ctx.get_proxy();
+        std::shared_ptr<Tango::DeviceProxy> device = ctx.get_proxy();
 
         REQUIRE(idlver == device->get_idl_version());
 
@@ -260,53 +246,38 @@ SCENARIO("Change events for DevDouble are generated on NaN with relative change"
             AND_GIVEN("a change event subscription")
             {
                 TangoTest::CallbackMock<Tango::EventData> callback;
-                REQUIRE_NOTHROW(device->subscribe_event(att, Tango::CHANGE_EVENT, &callback));
+                TangoTest::Subscription sub{device, att, Tango::CHANGE_EVENT, &callback};
+
                 THEN("we receive some events with the initial value")
                 {
-                    using Catch::Matchers::IsNaN;
-                    using Catch::Matchers::WithinAbs;
-                    using TangoTest::AnyLikeMatches;
-
-                    // We get the following two initial events (the fact there
-                    // are two is a side effect of the fix for #369):
-                    //
-                    // 1. In `subscribe_event` we do a `read_attribute` to
-                    // generate the first event
-                    // 2. Because we are the first subscriber to `"attr"`, the
-                    // polling loop starts and sends an event because it is the
-                    // first time it has read the attribute
-
-                    auto maybe_initial_event = callback.pop_next_event();
-                    REQUIRE(maybe_initial_event.has_value());
-                    REQUIRE(!maybe_initial_event->err);
-                    REQUIRE(maybe_initial_event->attr_value != nullptr);
-                    REQUIRE_THAT(*maybe_initial_event->attr_value,
-                                 AnyLikeMatches(WithinAbs(ATTR_INIT_VALUE, 0.0000001)));
-
-                    maybe_initial_event = callback.pop_next_event();
+                    require_initial_events(callback, ATTR_INIT_VALUE);
 
                     WHEN("we set the attribute value to NaN")
                     {
                         REQUIRE_NOTHROW(device->command_inout("set_rel_nan"));
+
                         THEN("a change event is generated")
                         {
+                            using namespace Catch::Matchers;
+                            using namespace TangoTest::Matchers;
+
                             auto maybe_new_event = callback.pop_next_event();
-                            REQUIRE(maybe_new_event.has_value());
-                            REQUIRE(!maybe_new_event->err);
-                            REQUIRE(maybe_new_event->attr_value != nullptr);
-                            REQUIRE_THAT(*maybe_new_event->attr_value, AnyLikeMatches(IsNaN()));
+                            REQUIRE(maybe_new_event != std::nullopt);
+                            REQUIRE_THAT(maybe_new_event, EventValueMatches(AnyLikeMatches(IsNaN())));
 
                             AND_WHEN("we unset the attribute value from NaN")
                             {
                                 REQUIRE_NOTHROW(device->command_inout("unset_rel_nan"));
                                 THEN("a change event is generated")
                                 {
+                                    using namespace Catch::Matchers;
+                                    using namespace TangoTest::Matchers;
+
                                     auto maybe_new_event = callback.pop_next_event();
-                                    REQUIRE(maybe_new_event.has_value());
-                                    REQUIRE(!maybe_new_event->err);
-                                    REQUIRE(maybe_new_event->attr_value != nullptr);
-                                    REQUIRE_THAT(*maybe_new_event->attr_value,
-                                                 AnyLikeMatches(WithinAbs(ATTR_INIT_VALUE, 0.0000001)));
+                                    REQUIRE(maybe_new_event != std::nullopt);
+                                    REQUIRE_THAT(
+                                        maybe_new_event,
+                                        EventValueMatches(AnyLikeMatches(WithinAbs(ATTR_INIT_VALUE, 0.0000001))));
                                 }
                             }
                         }
@@ -325,7 +296,7 @@ SCENARIO("Change events for DevFloat are generated on NaN with absolute change")
     GIVEN("a device proxy to a simple IDLv" << idlver << " device")
     {
         TangoTest::Context ctx{"change_event_on_nan", "ChangeEventOnNanDev_Float", idlver};
-        auto device = ctx.get_proxy();
+        std::shared_ptr<Tango::DeviceProxy> device = ctx.get_proxy();
 
         REQUIRE(idlver == device->get_idl_version());
 
@@ -338,31 +309,11 @@ SCENARIO("Change events for DevFloat are generated on NaN with absolute change")
             AND_GIVEN("a change event subscription")
             {
                 TangoTest::CallbackMock<Tango::EventData> callback;
-                REQUIRE_NOTHROW(device->subscribe_event(att, Tango::CHANGE_EVENT, &callback));
+                TangoTest::Subscription sub{device, att, Tango::CHANGE_EVENT, &callback};
 
                 THEN("we receive some events with the initial value")
                 {
-                    using Catch::Matchers::IsNaN;
-                    using Catch::Matchers::WithinAbs;
-                    using TangoTest::AnyLikeMatches;
-
-                    // We get the following two initial events (the fact there
-                    // are two is a side effect of the fix for #369):
-                    //
-                    // 1. In `subscribe_event` we do a `read_attribute` to
-                    // generate the first event
-                    // 2. Because we are the first subscriber to `"attr"`, the
-                    // polling loop starts and sends an event because it is the
-                    // first time it has read the attribute
-
-                    auto maybe_initial_event = callback.pop_next_event();
-                    REQUIRE(maybe_initial_event.has_value());
-                    REQUIRE(!maybe_initial_event->err);
-                    REQUIRE(maybe_initial_event->attr_value != nullptr);
-                    REQUIRE_THAT(*maybe_initial_event->attr_value,
-                                 AnyLikeMatches<float>(WithinAbs(ATTR_INIT_VALUE, 0.0000001f)));
-
-                    maybe_initial_event = callback.pop_next_event();
+                    require_initial_events(callback, static_cast<float>(ATTR_INIT_VALUE));
 
                     WHEN("we set the attribute value to NaN")
                     {
@@ -370,23 +321,26 @@ SCENARIO("Change events for DevFloat are generated on NaN with absolute change")
 
                         THEN("a change event is generated")
                         {
+                            using namespace Catch::Matchers;
+                            using namespace TangoTest::Matchers;
+
                             auto maybe_new_event = callback.pop_next_event();
-                            REQUIRE(maybe_new_event.has_value());
-                            REQUIRE(!maybe_new_event->err);
-                            REQUIRE(maybe_new_event->attr_value != nullptr);
-                            REQUIRE_THAT(*maybe_new_event->attr_value, AnyLikeMatches<float>(IsNaN()));
+                            REQUIRE(maybe_new_event != std::nullopt);
+                            REQUIRE_THAT(maybe_new_event, EventValueMatches(AnyLikeMatches<float>(IsNaN())));
                             AND_WHEN("we unset the attribute value from NaN")
                             {
                                 REQUIRE_NOTHROW(device->command_inout("unset_abs_nan"));
 
                                 THEN("a change event is generated")
                                 {
+                                    using namespace Catch::Matchers;
+                                    using namespace TangoTest::Matchers;
+
                                     auto maybe_new_event = callback.pop_next_event();
-                                    REQUIRE(maybe_new_event.has_value());
-                                    REQUIRE(!maybe_new_event->err);
-                                    REQUIRE(maybe_new_event->attr_value != nullptr);
-                                    REQUIRE_THAT(*maybe_new_event->attr_value,
-                                                 AnyLikeMatches<float>(WithinAbs(ATTR_INIT_VALUE, 0.0000001f)));
+                                    REQUIRE(maybe_new_event != std::nullopt);
+                                    REQUIRE_THAT(maybe_new_event,
+                                                 EventValueMatches(
+                                                     AnyLikeMatches<float>(WithinAbs(ATTR_INIT_VALUE, 0.0000001f))));
                                 }
                             }
                         }
@@ -403,7 +357,7 @@ SCENARIO("Change events for DevFloat are generated on NaN with relative change")
     GIVEN("a device proxy to a simple IDLv" << idlver << " device")
     {
         TangoTest::Context ctx{"change_event_on_nan", "ChangeEventOnNanDev_Float", idlver};
-        auto device = ctx.get_proxy();
+        std::shared_ptr<Tango::DeviceProxy> device = ctx.get_proxy();
 
         REQUIRE(idlver == device->get_idl_version());
 
@@ -416,53 +370,38 @@ SCENARIO("Change events for DevFloat are generated on NaN with relative change")
             AND_GIVEN("a change event subscription")
             {
                 TangoTest::CallbackMock<Tango::EventData> callback;
-                REQUIRE_NOTHROW(device->subscribe_event(att, Tango::CHANGE_EVENT, &callback));
+                TangoTest::Subscription sub{device, att, Tango::CHANGE_EVENT, &callback};
+
                 THEN("we receive some events with the initial value")
                 {
-                    using Catch::Matchers::IsNaN;
-                    using Catch::Matchers::WithinAbs;
-                    using TangoTest::AnyLikeMatches;
-
-                    // We get the following two initial events (the fact there
-                    // are two is a side effect of the fix for #369):
-                    //
-                    // 1. In `subscribe_event` we do a `read_attribute` to
-                    // generate the first event
-                    // 2. Because we are the first subscriber to `"attr"`, the
-                    // polling loop starts and sends an event because it is the
-                    // first time it has read the attribute
-
-                    auto maybe_initial_event = callback.pop_next_event();
-                    REQUIRE(maybe_initial_event.has_value());
-                    REQUIRE(!maybe_initial_event->err);
-                    REQUIRE(maybe_initial_event->attr_value != nullptr);
-                    REQUIRE_THAT(*maybe_initial_event->attr_value,
-                                 AnyLikeMatches<float>(WithinAbs(ATTR_INIT_VALUE, 0.0000001f)));
-
-                    maybe_initial_event = callback.pop_next_event();
+                    require_initial_events(callback, static_cast<float>(ATTR_INIT_VALUE));
 
                     WHEN("we set the attribute value to NaN")
                     {
                         REQUIRE_NOTHROW(device->command_inout("set_rel_nan"));
+
                         THEN("a change event is generated")
                         {
+                            using namespace Catch::Matchers;
+                            using namespace TangoTest::Matchers;
+
                             auto maybe_new_event = callback.pop_next_event();
-                            REQUIRE(maybe_new_event.has_value());
-                            REQUIRE(!maybe_new_event->err);
-                            REQUIRE(maybe_new_event->attr_value != nullptr);
-                            REQUIRE_THAT(*maybe_new_event->attr_value, AnyLikeMatches<float>(IsNaN()));
+                            REQUIRE(maybe_new_event != std::nullopt);
+                            REQUIRE_THAT(maybe_new_event, EventValueMatches(AnyLikeMatches<float>(IsNaN())));
 
                             AND_WHEN("we unset the attribute value from NaN")
                             {
                                 REQUIRE_NOTHROW(device->command_inout("unset_rel_nan"));
                                 THEN("a change event is generated")
                                 {
+                                    using namespace Catch::Matchers;
+                                    using namespace TangoTest::Matchers;
+
                                     auto maybe_new_event = callback.pop_next_event();
-                                    REQUIRE(maybe_new_event.has_value());
-                                    REQUIRE(!maybe_new_event->err);
-                                    REQUIRE(maybe_new_event->attr_value != nullptr);
-                                    REQUIRE_THAT(*maybe_new_event->attr_value,
-                                                 AnyLikeMatches<float>(WithinAbs(ATTR_INIT_VALUE, 0.0000001f)));
+                                    REQUIRE(maybe_new_event != std::nullopt);
+                                    REQUIRE_THAT(maybe_new_event,
+                                                 EventValueMatches(
+                                                     AnyLikeMatches<float>(WithinAbs(ATTR_INIT_VALUE, 0.0000001f))));
                                 }
                             }
                         }
