@@ -96,9 +96,6 @@ void EventUnsubCallBack::push_event(Tango::EventData *event_data)
 
 int main(int argc, char **argv)
 {
-    // TODO: FIXME: This test is temporarily disabled due to failures on single-core machines.
-    return 0;
-
     DeviceProxy *device;
 
     if(argc == 1)
@@ -310,7 +307,7 @@ int main(int argc, char **argv)
 
         try
         {
-            device->subscribe_event(att_name, Tango::CHANGE_EVENT, (CallBack *) NULL, filters);
+            device->subscribe_event(att_name, Tango::CHANGE_EVENT, (CallBack *) nullptr, filters);
         }
         catch(Tango::DevFailed &e)
         {
@@ -327,7 +324,7 @@ int main(int argc, char **argv)
         assert(cb.cb_executed == 8);
         assert(ex == true);
 
-        TEST_LOG << "   CallBack executed after a try to subscribe to one attribute with a NULL callback --> OK"
+        TEST_LOG << "   CallBack executed after a try to subscribe to one attribute with a nullptr callback --> OK"
                  << std::endl;
 
         //
@@ -343,7 +340,7 @@ int main(int argc, char **argv)
         //
 
         char *tg_host = getenv("TANGO_HOST");
-        if(tg_host == NULL)
+        if(tg_host == nullptr)
         {
             assert(false);
         }
@@ -598,149 +595,6 @@ int main(int argc, char **argv)
         cb.old_sec = cb.old_usec = 0;
         // start the polling first!
         device->poll_attribute(att_name, 1000);
-#ifdef NOTIFD
-        filters.push_back("$delta_change_abs >= 2 or $delta_change_abs <= -2");
-        eve_id = device->subscribe_event(att_name, Tango::CHANGE_EVENT, &cb, filters);
-
-        //
-        // Check that the attribute is still polled at 1000 mS
-        //
-
-        po = device->is_attribute_polled(att_name);
-        TEST_LOG << "attribute polled : " << po << std::endl;
-        assert(po == true);
-
-        poll_period = device->get_attribute_poll_period(att_name);
-        TEST_LOG << "att polling period : " << poll_period << std::endl;
-        assert(poll_period == 1000);
-
-        TEST_LOG << "   subscribe_event (with filter) --> OK" << std::endl;
-
-        //
-        // Check that first point has been received
-        //
-
-        assert(cb.cb_executed == 1);
-        assert(cb.val == 30);
-        assert(cb.val_size == 4);
-        TEST_LOG << "   first point received (with filter) --> OK" << std::endl;
-
-        //
-        // Generates a positive change
-        //
-
-        std::this_thread::sleep_for(std::chrono::seconds(1));
-
-        device->command_inout("IOIncValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(1));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 1);
-
-        // Let's hope the polling thread will not start just between the two command_inout
-
-        device->command_inout("IOIncValue");
-        device->command_inout("IOIncValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(3));
-
-        assert(cb.cb_executed == 2);
-        assert(cb.val == 33);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   CallBack executed for positive delta (with filter) --> OK" << std::endl;
-
-        //
-        // Generates a negative change
-        //
-
-        device->command_inout("IODecValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 2);
-
-        device->command_inout("IODecValue");
-        device->command_inout("IODecValue");
-        device->command_inout("IODecValue");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        assert(cb.cb_executed == 3);
-        assert(cb.val == 29);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   CallBack executed for negative delta (with filter) --> OK" << std::endl;
-
-        //
-        // Check that callback was called after adding one elt to the spectrum
-        //
-
-        device->command_inout("IOAddOneElt");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 4);
-        assert(cb.val == 29);
-        assert(cb.val_size == 5);
-
-        TEST_LOG << "   CallBack executed when spectrum size increases (with filter) --> OK" << std::endl;
-
-        //
-        // Check that callback was called after removing one elt to the spectrum
-        //
-
-        device->command_inout("IORemoveOneElt");
-
-        std::this_thread::sleep_for(std::chrono::seconds(2));
-
-        TEST_LOG << "cb excuted = " << cb.cb_executed << std::endl;
-        assert(cb.cb_executed == 5);
-        assert(cb.val == 29);
-        assert(cb.val_size == 4);
-
-        TEST_LOG << "   CallBack executed when spectrum size decreases (with filter) --> OK" << std::endl;
-
-        //
-        // Force the attribute to throw exception
-        //
-
-        data_in[0] = 1;
-        data_in[1] = 1;
-        di << data_in;
-
-        device->command_inout("IOAttrThrowEx", di);
-
-        //
-        // Check that callback was called
-        //
-
-        std::this_thread::sleep_for(std::chrono::seconds(3));
-        TEST_LOG << "Callback cb_err = " << cb.cb_err << std::endl;
-        assert(cb.cb_err == 1);
-
-        TEST_LOG << "   CallBack executed when attribute throw exception only once (with filter) --> OK" << std::endl;
-
-        //
-        // Attribute does not send exception any more
-        //
-
-        data_in[1] = 0;
-        di << data_in;
-
-        device->command_inout("IOAttrThrowEx", di);
-
-        //
-        // unsubscribe to the event
-        //
-
-        device->unsubscribe_event(eve_id);
-
-        TEST_LOG << "   unsubscribe_event --> OK" << std::endl;
-#endif
 
         //
         // Try to unsubscribe within the callback
