@@ -1,12 +1,14 @@
-#ifndef CompareTest_h
-#define CompareTest_h
+// NOLINTBEGIN(*)
 
-#include <iostream>
-#include <fstream>
-#include <sstream>
-#include <stdexcept>
-#include <map>
-#include <vector>
+#ifndef CompareTest_h
+  #define CompareTest_h
+
+  #include <iostream>
+  #include <fstream>
+  #include <sstream>
+  #include <stdexcept>
+  #include <map>
+  #include <vector>
 
 namespace CmpTst
 {
@@ -24,6 +26,15 @@ namespace CmpTst
 class CompareTest
 {
   public:
+    //+-------------------------------------------------------------------------
+    //
+    // method :            make_filename_unique
+    //
+    // description :    Returns a filename from `base` which is guaranteed to be
+    //                  unique among all the running copies of this program.
+    // argument : in :    - base : basename for the file
+    static std::string make_filename_unique(std::string base);
+
     //+-------------------------------------------------------------------------
     //
     // method :            out_set_event_properties
@@ -249,3 +260,5 @@ class CompareTestException : public std::runtime_error
 };
 } // namespace CmpTst
 #endif // CompareTest_h
+
+// NOLINTEND(*)
