@@ -76,9 +76,7 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
     void test_Scalar_Short(void)
     {
         DeviceAttribute da;
-#ifndef COMPAT
         TS_ASSERT_EQUALS(da.get_data_format(), Tango::FMT_UNKNOWN);
-#endif
 
         try
         {
@@ -104,10 +102,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         da >> sh;
         TS_ASSERT_EQUALS(sh, 12);
         TS_ASSERT_EQUALS(data_type, Tango::DEV_SHORT);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SCALAR);
-#endif
         //        TEST_LOG << "   Scalar short --> OK" << endl;
     }
 
@@ -116,9 +112,7 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
     void test_Scalar_Short_DevEncoded_2__loop(void)
     {
         DeviceAttribute da;
-#ifndef COMPAT
         TS_ASSERT_EQUALS(da.get_data_format(), Tango::FMT_UNKNOWN);
-#endif
 
         try
         {
@@ -134,10 +128,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         da >> sh;
         TS_ASSERT_EQUALS(sh, 12);
         TS_ASSERT_EQUALS(data_type, Tango::DEV_SHORT);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SCALAR);
-#endif
         //        TEST_LOG << "   Scalar short --> OK" << endl;
     }
 
@@ -146,9 +138,7 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
     void test_Scalar_Long__loop(void)
     {
         DeviceAttribute da;
-#ifndef COMPAT
         TS_ASSERT_EQUALS(da.get_data_format(), Tango::FMT_UNKNOWN);
-#endif
         try
         {
             da = device1->read_attribute("Long_attr");
@@ -163,10 +153,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         int data_type = da.get_type();
         TS_ASSERT_EQUALS(lo, 1246);
         TS_ASSERT_EQUALS(data_type, Tango::DEV_LONG);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SCALAR);
-#endif
     }
 
     // Test SCALAR double
@@ -303,10 +291,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
 
         TS_ASSERT_EQUALS(lo, 0x800000000LL);
         TS_ASSERT_EQUALS(data_type, Tango::DEV_LONG64);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SCALAR);
-#endif
     }
 
     // Test SCALAR unsigned long
@@ -356,9 +342,7 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
     void test_Scalar_State__loop(void)
     {
         DeviceAttribute da;
-#ifndef COMPAT
         TS_ASSERT_EQUALS(da.get_data_format(), Tango::FMT_UNKNOWN);
-#endif
         try
         {
             da = device1->read_attribute("State_attr_rw");
@@ -374,15 +358,12 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
 
         TS_ASSERT_EQUALS(lo, Tango::FAULT);
         TS_ASSERT_EQUALS(data_type, Tango::DEV_STATE);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SCALAR);
-#endif
     }
 
     // Test SCALAR DevEncoded
 
-#ifndef COMPAT
     void test_Scalar_DevEncoded__loop(void)
     {
         DeviceAttribute da;
@@ -401,10 +382,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
 
         TS_ASSERT_EQUALS(std::string(lo.encoded_format.in()), "Which format?");
         TS_ASSERT_EQUALS(data_type, Tango::DEV_ENCODED);
-  #ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SCALAR);
-  #endif
         TS_ASSERT_EQUALS(lo.encoded_data.length(), 4u);
         TS_ASSERT_EQUALS(lo.encoded_data[0], 97);
         TS_ASSERT_EQUALS(lo.encoded_data[1], 98);
@@ -420,7 +399,7 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         EncodedAttribute att;
         int width, height;
         unsigned char *gray8;
-  #ifdef TANGO_USE_JPEG
+#ifdef TANGO_USE_JPEG
         try
         {
             da = device1->read_attribute("Encoded_image");
@@ -439,14 +418,13 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         TS_ASSERT_LESS_THAN_EQUALS(gray8[128 + 128 * 256], 132);
 
         delete[] gray8;
-  #else
+#else
         da = device1->read_attribute("Encoded_image");
         TS_ASSERT_THROWS_ASSERT(att.decode_gray8(&da, &width, &height, &gray8),
                                 Tango::DevFailed & e,
                                 TS_ASSERT_EQUALS(string(e.errors[0].reason.in()), API_EmptyDeviceAttribute));
-  #endif
-    }
 #endif
+    }
 
     // Thirteen in one go
 
@@ -465,11 +443,9 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         names.push_back("ULong_attr_rw");
         names.push_back("ULong64_attr_rw");
         names.push_back("State_attr_rw");
-#ifndef COMPAT
         names.push_back("Encoded_attr");
 
         DevEncoded enc;
-#endif
 
         vector<DeviceAttribute> *received;
 
@@ -519,11 +495,9 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(ulo64, 0xC000000000000000LL);
         (*received)[11] >> sta;
         TS_ASSERT_EQUALS(sta, Tango::FAULT);
-#ifndef COMPAT
         (*received)[12] >> enc;
         TS_ASSERT_EQUALS(enc.encoded_data.length(), 4u);
         TS_ASSERT_EQUALS(std::string(enc.encoded_format.in()), "Which format?");
-#endif
 
         delete received;
     }
@@ -550,10 +524,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         bool ret = (da >> sh);
 
         TS_ASSERT(ret);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SPECTRUM);
-#endif
         TS_ASSERT_EQUALS(sh[0], 10);
         TS_ASSERT_EQUALS(sh[1], 20);
         TS_ASSERT_EQUALS(sh[2], 30);
@@ -578,10 +550,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         bool ret = (da >> lo);
 
         TS_ASSERT(ret);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SPECTRUM);
-#endif
         TS_ASSERT_EQUALS(lo[0], 0);
         TS_ASSERT_EQUALS(lo[1], 1);
         TS_ASSERT_EQUALS(lo[2], 2);
@@ -676,10 +646,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         bool ret = (da >> sh);
 
         TS_ASSERT(ret);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SPECTRUM);
-#endif
         TS_ASSERT(sh[0]);
         TS_ASSERT(sh[1]);
         TS_ASSERT(!sh[2]);
@@ -1120,10 +1088,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         DevVarStateArray *lo;
         bool ret = (da >> lo);
         TS_ASSERT(ret);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::SPECTRUM);
-#endif
         TS_ASSERT_EQUALS((*lo)[0], Tango::ON);
         TS_ASSERT_EQUALS((*lo)[1], Tango::OFF);
         TS_ASSERT_EQUALS((*lo)[2], Tango::UNKNOWN);
@@ -1149,10 +1115,8 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
         bool ret = (da >> lo);
 
         TS_ASSERT(ret);
-#ifndef COMPAT
         AttrDataFormat data_format = da.get_data_format();
         TS_ASSERT_EQUALS(data_format, Tango::IMAGE);
-#endif
 
         delete lo;
     }
@@ -1163,7 +1127,6 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
     {
         bool except = false;
         DeviceAttribute db;
-#ifndef COMPAT
         db.set_exceptions(DeviceAttribute::unknown_format_flag);
 
         try
@@ -1180,8 +1143,6 @@ class CmdTypesTestSuite : public CxxTest::TestSuite
 
         AttrDataFormat df = db.get_data_format();
         TS_ASSERT_EQUALS(df, Tango::FMT_UNKNOWN);
-
-#endif
     }
 
     // Test DeviceAttribute get_type method after constructor call
