@@ -1,5 +1,4 @@
-#ifndef DynamicAttributesTestSuite_h
-#define DynamicAttributesTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -157,4 +156,4 @@ class DynamicAttributesTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // DynamicAttributesTestSuite_h
+// NOLINTEND(*)
