@@ -1,5 +1,4 @@
-#ifndef EnumTestSuite_h
-#define EnumTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -604,4 +603,4 @@ class EnumAttTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // EnumTestSuite_h
+// NOLINTEND(*)
