@@ -1,5 +1,4 @@
-#ifndef ExceptionTestSuite_h
-#define ExceptionTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -159,4 +158,5 @@ class ExceptionTestSuite : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(state_out, Tango::ON);
     }
 };
-#endif // ExceptionTestSuite_h
+
+// NOLINTEND(*)
