@@ -52,8 +52,8 @@ class FwdAttTestSuite : public CxxTest::TestSuite
         // Initialization --------------------------------------------------
         //
 
-        confs_init = NULL;
-        confs_root_init = NULL;
+        confs_init = nullptr;
+        confs_root_init = nullptr;
 
         try
         {
@@ -552,6 +552,7 @@ class FwdAttTestSuite : public CxxTest::TestSuite
 
         std::this_thread::sleep_for(std::chrono::seconds(1));
 
+        delete confs_root;
         confs_root = device1->get_attribute_config_ex(att_names_root);
         TS_ASSERT_EQUALS((*confs_root)[0].min_value, "0");
 
@@ -578,9 +579,11 @@ class FwdAttTestSuite : public CxxTest::TestSuite
         (*confs)[0].label = "Hai Hai Hai";
         fwd_device->set_attribute_config(*confs);
 
+        delete confs;
         confs = fwd_device->get_attribute_config_ex(att_names);
         TS_ASSERT_EQUALS((*confs)[0].label, "Hai Hai Hai");
 
+        delete confs_root;
         confs_root = device1->get_attribute_config_ex(att_names_root);
         TS_ASSERT_EQUALS((*confs_root)[0].label, "Ca marche?");
 
