@@ -1,5 +1,4 @@
-#ifndef MemAttrTestSuite_h
-#define MemAttrTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -215,4 +214,4 @@ class MemAttrTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // MemAttrTestSuite_h
+// NOLINTEND(*)
