@@ -1,5 +1,4 @@
-#ifndef MiscUtilTestSuite_h
-#define MiscUtilTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -135,4 +134,5 @@ class MiscUtilTestSuite : public CxxTest::TestSuite
                                 TS_ASSERT_EQUALS(e.errors[0].severity, Tango::ERR));
     }
 };
-#endif // MiscUtilTestSuite_h
+
+// NOLINTEND(*)
