@@ -1,5 +1,4 @@
-#ifndef PipeTestSuite_h
-#define PipeTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -703,4 +702,4 @@ class PipeTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // PipeTestSuite_h
+// NOLINTEND(*)
