@@ -1,5 +1,4 @@
-#ifndef PipeConfTestSuite_h
-#define PipeConfTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -373,4 +372,4 @@ class PipeConfTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // PipeTestSuite_h
+// NOLINTEND(*)
