@@ -1,5 +1,4 @@
-#ifndef PollTestSuite_h
-#define PollTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -441,4 +440,4 @@ class PollTestSuite__loop : public CxxTest::TestSuite
     }
 };
 
-#endif // PollTestSuite_h
+// NOLINTEND(*)
