@@ -1,5 +1,4 @@
-#ifndef SeqVecTestSuite_h
-#define SeqVecTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -236,4 +235,4 @@ class SeqVecTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // SeqVecTestSuite_h
+// NOLINTEND(*)
