@@ -1,5 +1,4 @@
-#ifndef TemplateTestSuite_h
-#define TemplateTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -108,4 +107,4 @@ class TemplateTestSuite : public CxxTest::TestSuite
     }
 };
 
-#endif // TemplateTestSuite_h
+// NOLINTEND(*)
