@@ -1,5 +1,4 @@
-#ifndef WriteAttrHardware_h
-#define WriteAttrHardware_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -275,7 +274,10 @@ class WriteAttrHardware : public CxxTest::TestSuite
         TS_ASSERT_EQUALS(read_after_att2[0], Tango::STANDBY);
         TS_ASSERT_EQUALS(read_after_att1.size(), 1u);
         TS_ASSERT_EQUALS(read_after_att1[0], 111);
+
+        delete read_bef;
+        delete read_after;
     }
 };
 
-#endif // WriteAttrHardware_h
+// NOLINTEND(*)
