@@ -1,5 +1,4 @@
-#ifndef McastLocalRemoteTestSuite_h
-#define McastLocalRemoteTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -256,4 +255,4 @@ void McastLocalRemoteTestSuite::EventCallBack::push_event(Tango::EventData *even
     }
 }
 
-#endif // McastLocalRemoteTestSuite_h
+// NOLINTEND(*)
