@@ -1,5 +1,4 @@
-#ifndef SvrMcastLocalRemoteTestSuite_h
-#define SvrMcastLocalRemoteTestSuite_h
+// NOLINTBEGIN(*)
 
 #include "cxx_common.h"
 
@@ -265,4 +264,4 @@ void SvrMcastLocalRemoteTestSuite::EventCallBack::push_event(Tango::EventData *e
     }
 }
 
-#endif // SvrMcastLocalRemoteTestSuite_h
+// NOLINTEND(*)
