@@ -10,6 +10,8 @@
 
 #include <cxxtest/Flags.h>
 
+#include <tango/internal/parse.h>
+
 #ifndef _CXXTEST_HAVE_STD
 #   define _CXXTEST_HAVE_STD
 #endif // _CXXTEST_HAVE_STD
@@ -365,13 +367,11 @@ public:
             exit(0);
         }
 
-        // atoi() converts string into integer; if not possible, returns 0
-        if (is_param_defined("loop"))
-            loop = atoi(get_param_val("loop").c_str());
+        if (is_param_set("loop"))
+            loop = Tango::detail::parse_as<int>(get_param_val("loop"));
 
-        // atoi() converts string into integer; if not possible, returns 0
-        if (is_param_defined("suiteloop"))
-            suite_loop = atoi(get_param_val("suiteloop").c_str());
+        if (is_param_set("suiteloop"))
+            suite_loop = Tango::detail::parse_as<int>(get_param_val("suiteloop"));
 
         TestRunner::runAllTests(*this);
         return tracker().failedTests();
