@@ -20,7 +20,7 @@
 #include "IOSetAttr.h"
 #include "IOAddAttribute.h"
 
-DevTestClass *DevTestClass::_instance = NULL;
+DevTestClass *DevTestClass::_instance = nullptr;
 
 //+----------------------------------------------------------------------------
 //
@@ -55,7 +55,7 @@ DevTestClass::DevTestClass(std::string &s) :
 
 DevTestClass *DevTestClass::init(const char *name)
 {
-    if(_instance == NULL)
+    if(_instance == nullptr)
     {
         try
         {
@@ -72,7 +72,7 @@ DevTestClass *DevTestClass::init(const char *name)
 
 DevTestClass *DevTestClass::instance()
 {
-    if(_instance == NULL)
+    if(_instance == nullptr)
     {
         std::cerr << "Class is not initialised !!" << std::endl;
         exit(-1);
@@ -582,10 +582,8 @@ void DevTestClass::attribute_factory(std::vector<Tango::Attr *> &att_list)
 
     att_list.push_back(new Sub_device_tstAttr());
     att_list.push_back(new SlowAttr());
-#ifndef COMPAT
     att_list.push_back(new Encoded_attr_rwAttr());
     att_list.push_back(new Encoded_attr_image());
-#endif
 
     Tango::UserDefaultAttrProp att_no_data_prop;
     att_no_data_prop.set_description("User desc");
