@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 int main()
 {
@@ -105,3 +107,5 @@ int main()
 
     return 0;
 }
+
+// NOLINTEND(*)
