@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 class EventCallBack : public Tango::CallBack
 {
@@ -244,3 +246,5 @@ int main(int argc, char **argv)
 
     return 0;
 }
+
+// NOLINTEND(*)
