@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 int main()
 {
@@ -71,3 +73,5 @@ int main()
     delete dbase;
     return 0;
 }
+
+// NOLINTEND(*)
