@@ -1,7 +1,9 @@
+// NOLINTBEGIN(*)
+
 #include <thread>
 #include <chrono>
 
-#include "common.h"
+#include "old_common.h"
 
 class EventCallBack : public Tango::CallBack
 {
@@ -297,3 +299,5 @@ int main(int argc, char **argv)
 
     return 0;
 }
+
+// NOLINTEND(*)
