@@ -1,4 +1,6 @@
-#include "common.h"
+// NOLINTBEGIN(*)
+
+#include "old_common.h"
 
 /*
  * Test module for sub device diagnostics in the Tango API.
@@ -135,3 +137,5 @@ int main(int argc, char **argv)
     delete device;
     return 0;
 }
+
+// NOLINTEND(*)
