@@ -1,6 +1,8 @@
+// NOLINTBEGIN(*)
+
 #include <limits>
 
-#include "common.h"
+#include "old_common.h"
 
 int main(int argc, char **argv)
 {
@@ -13,7 +15,7 @@ int main(int argc, char **argv)
     }
 
     string device_name = argv[1];
-    int loop = atoi(argv[2]);
+    int loop = parse_as<int>(argv[2]);
 
     try
     {
@@ -604,3 +606,5 @@ int main(int argc, char **argv)
     delete device;
     return 0;
 }
+
+// NOLINTEND(*)
